Class: Aws::NetworkFirewall::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NetworkFirewall::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-networkfirewall/client.rb,
sig/client.rbs
Overview
An API client for NetworkFirewall. To construct a client, you need to configure a :region and :credentials.
client = Aws::NetworkFirewall::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcceptNetworkFirewallTransitGatewayAttachmentResponseSuccess, _AssociateAvailabilityZonesResponseSuccess, _AssociateFirewallPolicyResponseSuccess, _AssociateSubnetsResponseSuccess, _AttachRuleGroupsToProxyConfigurationResponseSuccess, _CreateContainerAssociationResponseSuccess, _CreateFirewallPolicyResponseSuccess, _CreateFirewallResponseSuccess, _CreateProxyConfigurationResponseSuccess, _CreateProxyResponseSuccess, _CreateProxyRuleGroupResponseSuccess, _CreateProxyRulesResponseSuccess, _CreateRuleGroupResponseSuccess, _CreateTLSInspectionConfigurationResponseSuccess, _CreateVpcEndpointAssociationResponseSuccess, _DeleteContainerAssociationResponseSuccess, _DeleteFirewallPolicyResponseSuccess, _DeleteFirewallResponseSuccess, _DeleteNetworkFirewallTransitGatewayAttachmentResponseSuccess, _DeleteProxyConfigurationResponseSuccess, _DeleteProxyResponseSuccess, _DeleteProxyRuleGroupResponseSuccess, _DeleteProxyRulesResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DeleteRuleGroupResponseSuccess, _DeleteTLSInspectionConfigurationResponseSuccess, _DeleteVpcEndpointAssociationResponseSuccess, _DescribeContainerAssociationResponseSuccess, _DescribeFirewallMetadataResponseSuccess, _DescribeFirewallPolicyResponseSuccess, _DescribeFirewallResponseSuccess, _DescribeFlowOperationResponseSuccess, _DescribeLoggingConfigurationResponseSuccess, _DescribeProxyConfigurationResponseSuccess, _DescribeProxyResponseSuccess, _DescribeProxyRuleGroupResponseSuccess, _DescribeProxyRuleResponseSuccess, _DescribeResourcePolicyResponseSuccess, _DescribeRuleGroupMetadataResponseSuccess, _DescribeRuleGroupResponseSuccess, _DescribeRuleGroupSummaryResponseSuccess, _DescribeTLSInspectionConfigurationResponseSuccess, _DescribeVpcEndpointAssociationResponseSuccess, _DetachRuleGroupsFromProxyConfigurationResponseSuccess, _DisassociateAvailabilityZonesResponseSuccess, _DisassociateSubnetsResponseSuccess, _GetAnalysisReportResultsResponseSuccess, _ListAnalysisReportsResponseSuccess, _ListContainerAssociationsResponseSuccess, _ListFirewallPoliciesResponseSuccess, _ListFirewallsResponseSuccess, _ListFlowOperationResultsResponseSuccess, _ListFlowOperationsResponseSuccess, _ListProxiesResponseSuccess, _ListProxyConfigurationsResponseSuccess, _ListProxyRuleGroupsResponseSuccess, _ListRuleGroupsResponseSuccess, _ListTLSInspectionConfigurationsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVpcEndpointAssociationsResponseSuccess, _PutResourcePolicyResponseSuccess, _RejectNetworkFirewallTransitGatewayAttachmentResponseSuccess, _StartAnalysisReportResponseSuccess, _StartFlowCaptureResponseSuccess, _StartFlowFlushResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAvailabilityZoneChangeProtectionResponseSuccess, _UpdateContainerAssociationResponseSuccess, _UpdateFirewallAnalysisSettingsResponseSuccess, _UpdateFirewallDeleteProtectionResponseSuccess, _UpdateFirewallDescriptionResponseSuccess, _UpdateFirewallEncryptionConfigurationResponseSuccess, _UpdateFirewallPolicyChangeProtectionResponseSuccess, _UpdateFirewallPolicyResponseSuccess, _UpdateLoggingConfigurationResponseSuccess, _UpdateProxyConfigurationResponseSuccess, _UpdateProxyResponseSuccess, _UpdateProxyRuleGroupPrioritiesResponseSuccess, _UpdateProxyRulePrioritiesResponseSuccess, _UpdateProxyRuleResponseSuccess, _UpdateRuleGroupResponseSuccess, _UpdateSubnetChangeProtectionResponseSuccess, _UpdateTLSInspectionConfigurationResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#accept_network_firewall_transit_gateway_attachment(params = {}) ⇒ Types::AcceptNetworkFirewallTransitGatewayAttachmentResponse
Accepts a transit gateway attachment request for Network Firewall.
-
#associate_availability_zones(params = {}) ⇒ Types::AssociateAvailabilityZonesResponse
Associates the specified Availability Zones with a transit gateway-attached firewall.
-
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
-
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall.
-
#attach_rule_groups_to_proxy_configuration(params = {}) ⇒ Types::AttachRuleGroupsToProxyConfigurationResponse
Attaches ProxyRuleGroup resources to a ProxyConfiguration.
-
#create_container_association(params = {}) ⇒ Types::CreateContainerAssociationResponse
Creates a container association for Network Firewall.
-
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
-
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
-
#create_proxy(params = {}) ⇒ Types::CreateProxyResponse
Creates an Network Firewall Proxy.
-
#create_proxy_configuration(params = {}) ⇒ Types::CreateProxyConfigurationResponse
Creates an Network Firewall ProxyConfiguration.
-
#create_proxy_rule_group(params = {}) ⇒ Types::CreateProxyRuleGroupResponse
Creates an Network Firewall ProxyRuleGroup.
-
#create_proxy_rules(params = {}) ⇒ Types::CreateProxyRulesResponse
Creates Network Firewall ProxyRule resources.
-
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
-
#create_tls_inspection_configuration(params = {}) ⇒ Types::CreateTLSInspectionConfigurationResponse
Creates an Network Firewall TLS inspection configuration.
-
#create_vpc_endpoint_association(params = {}) ⇒ Types::CreateVpcEndpointAssociationResponse
Creates a firewall endpoint for an Network Firewall firewall.
-
#delete_container_association(params = {}) ⇒ Types::DeleteContainerAssociationResponse
Deletes the specified container association.
-
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus.
-
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
-
#delete_network_firewall_transit_gateway_attachment(params = {}) ⇒ Types::DeleteNetworkFirewallTransitGatewayAttachmentResponse
Deletes a transit gateway attachment from a Network Firewall.
-
#delete_proxy(params = {}) ⇒ Types::DeleteProxyResponse
Deletes the specified Proxy.
-
#delete_proxy_configuration(params = {}) ⇒ Types::DeleteProxyConfigurationResponse
Deletes the specified ProxyConfiguration.
-
#delete_proxy_rule_group(params = {}) ⇒ Types::DeleteProxyRuleGroupResponse
Deletes the specified ProxyRuleGroup.
-
#delete_proxy_rules(params = {}) ⇒ Types::DeleteProxyRulesResponse
Deletes the specified ProxyRule(s).
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
-
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
-
#delete_tls_inspection_configuration(params = {}) ⇒ Types::DeleteTLSInspectionConfigurationResponse
Deletes the specified TLSInspectionConfiguration.
-
#delete_vpc_endpoint_association(params = {}) ⇒ Types::DeleteVpcEndpointAssociationResponse
Deletes the specified VpcEndpointAssociation.
-
#describe_container_association(params = {}) ⇒ Types::DescribeContainerAssociationResponse
Returns the properties of a container association.
-
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
-
#describe_firewall_metadata(params = {}) ⇒ Types::DescribeFirewallMetadataResponse
Returns the high-level information about a firewall, including the Availability Zones where the Firewall is currently in use.
-
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
-
#describe_flow_operation(params = {}) ⇒ Types::DescribeFlowOperationResponse
Returns key information about a specific flow operation.
-
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
-
#describe_proxy(params = {}) ⇒ Types::DescribeProxyResponse
Returns the data objects for the specified proxy.
-
#describe_proxy_configuration(params = {}) ⇒ Types::DescribeProxyConfigurationResponse
Returns the data objects for the specified proxy configuration.
-
#describe_proxy_rule(params = {}) ⇒ Types::DescribeProxyRuleResponse
Returns the data objects for the specified proxy configuration for the specified proxy rule group.
-
#describe_proxy_rule_group(params = {}) ⇒ Types::DescribeProxyRuleGroupResponse
Returns the data objects for the specified proxy rule group.
-
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
-
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
-
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe.
-
#describe_rule_group_summary(params = {}) ⇒ Types::DescribeRuleGroupSummaryResponse
Returns detailed information for a stateful rule group.
-
#describe_tls_inspection_configuration(params = {}) ⇒ Types::DescribeTLSInspectionConfigurationResponse
Returns the data objects for the specified TLS inspection configuration.
-
#describe_vpc_endpoint_association(params = {}) ⇒ Types::DescribeVpcEndpointAssociationResponse
Returns the data object for the specified VPC endpoint association.
-
#detach_rule_groups_from_proxy_configuration(params = {}) ⇒ Types::DetachRuleGroupsFromProxyConfigurationResponse
Detaches ProxyRuleGroup resources from a ProxyConfiguration.
-
#disassociate_availability_zones(params = {}) ⇒ Types::DisassociateAvailabilityZonesResponse
Removes the specified Availability Zone associations from a transit gateway-attached firewall.
-
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall.
-
#get_analysis_report_results(params = {}) ⇒ Types::GetAnalysisReportResultsResponse
The results of a
COMPLETEDanalysis report generated with StartAnalysisReport. -
#list_analysis_reports(params = {}) ⇒ Types::ListAnalysisReportsResponse
Returns a list of all traffic analysis reports generated within the last 30 days.
-
#list_container_associations(params = {}) ⇒ Types::ListContainerAssociationsResponse
Retrieves the metadata for the container associations that you have defined.
-
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined.
-
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined.
-
#list_flow_operation_results(params = {}) ⇒ Types::ListFlowOperationResultsResponse
Returns the results of a specific flow operation.
-
#list_flow_operations(params = {}) ⇒ Types::ListFlowOperationsResponse
Returns a list of all flow operations ran in a specific firewall.
-
#list_proxies(params = {}) ⇒ Types::ListProxiesResponse
Retrieves the metadata for the proxies that you have defined.
-
#list_proxy_configurations(params = {}) ⇒ Types::ListProxyConfigurationsResponse
Retrieves the metadata for the proxy configuration that you have defined.
-
#list_proxy_rule_groups(params = {}) ⇒ Types::ListProxyRuleGroupsResponse
Retrieves the metadata for the proxy rule groups that you have defined.
-
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource.
-
#list_tls_inspection_configurations(params = {}) ⇒ Types::ListTLSInspectionConfigurationsResponse
Retrieves the metadata for the TLS inspection configurations that you have defined.
-
#list_vpc_endpoint_associations(params = {}) ⇒ Types::ListVpcEndpointAssociationsResponse
Retrieves the metadata for the VPC endpoint associations that you have defined.
-
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group, firewall policy, or firewall.
-
#reject_network_firewall_transit_gateway_attachment(params = {}) ⇒ Types::RejectNetworkFirewallTransitGatewayAttachmentResponse
Rejects a transit gateway attachment request for Network Firewall.
-
#start_analysis_report(params = {}) ⇒ Types::StartAnalysisReportResponse
Generates a traffic analysis report for the timeframe and traffic type you specify.
-
#start_flow_capture(params = {}) ⇒ Types::StartFlowCaptureResponse
Begins capturing the flows in a firewall, according to the filters you define.
-
#start_flow_flush(params = {}) ⇒ Types::StartFlowFlushResponse
Begins the flushing of traffic from the firewall, according to the filters you define.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource.
-
#update_availability_zone_change_protection(params = {}) ⇒ Types::UpdateAvailabilityZoneChangeProtectionResponse
Modifies the
AvailabilityZoneChangeProtectionsetting for a transit gateway-attached firewall. -
#update_container_association(params = {}) ⇒ Types::UpdateContainerAssociationResponse
Updates the properties of an existing container association.
-
#update_firewall_analysis_settings(params = {}) ⇒ Types::UpdateFirewallAnalysisSettingsResponse
Enables specific types of firewall analysis on a specific firewall you define.
-
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag,
DeleteProtection, which indicates whether it is possible to delete the firewall. -
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall.
-
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
-
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
-
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag,
ChangeProtection, which indicates whether it is possible to change the firewall. -
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
-
#update_proxy(params = {}) ⇒ Types::UpdateProxyResponse
Updates the properties of the specified proxy.
-
#update_proxy_configuration(params = {}) ⇒ Types::UpdateProxyConfigurationResponse
Updates the properties of the specified proxy configuration.
-
#update_proxy_rule(params = {}) ⇒ Types::UpdateProxyRuleResponse
Updates the properties of the specified proxy rule.
-
#update_proxy_rule_group_priorities(params = {}) ⇒ Types::UpdateProxyRuleGroupPrioritiesResponse
Updates proxy rule group priorities within a proxy configuration.
-
#update_proxy_rule_priorities(params = {}) ⇒ Types::UpdateProxyRulePrioritiesResponse
Updates proxy rule priorities within a proxy rule group.
-
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group.
-
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:.
-
#update_tls_inspection_configuration(params = {}) ⇒ Types::UpdateTLSInspectionConfigurationResponse
Updates the TLS inspection configuration settings for the specified TLS inspection configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7278 7279 7280 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 7278 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7281 7282 7283 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 7281 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#accept_network_firewall_transit_gateway_attachment(params = {}) ⇒ Types::AcceptNetworkFirewallTransitGatewayAttachmentResponse
Accepts a transit gateway attachment request for Network Firewall. When you accept the attachment request, Network Firewall creates the necessary routing components to enable traffic flow between the transit gateway and firewall endpoints.
You must accept a transit gateway attachment to complete the creation of a transit gateway-attached firewall, unless auto-accept is enabled on the transit gateway. After acceptance, use DescribeFirewall to verify the firewall status.
To reject an attachment instead of accepting it, use RejectNetworkFirewallTransitGatewayAttachment.
88 |
# File 'sig/client.rbs', line 88
def accept_network_firewall_transit_gateway_attachment: (
|
#associate_availability_zones(params = {}) ⇒ Types::AssociateAvailabilityZonesResponse
Associates the specified Availability Zones with a transit gateway-attached firewall. For each Availability Zone, Network Firewall creates a firewall endpoint to process traffic. You can specify one or more Availability Zones where you want to deploy the firewall.
After adding Availability Zones, you must update your transit gateway route tables to direct traffic through the new firewall endpoints. Use DescribeFirewall to monitor the status of the new endpoints.
101 |
# File 'sig/client.rbs', line 101
def associate_availability_zones: (
|
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
A firewall policy defines how to monitor and manage your VPC network traffic, using a collection of inspection rule groups and other settings. Each firewall requires one firewall policy association, and you can use the same firewall policy for multiple firewalls.
121 |
# File 'sig/client.rbs', line 121
def associate_firewall_policy: (
|
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall. You can specify one subnet for each of the Availability Zones that the VPC spans.
This request creates an Network Firewall firewall endpoint in each of the subnets. To enable the firewall's protections, you must also modify the VPC's route tables for each subnet's Availability Zone, to redirect the traffic that's coming into and going out of the zone through the firewall endpoint.
137 |
# File 'sig/client.rbs', line 137
def associate_subnets: (
|
#attach_rule_groups_to_proxy_configuration(params = {}) ⇒ Types::AttachRuleGroupsToProxyConfigurationResponse
Attaches ProxyRuleGroup resources to a ProxyConfiguration
A Proxy Configuration defines the monitoring and protection behavior for a Proxy. The details of the behavior are defined in the rule groups that you add to your configuration.
156 |
# File 'sig/client.rbs', line 156
def attach_rule_groups_to_proxy_configuration: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7251 7252 7253 7254 7255 7256 7257 7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 7251 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NetworkFirewall') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-networkfirewall' context[:gem_version] = '1.94.0' Seahorse::Client::Request.new(handlers, context) end |
#create_container_association(params = {}) ⇒ Types::CreateContainerAssociationResponse
Creates a container association for Network Firewall. A container association links container clusters (ECS or EKS) to Network Firewall, enabling dynamic IP resolution for firewall rules based on container attributes.
To manage a container association's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about container associations, use ListContainerAssociations and DescribeContainerAssociation.
181 |
# File 'sig/client.rbs', line 181
def create_container_association: (
|
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
The firewall defines the configuration settings for an Network Firewall firewall. The settings that you can define at creation include the firewall policy, the subnets in your VPC to use for the firewall endpoints, and any tags that are attached to the firewall Amazon Web Services resource.
After you create a firewall, you can provide additional settings, like the logging configuration.
To update the settings for a firewall, you use the operations that apply to the settings themselves, for example UpdateLoggingConfiguration, AssociateSubnets, and UpdateFirewallDeleteProtection.
To manage a firewall's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about firewalls, use ListFirewalls and DescribeFirewall.
To generate a report on the last 30 days of traffic monitored by a firewall, use StartAnalysisReport.
211 |
# File 'sig/client.rbs', line 211
def create_firewall: (
|
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
An Network Firewall firewall policy defines the behavior of a firewall, in a collection of stateless and stateful rule groups and other settings. You can use one firewall policy for multiple firewalls.
252 |
# File 'sig/client.rbs', line 252
def create_firewall_policy: (
|
#create_proxy(params = {}) ⇒ Types::CreateProxyResponse
Creates an Network Firewall Proxy
Attaches a Proxy configuration to a NAT Gateway.
To manage a proxy's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about proxies, use ListProxies and DescribeProxy.
276 |
# File 'sig/client.rbs', line 276
def create_proxy: (
|
#create_proxy_configuration(params = {}) ⇒ Types::CreateProxyConfigurationResponse
Creates an Network Firewall ProxyConfiguration
A Proxy Configuration defines the monitoring and protection behavior for a Proxy. The details of the behavior are defined in the rule groups that you add to your configuration.
To manage a proxy configuration's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about proxies, use ListProxyConfigurations and DescribeProxyConfiguration.
306 |
# File 'sig/client.rbs', line 306
def create_proxy_configuration: (
|
#create_proxy_rule_group(params = {}) ⇒ Types::CreateProxyRuleGroupResponse
Creates an Network Firewall ProxyRuleGroup
Collections of related proxy filtering rules. Rule groups help you manage and reuse sets of rules across multiple proxy configurations.
To manage a proxy rule group's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about proxy rule groups, use ListProxyRuleGroups and DescribeProxyRuleGroup.
To retrieve information about individual proxy rules, use DescribeProxyRuleGroup and DescribeProxyRule.
331 |
# File 'sig/client.rbs', line 331
def create_proxy_rule_group: (
|
#create_proxy_rules(params = {}) ⇒ Types::CreateProxyRulesResponse
Creates Network Firewall ProxyRule resources.
Attaches new proxy rule(s) to an existing proxy rule group.
To retrieve information about individual proxy rules, use DescribeProxyRuleGroup and DescribeProxyRule.
360 |
# File 'sig/client.rbs', line 360
def create_proxy_rules: (
|
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
You provide your rule group specification in your request using either
RuleGroup or Rules.
383 |
# File 'sig/client.rbs', line 383
def create_rule_group: (
|
#create_tls_inspection_configuration(params = {}) ⇒ Types::CreateTLSInspectionConfigurationResponse
Creates an Network Firewall TLS inspection configuration. Network Firewall uses TLS inspection configurations to decrypt your firewall's inbound and outbound SSL/TLS traffic. After decryption, Network Firewall inspects the traffic according to your firewall policy's stateful rules, and then re-encrypts it before sending it to its destination. You can enable inspection of your firewall's inbound traffic, outbound traffic, or both. To use TLS inspection with your firewall, you must first import or provision certificates using ACM, create a TLS inspection configuration, add that configuration to a new firewall policy, and then associate that policy with your firewall.
To update the settings for a TLS inspection configuration, use UpdateTLSInspectionConfiguration.
To manage a TLS inspection configuration's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about TLS inspection configurations, use ListTLSInspectionConfigurations and DescribeTLSInspectionConfiguration.
For more information about TLS inspection configurations, see Inspecting SSL/TLS traffic with TLS inspection configurations in the Network Firewall Developer Guide.
418 |
# File 'sig/client.rbs', line 418
def create_tls_inspection_configuration: (
|
#create_vpc_endpoint_association(params = {}) ⇒ Types::CreateVpcEndpointAssociationResponse
Creates a firewall endpoint for an Network Firewall firewall. This
type of firewall endpoint is independent of the firewall endpoints
that you specify in the Firewall itself, and you define it in
addition to those endpoints after the firewall has been created. You
can define a VPC endpoint association using a different VPC than the
one you used in the firewall specifications.
441 |
# File 'sig/client.rbs', line 441
def create_vpc_endpoint_association: (
|
#delete_container_association(params = {}) ⇒ Types::DeleteContainerAssociationResponse
Deletes the specified container association. When you delete a container association, Network Firewall stops monitoring the associated container clusters and removes the resolved IP addresses from firewall rules.
465 |
# File 'sig/client.rbs', line 465
def delete_container_association: (
|
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus. This operation
requires the firewall's DeleteProtection flag to be FALSE. You
can't revert this operation.
You can check whether a firewall is in use by reviewing the route tables for the Availability Zones where you have firewall subnet mappings. Retrieve the subnet mappings by calling DescribeFirewall. You define and update the route tables through Amazon VPC. As needed, update the route tables for the zones to remove the firewall endpoints. When the route tables no longer use the firewall endpoints, you can remove the firewall safely.
To delete a firewall, remove the delete protection if you need to using UpdateFirewallDeleteProtection, then delete the firewall by calling DeleteFirewall.
477 |
# File 'sig/client.rbs', line 477
def delete_firewall: (
|
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
488 |
# File 'sig/client.rbs', line 488
def delete_firewall_policy: (
|
#delete_network_firewall_transit_gateway_attachment(params = {}) ⇒ Types::DeleteNetworkFirewallTransitGatewayAttachmentResponse
Deletes a transit gateway attachment from a Network Firewall. Either the firewall owner or the transit gateway owner can delete the attachment.
After you delete a transit gateway attachment, traffic will no longer flow through the firewall endpoints.
After you initiate the delete operation, use DescribeFirewall to monitor the deletion status.
500 |
# File 'sig/client.rbs', line 500
def delete_network_firewall_transit_gateway_attachment: (
|
#delete_proxy(params = {}) ⇒ Types::DeleteProxyResponse
Deletes the specified Proxy.
Detaches a Proxy configuration from a NAT Gateway.
512 |
# File 'sig/client.rbs', line 512
def delete_proxy: (
|
#delete_proxy_configuration(params = {}) ⇒ Types::DeleteProxyConfigurationResponse
Deletes the specified ProxyConfiguration.
525 |
# File 'sig/client.rbs', line 525
def delete_proxy_configuration: (
|
#delete_proxy_rule_group(params = {}) ⇒ Types::DeleteProxyRuleGroupResponse
Deletes the specified ProxyRuleGroup.
537 |
# File 'sig/client.rbs', line 537
def delete_proxy_rule_group: (
|
#delete_proxy_rules(params = {}) ⇒ Types::DeleteProxyRulesResponse
Deletes the specified ProxyRule(s). currently attached to a ProxyRuleGroup
548 |
# File 'sig/client.rbs', line 548
def delete_proxy_rules: (
|
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
559 |
# File 'sig/client.rbs', line 559
def delete_resource_policy: (
|
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
569 |
# File 'sig/client.rbs', line 569
def delete_rule_group: (
|
#delete_tls_inspection_configuration(params = {}) ⇒ Types::DeleteTLSInspectionConfigurationResponse
Deletes the specified TLSInspectionConfiguration.
581 |
# File 'sig/client.rbs', line 581
def delete_tls_inspection_configuration: (
|
#delete_vpc_endpoint_association(params = {}) ⇒ Types::DeleteVpcEndpointAssociationResponse
Deletes the specified VpcEndpointAssociation.
You can check whether an endpoint association is in use by reviewing the route tables for the Availability Zones where you have the endpoint subnet mapping. You can retrieve the subnet mapping by calling DescribeVpcEndpointAssociation. You define and update the route tables through Amazon VPC. As needed, update the route tables for the Availability Zone to remove the firewall endpoint for the association. When the route tables no longer use the firewall endpoint, you can remove the endpoint association safely.
593 |
# File 'sig/client.rbs', line 593
def delete_vpc_endpoint_association: (
|
#describe_container_association(params = {}) ⇒ Types::DescribeContainerAssociationResponse
Returns the properties of a container association.
612 |
# File 'sig/client.rbs', line 612
def describe_container_association: (
|
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
625 |
# File 'sig/client.rbs', line 625
def describe_firewall: (
|
#describe_firewall_metadata(params = {}) ⇒ Types::DescribeFirewallMetadataResponse
Returns the high-level information about a firewall, including the Availability Zones where the Firewall is currently in use.
641 |
# File 'sig/client.rbs', line 641
def describe_firewall_metadata: (
|
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
653 |
# File 'sig/client.rbs', line 653
def describe_firewall_policy: (
|
#describe_flow_operation(params = {}) ⇒ Types::DescribeFlowOperationResponse
Returns key information about a specific flow operation.
673 |
# File 'sig/client.rbs', line 673
def describe_flow_operation: (
|
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
689 |
# File 'sig/client.rbs', line 689
def describe_logging_configuration: (
|
#describe_proxy(params = {}) ⇒ Types::DescribeProxyResponse
Returns the data objects for the specified proxy.
701 |
# File 'sig/client.rbs', line 701
def describe_proxy: (
|
#describe_proxy_configuration(params = {}) ⇒ Types::DescribeProxyConfigurationResponse
Returns the data objects for the specified proxy configuration.
713 |
# File 'sig/client.rbs', line 713
def describe_proxy_configuration: (
|
#describe_proxy_rule(params = {}) ⇒ Types::DescribeProxyRuleResponse
Returns the data objects for the specified proxy configuration for the specified proxy rule group.
725 |
# File 'sig/client.rbs', line 725
def describe_proxy_rule: (
|
#describe_proxy_rule_group(params = {}) ⇒ Types::DescribeProxyRuleGroupResponse
Returns the data objects for the specified proxy rule group.
738 |
# File 'sig/client.rbs', line 738
def describe_proxy_rule_group: (
|
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
749 |
# File 'sig/client.rbs', line 749
def describe_resource_policy: (
|
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
761 |
# File 'sig/client.rbs', line 761
def describe_rule_group: (
|
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe. You can use the information provided in the metadata to retrieve and manage a rule group. You can retrieve all objects for a rule group by calling DescribeRuleGroup.
783 |
# File 'sig/client.rbs', line 783
def describe_rule_group_metadata: (
|
#describe_rule_group_summary(params = {}) ⇒ Types::DescribeRuleGroupSummaryResponse
Returns detailed information for a stateful rule group.
For active threat defense Amazon Web Services managed rule groups, this operation provides insight into the protections enabled by the rule group, based on Suricata rule metadata fields. Summaries are available for rule groups you manage and for active threat defense Amazon Web Services managed rule groups.
To modify how threat information appears in summaries, use the
SummaryConfiguration parameter in UpdateRuleGroup.
797 |
# File 'sig/client.rbs', line 797
def describe_rule_group_summary: (
|
#describe_tls_inspection_configuration(params = {}) ⇒ Types::DescribeTLSInspectionConfigurationResponse
Returns the data objects for the specified TLS inspection configuration.
811 |
# File 'sig/client.rbs', line 811
def describe_tls_inspection_configuration: (
|
#describe_vpc_endpoint_association(params = {}) ⇒ Types::DescribeVpcEndpointAssociationResponse
Returns the data object for the specified VPC endpoint association.
823 |
# File 'sig/client.rbs', line 823
def describe_vpc_endpoint_association: (
|
#detach_rule_groups_from_proxy_configuration(params = {}) ⇒ Types::DetachRuleGroupsFromProxyConfigurationResponse
Detaches ProxyRuleGroup resources from a ProxyConfiguration
A Proxy Configuration defines the monitoring and protection behavior for a Proxy. The details of the behavior are defined in the rule groups that you add to your configuration.
834 |
# File 'sig/client.rbs', line 834
def detach_rule_groups_from_proxy_configuration: (
|
#disassociate_availability_zones(params = {}) ⇒ Types::DisassociateAvailabilityZonesResponse
Removes the specified Availability Zone associations from a transit gateway-attached firewall. This removes the firewall endpoints from these Availability Zones and stops traffic filtering in those zones. Before removing an Availability Zone, ensure you've updated your transit gateway route tables to redirect traffic appropriately.
AvailabilityZoneChangeProtection is enabled, you must first
disable it using UpdateAvailabilityZoneChangeProtection.
To verify the status of your Availability Zone changes, use DescribeFirewall.
851 |
# File 'sig/client.rbs', line 851
def disassociate_availability_zones: (
|
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall. This removes the firewall endpoints from the subnets and removes any network filtering protections that the endpoints were providing.
871 |
# File 'sig/client.rbs', line 871
def disassociate_subnets: (
|
#get_analysis_report_results(params = {}) ⇒ Types::GetAnalysisReportResultsResponse
The results of a COMPLETED analysis report generated with
StartAnalysisReport.
For more information, see AnalysisTypeReportResult.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
890 |
# File 'sig/client.rbs', line 890
def get_analysis_report_results: (
|
#list_analysis_reports(params = {}) ⇒ Types::ListAnalysisReportsResponse
Returns a list of all traffic analysis reports generated within the last 30 days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
905 |
# File 'sig/client.rbs', line 905
def list_analysis_reports: (
|
#list_container_associations(params = {}) ⇒ Types::ListContainerAssociationsResponse
Retrieves the metadata for the container associations that you have defined. You can optionally page through results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
919 |
# File 'sig/client.rbs', line 919
def list_container_associations: (
|
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined. Depending on your setting for max results and the number of firewall policies, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
931 |
# File 'sig/client.rbs', line 931
def list_firewall_policies: (
|
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined. If you provide VPC identifiers in your request, this returns only the firewalls for those VPCs.
Depending on your setting for max results and the number of firewalls, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
943 |
# File 'sig/client.rbs', line 943
def list_firewalls: (
|
#list_flow_operation_results(params = {}) ⇒ Types::ListFlowOperationResultsResponse
Returns the results of a specific flow operation.
Flow operations let you manage the flows tracked in the flow table, also known as the firewall table.
A flow is network traffic that is monitored by a firewall, either by stateful or stateless rules. For traffic to be considered part of a flow, it must share Destination, DestinationPort, Direction, Protocol, Source, and SourcePort.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
964 |
# File 'sig/client.rbs', line 964
def list_flow_operation_results: (
|
#list_flow_operations(params = {}) ⇒ Types::ListFlowOperationsResponse
Returns a list of all flow operations ran in a specific firewall. You can optionally narrow the request scope by specifying the operation type or Availability Zone associated with a firewall's flow operations.
Flow operations let you manage the flows tracked in the flow table, also known as the firewall table.
A flow is network traffic that is monitored by a firewall, either by stateful or stateless rules. For traffic to be considered part of a flow, it must share Destination, DestinationPort, Direction, Protocol, Source, and SourcePort.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
981 |
# File 'sig/client.rbs', line 981
def list_flow_operations: (
|
#list_proxies(params = {}) ⇒ Types::ListProxiesResponse
Retrieves the metadata for the proxies that you have defined. Depending on your setting for max results and the number of proxies, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
998 |
# File 'sig/client.rbs', line 998
def list_proxies: (
|
#list_proxy_configurations(params = {}) ⇒ Types::ListProxyConfigurationsResponse
Retrieves the metadata for the proxy configuration that you have defined. Depending on your setting for max results and the number of proxy configurations, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1010 |
# File 'sig/client.rbs', line 1010
def list_proxy_configurations: (
|
#list_proxy_rule_groups(params = {}) ⇒ Types::ListProxyRuleGroupsResponse
Retrieves the metadata for the proxy rule groups that you have defined. Depending on your setting for max results and the number of proxy rule groups, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1022 |
# File 'sig/client.rbs', line 1022
def list_proxy_rule_groups: (
|
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined. Depending on your setting for max results and the number of rule groups, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1034 |
# File 'sig/client.rbs', line 1034
def list_rule_groups: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1062 |
# File 'sig/client.rbs', line 1062
def list_tags_for_resource: (
|
#list_tls_inspection_configurations(params = {}) ⇒ Types::ListTLSInspectionConfigurationsResponse
Retrieves the metadata for the TLS inspection configurations that you have defined. Depending on your setting for max results and the number of TLS inspection configurations, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1050 |
# File 'sig/client.rbs', line 1050
def list_tls_inspection_configurations: (
|
#list_vpc_endpoint_associations(params = {}) ⇒ Types::ListVpcEndpointAssociationsResponse
Retrieves the metadata for the VPC endpoint associations that you have defined. If you specify a fireawll, this returns only the endpoint associations for that firewall.
Depending on your setting for max results and the number of associations, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1075 |
# File 'sig/client.rbs', line 1075
def list_vpc_endpoint_associations: (
|
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group, firewall policy, or firewall. Use this to share these resources between accounts. This operation works in conjunction with the Amazon Web Services Resource Access Manager (RAM) service to manage resource sharing for Network Firewall.
For information about using sharing with Network Firewall resources, see Sharing Network Firewall resources in the Network Firewall Developer Guide.
Use this operation to create or update a resource policy for your Network Firewall rule group, firewall policy, or firewall. In the resource policy, you specify the accounts that you want to share the Network Firewall resource with and the operations that you want the accounts to be able to perform.
When you add an account in the resource policy, you then run the following Resource Access Manager (RAM) operations to access and accept the shared resource.
-
GetResourceShareInvitations - Returns the Amazon Resource Names (ARNs) of the resource share invitations.
-
AcceptResourceShareInvitation - Accepts the share invitation for a specified resource share.
For additional information about resource sharing using RAM, see Resource Access Manager User Guide.
1086 |
# File 'sig/client.rbs', line 1086
def put_resource_policy: (
|
#reject_network_firewall_transit_gateway_attachment(params = {}) ⇒ Types::RejectNetworkFirewallTransitGatewayAttachmentResponse
Rejects a transit gateway attachment request for Network Firewall. When you reject the attachment request, Network Firewall cancels the creation of routing components between the transit gateway and firewall endpoints.
Only the transit gateway owner can reject the attachment. After rejection, no traffic will flow through the firewall endpoints for this attachment.
Use DescribeFirewall to monitor the rejection status. To accept the attachment instead of rejecting it, use AcceptNetworkFirewallTransitGatewayAttachment.
1098 |
# File 'sig/client.rbs', line 1098
def reject_network_firewall_transit_gateway_attachment: (
|
#start_analysis_report(params = {}) ⇒ Types::StartAnalysisReportResponse
Generates a traffic analysis report for the timeframe and traffic type you specify.
For information on the contents of a traffic analysis report, see AnalysisReport.
1108 |
# File 'sig/client.rbs', line 1108
def start_analysis_report: (
|
#start_flow_capture(params = {}) ⇒ Types::StartFlowCaptureResponse
Begins capturing the flows in a firewall, according to the filters you define. Captures are similar, but not identical to snapshots. Capture operations provide visibility into flows that are not closed and are tracked by a firewall's flow table. Unlike snapshots, captures are a time-boxed view.
A flow is network traffic that is monitored by a firewall, either by stateful or stateless rules. For traffic to be considered part of a flow, it must share Destination, DestinationPort, Direction, Protocol, Source, and SourcePort.
FlowFilters, like
narrow IP ranges, ports, or protocols.
1122 |
# File 'sig/client.rbs', line 1122
def start_flow_capture: (
|
#start_flow_flush(params = {}) ⇒ Types::StartFlowFlushResponse
Begins the flushing of traffic from the firewall, according to the filters you define. When the operation starts, impacted flows are temporarily marked as timed out before the Suricata engine prunes, or flushes, the flows from the firewall table.
While the flush completes, impacted flows are processed as midstream traffic. This may result in a temporary increase in midstream traffic metrics. We recommend that you double check your stream exception policy before you perform a flush operation.
1141 |
# File 'sig/client.rbs', line 1141
def start_flow_flush: (
|
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
1157 |
# File 'sig/client.rbs', line 1157
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can manage tags for the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
1172 |
# File 'sig/client.rbs', line 1172
def untag_resource: (
|
#update_availability_zone_change_protection(params = {}) ⇒ Types::UpdateAvailabilityZoneChangeProtectionResponse
Modifies the AvailabilityZoneChangeProtection setting for a transit
gateway-attached firewall. When enabled, this setting prevents
accidental changes to the firewall's Availability Zone configuration.
This helps protect against disrupting traffic flow in production
environments.
When enabled, you must disable this protection before using AssociateAvailabilityZones or DisassociateAvailabilityZones to modify the firewall's Availability Zone configuration.
1186 |
# File 'sig/client.rbs', line 1186
def update_availability_zone_change_protection: (
|
#update_container_association(params = {}) ⇒ Types::UpdateContainerAssociationResponse
Updates the properties of an existing container association. Use this to modify the container monitoring configurations or description.
1206 |
# File 'sig/client.rbs', line 1206
def update_container_association: (
|
#update_firewall_analysis_settings(params = {}) ⇒ Types::UpdateFirewallAnalysisSettingsResponse
Enables specific types of firewall analysis on a specific firewall you define.
1240 |
# File 'sig/client.rbs', line 1240
def update_firewall_analysis_settings: (
|
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag, DeleteProtection, which indicates whether it is
possible to delete the firewall. If the flag is set to TRUE, the
firewall is protected against deletion. This setting helps protect
against accidentally deleting a firewall that's in use.
1256 |
# File 'sig/client.rbs', line 1256
def update_firewall_delete_protection: (
|
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall. Use the description to help you identify the firewall when you're working with it.
1272 |
# File 'sig/client.rbs', line 1272
def update_firewall_description: (
|
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
1288 |
# File 'sig/client.rbs', line 1288
def update_firewall_encryption_configuration: (
|
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
1305 |
# File 'sig/client.rbs', line 1305
def update_firewall_policy: (
|
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag, ChangeProtection, which indicates whether it is
possible to change the firewall. If the flag is set to TRUE, the
firewall is protected from changes. This setting helps protect against
accidentally changing a firewall that's in use.
1327 |
# File 'sig/client.rbs', line 1327
def update_firewall_policy_change_protection: (
|
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
To change the logging configuration, retrieve the LoggingConfiguration by calling DescribeLoggingConfiguration, then change it and provide the modified object to this update call. You must change the logging configuration one LogDestinationConfig at a time inside the retrieved LoggingConfiguration object.
You can perform only one of the following actions in any call to
UpdateLoggingConfiguration:
-
Create a new log destination object by adding a single
LogDestinationConfigarray element toLogDestinationConfigs. -
Delete a log destination object by removing a single
LogDestinationConfigarray element fromLogDestinationConfigs. -
Change the
LogDestinationsetting in a singleLogDestinationConfigarray element.
You can't change the LogDestinationType or LogType in a
LogDestinationConfig. To change these settings, delete the existing
LogDestinationConfig object and create a new one, using two separate
calls to this update operation.
1343 |
# File 'sig/client.rbs', line 1343
def update_logging_configuration: (
|
#update_proxy(params = {}) ⇒ Types::UpdateProxyResponse
Updates the properties of the specified proxy.
1365 |
# File 'sig/client.rbs', line 1365
def update_proxy: (
|
#update_proxy_configuration(params = {}) ⇒ Types::UpdateProxyConfigurationResponse
Updates the properties of the specified proxy configuration.
1395 |
# File 'sig/client.rbs', line 1395
def update_proxy_configuration: (
|
#update_proxy_rule(params = {}) ⇒ Types::UpdateProxyRuleResponse
Updates the properties of the specified proxy rule.
1414 |
# File 'sig/client.rbs', line 1414
def update_proxy_rule: (
|
#update_proxy_rule_group_priorities(params = {}) ⇒ Types::UpdateProxyRuleGroupPrioritiesResponse
Updates proxy rule group priorities within a proxy configuration.
1444 |
# File 'sig/client.rbs', line 1444
def update_proxy_rule_group_priorities: (
|
#update_proxy_rule_priorities(params = {}) ⇒ Types::UpdateProxyRulePrioritiesResponse
Updates proxy rule priorities within a proxy rule group.
1466 |
# File 'sig/client.rbs', line 1466
def update_proxy_rule_priorities: (
|
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group. You use a rule group by reference in one or more firewall policies. When you modify a rule group, you modify all firewall policies that use the rule group.
To update a rule group, first call DescribeRuleGroup to retrieve the current RuleGroup object, update the object as needed, and then provide the updated object to this call.
1486 |
# File 'sig/client.rbs', line 1486
def update_rule_group: (
|
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:
- #update_token => String
- #firewall_arn => String
- #firewall_name => String
- #subnet_change_protection => Boolean
1518 |
# File 'sig/client.rbs', line 1518
def update_subnet_change_protection: (
|
#update_tls_inspection_configuration(params = {}) ⇒ Types::UpdateTLSInspectionConfigurationResponse
Updates the TLS inspection configuration settings for the specified TLS inspection configuration. You use a TLS inspection configuration by referencing it in one or more firewall policies. When you modify a TLS inspection configuration, you modify all firewall policies that use the TLS inspection configuration.
To update a TLS inspection configuration, first call DescribeTLSInspectionConfiguration to retrieve the current TLSInspectionConfiguration object, update the object as needed, and then provide the updated object to this call.
1532 |
# File 'sig/client.rbs', line 1532
def update_tls_inspection_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
7271 7272 7273 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 7271 def waiter_names [] end |