Class: Aws::NetworkFirewall::Types::ContainerAssociationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

The metadata for a container association returned by ListContainerAssociations. Contains the ARN and name that you use to identify the container association in other operations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the container association.

Returns:

  • (String)


875
876
877
878
879
880
# File 'lib/aws-sdk-networkfirewall/types.rb', line 875

class ContainerAssociationSummary < Struct.new(
  :arn,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The descriptive name of the container association.

Returns:

  • (String)


875
876
877
878
879
880
# File 'lib/aws-sdk-networkfirewall/types.rb', line 875

class ContainerAssociationSummary < Struct.new(
  :arn,
  :name)
  SENSITIVE = []
  include Aws::Structure
end