Class: Aws::NetworkFirewall::Types::CreateContainerAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_association_name ⇒ String

The descriptive name of the container association. You can't change the name of a container association after you create it.

Returns:

  • (String)


959
960
961
962
963
964
965
966
967
# File 'lib/aws-sdk-networkfirewall/types.rb', line 959

class CreateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#container_monitoring_configurations ⇒ Array<Types::ContainerMonitoringConfiguration>

The monitoring configurations for the container association. Each configuration specifies an Amazon ECS or Amazon EKS cluster to monitor and optional attribute filters to narrow which containers are tracked.



959
960
961
962
963
964
965
966
967
# File 'lib/aws-sdk-networkfirewall/types.rb', line 959

class CreateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the container association.

Returns:

  • (String)


959
960
961
962
963
964
965
966
967
# File 'lib/aws-sdk-networkfirewall/types.rb', line 959

class CreateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.

Returns:



959
960
961
962
963
964
965
966
967
# File 'lib/aws-sdk-networkfirewall/types.rb', line 959

class CreateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of containers to monitor. You can't change the container type after creation. Valid values:

  • ECS - Amazon Elastic Container Service

  • EKS - Amazon Elastic Kubernetes Service

Returns:

  • (String)


959
960
961
962
963
964
965
966
967
# File 'lib/aws-sdk-networkfirewall/types.rb', line 959

class CreateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end