Class: Aws::NetworkFirewall::Types::CreateFirewallPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::CreateFirewallPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the firewall policy.
-
#dry_run ⇒ Boolean
Indicates whether you want Network Firewall to just check the validity of the request, rather than run the request.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
A complex type that contains settings for encryption of your firewall policy resources.
-
#firewall_policy ⇒ Types::FirewallPolicy
The rule groups and policy actions to use in the firewall policy.
-
#firewall_policy_name ⇒ String
The descriptive name of the firewall policy.
-
#tags ⇒ Array<Types::Tag>
The key:value pairs to associate with the resource.
Instance Attribute Details
#description ⇒ String
A description of the firewall policy.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1073 class CreateFirewallPolicyRequest < Struct.new( :firewall_policy_name, :firewall_policy, :description, :tags, :dry_run, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Indicates whether you want Network Firewall to just check the validity of the request, rather than run the request.
If set to TRUE, Network Firewall checks whether the request can
run successfully, but doesn't actually make the requested changes.
The call returns the value that the request would return if you ran
it with dry run set to FALSE, but doesn't make additions or
changes to your resources. This option allows you to make sure that
you have the required permissions to run the request and that your
request parameters are valid.
If set to FALSE, Network Firewall makes the requested changes to
your resources.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1073 class CreateFirewallPolicyRequest < Struct.new( :firewall_policy_name, :firewall_policy, :description, :tags, :dry_run, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
A complex type that contains settings for encryption of your firewall policy resources.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1073 class CreateFirewallPolicyRequest < Struct.new( :firewall_policy_name, :firewall_policy, :description, :tags, :dry_run, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#firewall_policy ⇒ Types::FirewallPolicy
The rule groups and policy actions to use in the firewall policy.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1073 class CreateFirewallPolicyRequest < Struct.new( :firewall_policy_name, :firewall_policy, :description, :tags, :dry_run, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#firewall_policy_name ⇒ String
The descriptive name of the firewall policy. You can't change the name of a firewall policy after you create it.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1073 class CreateFirewallPolicyRequest < Struct.new( :firewall_policy_name, :firewall_policy, :description, :tags, :dry_run, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The key:value pairs to associate with the resource.
1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1073 class CreateFirewallPolicyRequest < Struct.new( :firewall_policy_name, :firewall_policy, :description, :tags, :dry_run, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |