Class: Aws::NetworkFirewall::Types::CreateFirewallPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::CreateFirewallPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_policy_response ⇒ Types::FirewallPolicyResponse
The high-level properties of a firewall policy.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#firewall_policy_response ⇒ Types::FirewallPolicyResponse
The high-level properties of a firewall policy. This, along with the FirewallPolicy, define the policy. You can retrieve all objects for a firewall policy by calling DescribeFirewallPolicy.
1106 1107 1108 1109 1110 1111 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1106 class CreateFirewallPolicyResponse < Struct.new( :update_token, :firewall_policy_response) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the firewall policy. The token marks the state of the policy resource at the time of the request.
To make changes to the policy, you provide the token in your
request. Network Firewall uses the token to ensure that the policy
hasn't changed since you last retrieved it. If it has changed, the
operation fails with an InvalidTokenException. If this happens,
retrieve the firewall policy again to get a current copy of it with
current token. Reapply your changes as needed, then try the
operation again using the new token.
1106 1107 1108 1109 1110 1111 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1106 class CreateFirewallPolicyResponse < Struct.new( :update_token, :firewall_policy_response) SENSITIVE = [] include Aws::Structure end |