Class: Aws::NetworkFirewall::Types::CreateFirewallResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#firewall ⇒ Types::Firewall

The configuration settings for the firewall. These settings include the firewall policy and the subnets in your VPC to use for the firewall endpoints.

Returns:



1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1306

class CreateFirewallResponse < Struct.new(
  :firewall,
  :firewall_status)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_status ⇒ Types::FirewallStatus

Detailed information about the current status of a Firewall. You can retrieve this for a firewall by calling DescribeFirewall and providing the firewall name and ARN.

The firewall status indicates a combined status. It indicates whether all subnets are up-to-date with the latest firewall configurations, which is based on the sync states config values, and also whether all subnets have their endpoints fully enabled, based on their sync states attachment values.



1306
1307
1308
1309
1310
1311
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1306

class CreateFirewallResponse < Struct.new(
  :firewall,
  :firewall_status)
  SENSITIVE = []
  include Aws::Structure
end