Class: Aws::NetworkFirewall::Types::CreateProxyConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_rule_phase_actions ⇒ Types::ProxyConfigDefaultRulePhaseActionsRequest

Evaluation points in the traffic flow where rules are applied. There are three phases in a traffic where the rule match is applied.



1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1345

class CreateProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :description,
  :rule_group_names,
  :rule_group_arns,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the proxy configuration.

Returns:

  • (String)


1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1345

class CreateProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :description,
  :rule_group_names,
  :rule_group_arns,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_name ⇒ String

The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.

Returns:

  • (String)


1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1345

class CreateProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :description,
  :rule_group_names,
  :rule_group_arns,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_arns ⇒ Array<String>

The proxy rule group arn(s) to attach to the proxy configuration.

You must specify the ARNs or the names, and you can specify both.

Returns:

  • (Array<String>)


1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1345

class CreateProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :description,
  :rule_group_names,
  :rule_group_arns,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_names ⇒ Array<String>

The proxy rule group name(s) to attach to the proxy configuration.

You must specify the ARNs or the names, and you can specify both.

Returns:

  • (Array<String>)


1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1345

class CreateProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :description,
  :rule_group_names,
  :rule_group_arns,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.

Returns:



1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1345

class CreateProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :description,
  :rule_group_names,
  :rule_group_arns,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end