Class: Aws::NetworkFirewall::Types::CreateProxyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#listener_properties ⇒ Array<Types::ListenerPropertyRequest>

Listener properties for HTTP and HTTPS traffic.

Returns:



1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1421

class CreateProxyRequest < Struct.new(
  :proxy_name,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_id ⇒ String

A unique identifier for the NAT gateway to use with proxy resources.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1421

class CreateProxyRequest < Struct.new(
  :proxy_name,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy configuration.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1421

class CreateProxyRequest < Struct.new(
  :proxy_name,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_name ⇒ String

The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1421

class CreateProxyRequest < Struct.new(
  :proxy_name,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_name ⇒ String

The descriptive name of the proxy. You can't change the name of a proxy after you create it.

Returns:

  • (String)


1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1421

class CreateProxyRequest < Struct.new(
  :proxy_name,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.

Returns:



1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1421

class CreateProxyRequest < Struct.new(
  :proxy_name,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tls_intercept_properties ⇒ Types::TlsInterceptPropertiesRequest

TLS decryption on traffic to filter on attributes in the HTTP header.



1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1421

class CreateProxyRequest < Struct.new(
  :proxy_name,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end