Class: Aws::NetworkFirewall::Types::CreateProxyRuleGroupResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::CreateProxyRuleGroupResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#proxy_rule_group ⇒ Types::ProxyRuleGroup
The properties that define the proxy rule group.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#proxy_rule_group ⇒ Types::ProxyRuleGroup
The properties that define the proxy rule group.
1550 1551 1552 1553 1554 1555 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1550 class CreateProxyRuleGroupResponse < Struct.new( :proxy_rule_group, :update_token) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the proxy rule group. The token marks the state of the proxy rule group resource at the time of the request.
To make changes to the proxy rule group, you provide the token in
your request. Network Firewall uses the token to ensure that the
proxy rule group hasn't changed since you last retrieved it. If it
has changed, the operation fails with an InvalidTokenException. If
this happens, retrieve the proxy rule group again to get a current
copy of it with a current token. Reapply your changes as needed,
then try the operation again using the new token.
1550 1551 1552 1553 1554 1555 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1550 class CreateProxyRuleGroupResponse < Struct.new( :proxy_rule_group, :update_token) SENSITIVE = [] include Aws::Structure end |