Class: Aws::NetworkFirewall::Types::CreateProxyRulesByRequestPhase

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Evaluation points in the traffic flow where rules are applied. There are three phases in a traffic where the rule match is applied.

This data type is used specifically for the CreateProxyRules API.

Pre-DNS - before domain resolution.

Pre-Request - after DNS, before request.

Post-Response - after receiving response.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#post_response ⇒ Array<Types::CreateProxyRule>

After receiving response.

Returns:



1582
1583
1584
1585
1586
1587
1588
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1582

class CreateProxyRulesByRequestPhase < Struct.new(
  :pre_dns,
  :pre_request,
  :post_response)
  SENSITIVE = []
  include Aws::Structure
end

#pre_dns ⇒ Array<Types::CreateProxyRule>

Before domain resolution.

Returns:



1582
1583
1584
1585
1586
1587
1588
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1582

class CreateProxyRulesByRequestPhase < Struct.new(
  :pre_dns,
  :pre_request,
  :post_response)
  SENSITIVE = []
  include Aws::Structure
end

#pre_request ⇒ Array<Types::CreateProxyRule>

After DNS, before request.

Returns:



1582
1583
1584
1585
1586
1587
1588
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1582

class CreateProxyRulesByRequestPhase < Struct.new(
  :pre_dns,
  :pre_request,
  :post_response)
  SENSITIVE = []
  include Aws::Structure
end