Class: Aws::NetworkFirewall::Types::CreateProxyRulesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#proxy_rule_group_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy rule group.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


1611
1612
1613
1614
1615
1616
1617
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1611

class CreateProxyRulesRequest < Struct.new(
  :proxy_rule_group_arn,
  :proxy_rule_group_name,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_rule_group_name ⇒ String

The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


1611
1612
1613
1614
1615
1616
1617
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1611

class CreateProxyRulesRequest < Struct.new(
  :proxy_rule_group_arn,
  :proxy_rule_group_name,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#rules ⇒ Types::CreateProxyRulesByRequestPhase

Individual rules that define match conditions and actions for application-layer traffic. Rules specify what to inspect (domains, headers, methods) and what action to take (allow, deny, alert).



1611
1612
1613
1614
1615
1616
1617
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1611

class CreateProxyRulesRequest < Struct.new(
  :proxy_rule_group_arn,
  :proxy_rule_group_name,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end