Class: Aws::NetworkFirewall::Types::CreateVpcEndpointAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

A description of the VPC endpoint association.

Returns:



1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963

class CreateVpcEndpointAssociationRequest < Struct.new(
  :firewall_arn,
  :vpc_id,
  :subnet_mapping,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall.

Returns:



1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963

class CreateVpcEndpointAssociationRequest < Struct.new(
  :firewall_arn,
  :vpc_id,
  :subnet_mapping,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_mapping ⇒ Types::SubnetMapping

The ID for a subnet that's used in an association with a firewall. This is used in CreateFirewall, AssociateSubnets, and CreateVpcEndpointAssociation. Network Firewall creates an instance of the associated firewall in each subnet that you specify, to filter traffic in the subnet's Availability Zone.

Returns:



1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963

class CreateVpcEndpointAssociationRequest < Struct.new(
  :firewall_arn,
  :vpc_id,
  :subnet_mapping,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.

Returns:



1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963

class CreateVpcEndpointAssociationRequest < Struct.new(
  :firewall_arn,
  :vpc_id,
  :subnet_mapping,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_id ⇒ String

The unique identifier of the VPC where you want to create a firewall endpoint.

Returns:



1963
1964
1965
1966
1967
1968
1969
1970
1971
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963

class CreateVpcEndpointAssociationRequest < Struct.new(
  :firewall_arn,
  :vpc_id,
  :subnet_mapping,
  :description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end