Class: Aws::NetworkFirewall::Types::DeleteContainerAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_association_arn ⇒ String

The Amazon Resource Name (ARN) of the container association.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2048
2049
2050
2051
2052
2053
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2048

class DeleteContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn)
  SENSITIVE = []
  include Aws::Structure
end

#container_association_name ⇒ String

The descriptive name of the container association.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2048
2049
2050
2051
2052
2053
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2048

class DeleteContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn)
  SENSITIVE = []
  include Aws::Structure
end