Class: Aws::NetworkFirewall::Types::DeleteFirewallPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_policy_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall policy.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2093
2094
2095
2096
2097
2098
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2093

class DeleteFirewallPolicyRequest < Struct.new(
  :firewall_policy_name,
  :firewall_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_policy_name ⇒ String

The descriptive name of the firewall policy. You can't change the name of a firewall policy after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2093
2094
2095
2096
2097
2098
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2093

class DeleteFirewallPolicyRequest < Struct.new(
  :firewall_policy_name,
  :firewall_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end