Class: Aws::NetworkFirewall::Types::DeleteFirewallRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2128

class DeleteFirewallRequest < Struct.new(
  :firewall_name,
  :firewall_arn)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_name ⇒ String

The descriptive name of the firewall. You can't change the name of a firewall after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2128
2129
2130
2131
2132
2133
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2128

class DeleteFirewallRequest < Struct.new(
  :firewall_name,
  :firewall_arn)
  SENSITIVE = []
  include Aws::Structure
end