Class: Aws::NetworkFirewall::Types::DeleteFirewallResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DeleteFirewallResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall ⇒ Types::Firewall
A firewall defines the behavior of a firewall, the main VPC where the firewall is used, the Availability Zones where the firewall can be used, and one subnet to use for a firewall endpoint within each of the Availability Zones.
-
#firewall_status ⇒ Types::FirewallStatus
Detailed information about the current status of a Firewall.
Instance Attribute Details
#firewall ⇒ Types::Firewall
A firewall defines the behavior of a firewall, the main VPC where the firewall is used, the Availability Zones where the firewall can be used, and one subnet to use for a firewall endpoint within each of the Availability Zones. The Availability Zones are defined implicitly in the subnet specifications.
In addition to the firewall endpoints that you define in this Firewall specification, you can create firewall endpoints in VpcEndpointAssociation resources for any VPC, in any Availability Zone where the firewall is already in use.
The status of the firewall, for example whether it’s ready to filter network traffic, is provided in the corresponding FirewallStatus. You can retrieve both the firewall and firewall status by calling DescribeFirewall.
1901 1902 1903 1904 1905 1906 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1901 class DeleteFirewallResponse < Struct.new( :firewall, :firewall_status) SENSITIVE = [] include Aws::Structure end |
#firewall_status ⇒ Types::FirewallStatus
Detailed information about the current status of a Firewall. You can retrieve this for a firewall by calling DescribeFirewall and providing the firewall name and ARN.
The firewall status indicates a combined status. It indicates whether all subnets are up-to-date with the latest firewall configurations, which is based on the sync states config values, and also whether all subnets have their endpoints fully enabled, based on their sync states attachment values.
1901 1902 1903 1904 1905 1906 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1901 class DeleteFirewallResponse < Struct.new( :firewall, :firewall_status) SENSITIVE = [] include Aws::Structure end |