Class: Aws::NetworkFirewall::Types::DeleteProxyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nat_gateway_id ⇒ String

The NAT Gateway the proxy is attached to.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2286

class DeleteProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2286

class DeleteProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_name ⇒ String

The descriptive name of the proxy. You can't change the name of a proxy after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2286
2287
2288
2289
2290
2291
2292
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2286

class DeleteProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn)
  SENSITIVE = []
  include Aws::Structure
end