Class: Aws::NetworkFirewall::Types::DeleteProxyRulesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#proxy_rule_group_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy rule group.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2376

class DeleteProxyRulesRequest < Struct.new(
  :proxy_rule_group_arn,
  :proxy_rule_group_name,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_rule_group_name ⇒ String

The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2376

class DeleteProxyRulesRequest < Struct.new(
  :proxy_rule_group_arn,
  :proxy_rule_group_name,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end

#rules ⇒ Array<String>

The proxy rule(s) to remove from the existing proxy rule group.

Returns:

  • (Array<String>)


2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2376

class DeleteProxyRulesRequest < Struct.new(
  :proxy_rule_group_arn,
  :proxy_rule_group_name,
  :rules)
  SENSITIVE = []
  include Aws::Structure
end