Class: Aws::NetworkFirewall::Types::DescribeContainerAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_association_arn ⇒ String

The Amazon Resource Name (ARN) of the container association.

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#container_association_name ⇒ String

The descriptive name of the container association.

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#container_monitoring_configurations ⇒ Array<Types::ContainerMonitoringConfiguration>

The monitoring configurations for the container association.



2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the container association.

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_time ⇒ Time

The most recent time that Network Firewall updated the container association.

Returns:

  • (Time)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_cidr_count ⇒ Integer

The number of CIDR blocks resolved from the monitored containers.

Returns:

  • (Integer)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the container association.

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.

Returns:



2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The container type. Valid values:

  • ECS - Amazon Elastic Container Service

  • EKS - Amazon Elastic Kubernetes Service

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#update_token ⇒ String

A token used for optimistic locking. Network Firewall returns a token to your requests that access the container association. The token marks the state of the container association resource at the time of the request.

To make changes to the container association, you provide the token in your request. Network Firewall uses the token to ensure that the container association hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the container association again to get a current copy of it with a current token. Reapply your changes as needed, then try the operation again using the new token.

Returns:

  • (String)


2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2614

class DescribeContainerAssociationResponse < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :status,
  :resolved_cidr_count,
  :last_updated_time,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end