Class: Aws::NetworkFirewall::Types::DescribeFirewallPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DescribeFirewallPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_policy ⇒ Types::FirewallPolicy
The policy for the specified firewall policy.
-
#firewall_policy_response ⇒ Types::FirewallPolicyResponse
The high-level properties of a firewall policy.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#firewall_policy ⇒ Types::FirewallPolicy
The policy for the specified firewall policy.
2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2735 class DescribeFirewallPolicyResponse < Struct.new( :update_token, :firewall_policy_response, :firewall_policy) SENSITIVE = [] include Aws::Structure end |
#firewall_policy_response ⇒ Types::FirewallPolicyResponse
The high-level properties of a firewall policy. This, along with the FirewallPolicy, define the policy. You can retrieve all objects for a firewall policy by calling DescribeFirewallPolicy.
2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2735 class DescribeFirewallPolicyResponse < Struct.new( :update_token, :firewall_policy_response, :firewall_policy) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the firewall policy. The token marks the state of the policy resource at the time of the request.
To make changes to the policy, you provide the token in your
request. Network Firewall uses the token to ensure that the policy
hasn't changed since you last retrieved it. If it has changed, the
operation fails with an InvalidTokenException. If this happens,
retrieve the firewall policy again to get a current copy of it with
current token. Reapply your changes as needed, then try the
operation again using the new token.
2735 2736 2737 2738 2739 2740 2741 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2735 class DescribeFirewallPolicyResponse < Struct.new( :update_token, :firewall_policy_response, :firewall_policy) SENSITIVE = [] include Aws::Structure end |