Class: Aws::NetworkFirewall::Types::DescribeFlowOperationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone ⇒ String

The ID of the Availability Zone where the firewall is located. For example, us-east-2a.

Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation.

Returns:

  • (String)


2842
2843
2844
2845
2846
2847
2848
2849
2850
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2842

class DescribeFlowOperationRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :flow_operation_id)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall.

Returns:

  • (String)


2842
2843
2844
2845
2846
2847
2848
2849
2850
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2842

class DescribeFlowOperationRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :flow_operation_id)
  SENSITIVE = []
  include Aws::Structure
end

#flow_operation_id ⇒ String

A unique identifier for the flow operation. This ID is returned in the responses to start and list commands. You provide to describe commands.

Returns:

  • (String)


2842
2843
2844
2845
2846
2847
2848
2849
2850
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2842

class DescribeFlowOperationRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :flow_operation_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_association_arn ⇒ String

The Amazon Resource Name (ARN) of a VPC endpoint association.

Returns:

  • (String)


2842
2843
2844
2845
2846
2847
2848
2849
2850
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2842

class DescribeFlowOperationRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :flow_operation_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_id ⇒ String

A unique identifier for the primary endpoint associated with a firewall.

Returns:

  • (String)


2842
2843
2844
2845
2846
2847
2848
2849
2850
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2842

class DescribeFlowOperationRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :flow_operation_id)
  SENSITIVE = []
  include Aws::Structure
end