Class: Aws::NetworkFirewall::Types::DescribeProxyConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#proxy_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy configuration.

You must specify the ARN or the name, and you can specify both.

Returns:



2990
2991
2992
2993
2994
2995
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2990

class DescribeProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_name ⇒ String

The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:



2990
2991
2992
2993
2994
2995
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2990

class DescribeProxyConfigurationRequest < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn)
  SENSITIVE = []
  include Aws::Structure
end