Class: Aws::NetworkFirewall::Types::DescribeProxyConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DescribeProxyConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration for the specified proxy configuration.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#proxy_configuration ⇒ Types::ProxyConfiguration
The configuration for the specified proxy configuration.
3018 3019 3020 3021 3022 3023 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3018 class DescribeProxyConfigurationResponse < Struct.new( :proxy_configuration, :update_token) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the proxy configuration. The token marks the state of the proxy configuration resource at the time of the request.
To make changes to the proxy configuration, you provide the token in
your request. Network Firewall uses the token to ensure that the
proxy configuration hasn't changed since you last retrieved it. If
it has changed, the operation fails with an InvalidTokenException.
If this happens, retrieve the proxy configuration again to get a
current copy of it with a current token. Reapply your changes as
needed, then try the operation again using the new token.
3018 3019 3020 3021 3022 3023 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3018 class DescribeProxyConfigurationResponse < Struct.new( :proxy_configuration, :update_token) SENSITIVE = [] include Aws::Structure end |