Class: Aws::NetworkFirewall::Types::DescribeProxyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#proxy_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3040

class DescribeProxyRequest < Struct.new(
  :proxy_name,
  :proxy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_name ⇒ String

The descriptive name of the proxy. You can't change the name of a proxy after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3040

class DescribeProxyRequest < Struct.new(
  :proxy_name,
  :proxy_arn)
  SENSITIVE = []
  include Aws::Structure
end