Class: Aws::NetworkFirewall::Types::DescribeProxyRuleRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#proxy_rule_group_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy rule group.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3241

class DescribeProxyRuleRequest < Struct.new(
  :proxy_rule_name,
  :proxy_rule_group_name,
  :proxy_rule_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_rule_group_name ⇒ String

The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3241

class DescribeProxyRuleRequest < Struct.new(
  :proxy_rule_name,
  :proxy_rule_group_name,
  :proxy_rule_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_rule_name ⇒ String

The descriptive name of the proxy rule. You can't change the name of a proxy rule after you create it.

Returns:

  • (String)


3241
3242
3243
3244
3245
3246
3247
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3241

class DescribeProxyRuleRequest < Struct.new(
  :proxy_rule_name,
  :proxy_rule_group_name,
  :proxy_rule_group_arn)
  SENSITIVE = []
  include Aws::Structure
end