Class: Aws::NetworkFirewall::Types::DescribeRuleGroupMetadataRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rule_group_arn ⇒ String

The descriptive name of the rule group. You can't change the name of a rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3328
3329
3330
3331
3332
3333
3334
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3328

class DescribeRuleGroupMetadataRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_name ⇒ String

The descriptive name of the rule group. You can't change the name of a rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3328
3329
3330
3331
3332
3333
3334
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3328

class DescribeRuleGroupMetadataRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules.

This setting is required for requests that do not include the RuleGroupARN.

Returns:

  • (String)


3328
3329
3330
3331
3332
3333
3334
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3328

class DescribeRuleGroupMetadataRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end