Class: Aws::NetworkFirewall::Types::DescribeRuleGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analyze_rule_group ⇒ Boolean

Indicates whether you want Network Firewall to analyze the stateless rules in the rule group for rule behavior such as asymmetric routing. If set to TRUE, Network Firewall runs the analysis.

Returns:

  • (Boolean)


3449
3450
3451
3452
3453
3454
3455
3456
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3449

class DescribeRuleGroupRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type,
  :analyze_rule_group)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_arn ⇒ String

The Amazon Resource Name (ARN) of the rule group.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3449

class DescribeRuleGroupRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type,
  :analyze_rule_group)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_name ⇒ String

The descriptive name of the rule group. You can't change the name of a rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3449

class DescribeRuleGroupRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type,
  :analyze_rule_group)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules.

This setting is required for requests that do not include the RuleGroupARN.

Returns:

  • (String)


3449
3450
3451
3452
3453
3454
3455
3456
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3449

class DescribeRuleGroupRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type,
  :analyze_rule_group)
  SENSITIVE = []
  include Aws::Structure
end