Class: Aws::NetworkFirewall::Types::DescribeRuleGroupSummaryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rule_group_arn ⇒ String

Required. The Amazon Resource Name (ARN) of the rule group.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3529
3530
3531
3532
3533
3534
3535
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3529

class DescribeRuleGroupSummaryRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_name ⇒ String

The descriptive name of the rule group. You can't change the name of a rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3529
3530
3531
3532
3533
3534
3535
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3529

class DescribeRuleGroupSummaryRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of rule group you want a summary for. This is a required field.

Valid value: STATEFUL

Note that STATELESS exists but is not currently supported. If you provide STATELESS, an exception is returned.

Returns:

  • (String)


3529
3530
3531
3532
3533
3534
3535
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3529

class DescribeRuleGroupSummaryRequest < Struct.new(
  :rule_group_name,
  :rule_group_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end