Class: Aws::NetworkFirewall::Types::DescribeRuleGroupSummaryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

A description of the rule group.

Returns:

  • (String)


3563
3564
3565
3566
3567
3568
3569
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3563

class DescribeRuleGroupSummaryResponse < Struct.new(
  :rule_group_name,
  :description,
  :summary)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_name ⇒ String

The descriptive name of the rule group. You can't change the name of a rule group after you create it.

Returns:

  • (String)


3563
3564
3565
3566
3567
3568
3569
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3563

class DescribeRuleGroupSummaryResponse < Struct.new(
  :rule_group_name,
  :description,
  :summary)
  SENSITIVE = []
  include Aws::Structure
end

#summary ⇒ Types::Summary

A complex type that contains rule information based on the rule group's configured summary settings. The content varies depending on the fields that you specified to extract in your SummaryConfiguration. When you haven't configured any summary settings, this returns an empty array. The response might include:

  • Rule identifiers

  • Rule descriptions

  • Any metadata fields that you specified in your SummaryConfiguration

Returns:



3563
3564
3565
3566
3567
3568
3569
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3563

class DescribeRuleGroupSummaryResponse < Struct.new(
  :rule_group_name,
  :description,
  :summary)
  SENSITIVE = []
  include Aws::Structure
end