Class: Aws::NetworkFirewall::Types::DescribeTLSInspectionConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tls_inspection_configuration ⇒ Types::TLSInspectionConfiguration

The object that defines a TLS inspection configuration. This, along with TLSInspectionConfigurationResponse, define the TLS inspection configuration. You can retrieve all objects for a TLS inspection configuration by calling DescribeTLSInspectionConfiguration.

Network Firewall uses a TLS inspection configuration to decrypt traffic. Network Firewall re-encrypts the traffic before sending it to its destination.

To use a TLS inspection configuration, you add it to a new Network Firewall firewall policy, then you apply the firewall policy to a firewall. Network Firewall acts as a proxy service to decrypt and inspect the traffic traveling through your firewalls. You can reference a TLS inspection configuration from more than one firewall policy, and you can use a firewall policy in more than one firewall. For more information about using TLS inspection configurations, see Inspecting SSL/TLS traffic with TLS inspection configurations in the Network Firewall Developer Guide.



3644
3645
3646
3647
3648
3649
3650
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3644

class DescribeTLSInspectionConfigurationResponse < Struct.new(
  :update_token,
  :tls_inspection_configuration,
  :tls_inspection_configuration_response)
  SENSITIVE = []
  include Aws::Structure
end

#tls_inspection_configuration_response ⇒ Types::TLSInspectionConfigurationResponse

The high-level properties of a TLS inspection configuration. This, along with the TLSInspectionConfiguration, define the TLS inspection configuration. You can retrieve all objects for a TLS inspection configuration by calling DescribeTLSInspectionConfiguration.



3644
3645
3646
3647
3648
3649
3650
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3644

class DescribeTLSInspectionConfigurationResponse < Struct.new(
  :update_token,
  :tls_inspection_configuration,
  :tls_inspection_configuration_response)
  SENSITIVE = []
  include Aws::Structure
end

#update_token ⇒ String

A token used for optimistic locking. Network Firewall returns a token to your requests that access the TLS inspection configuration. The token marks the state of the TLS inspection configuration resource at the time of the request.

To make changes to the TLS inspection configuration, you provide the token in your request. Network Firewall uses the token to ensure that the TLS inspection configuration hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the TLS inspection configuration again to get a current copy of it with a current token. Reapply your changes as needed, then try the operation again using the new token.

Returns:

  • (String)


3644
3645
3646
3647
3648
3649
3650
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3644

class DescribeTLSInspectionConfigurationResponse < Struct.new(
  :update_token,
  :tls_inspection_configuration,
  :tls_inspection_configuration_response)
  SENSITIVE = []
  include Aws::Structure
end