Class: Aws::NetworkFirewall::Types::DescribeVpcEndpointAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#vpc_endpoint_association ⇒ Types::VpcEndpointAssociation

The configuration settings for the VPC endpoint association. These settings include the firewall and the VPC and subnet to use for the firewall endpoint.



3679
3680
3681
3682
3683
3684
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3679

class DescribeVpcEndpointAssociationResponse < Struct.new(
  :vpc_endpoint_association,
  :vpc_endpoint_association_status)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_association_status ⇒ Types::VpcEndpointAssociationStatus

Detailed information about the current status of a VpcEndpointAssociation. You can retrieve this by calling DescribeVpcEndpointAssociation and providing the VPC endpoint association ARN.



3679
3680
3681
3682
3683
3684
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3679

class DescribeVpcEndpointAssociationResponse < Struct.new(
  :vpc_endpoint_association,
  :vpc_endpoint_association_status)
  SENSITIVE = []
  include Aws::Structure
end