Class: Aws::NetworkFirewall::Types::Flow

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Any number of arrays, where each array is a single flow identified in the scope of the operation. If multiple flows were in the scope of the operation, multiple Flows arrays are returned.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#age ⇒ Integer

Returned as info about age of the flows identified by the flow operation.

Returns:

  • (Integer)


4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end

#byte_count ⇒ Integer

Returns the number of bytes received or transmitted in a specific flow.

Returns:

  • (Integer)


4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end

#destination_address ⇒ Types::Address

A single IP address specification. This is used in the MatchAttributes source and destination specifications.

Returns:



4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end

#destination_port ⇒ String

The destination port to inspect for. You can specify an individual port, for example 1994 and you can specify a port range, for example 1990:1994. To match with any port, specify ANY.

Returns:

  • (String)


4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end

#packet_count ⇒ Integer

Returns the total number of data packets received or transmitted in a flow.

Returns:

  • (Integer)


4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end

#protocol ⇒ String

The protocols to inspect for, specified using the assigned internet protocol number (IANA) for each protocol. If not specified, this matches with any protocol.

Returns:

  • (String)


4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end

#source_address ⇒ Types::Address

A single IP address specification. This is used in the MatchAttributes source and destination specifications.

Returns:



4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end

#source_port ⇒ String

The source port to inspect for. You can specify an individual port, for example 1994 and you can specify a port range, for example 1990:1994. To match with any port, specify ANY.

Returns:

  • (String)


4592
4593
4594
4595
4596
4597
4598
4599
4600
4601
4602
4603
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4592

class Flow < Struct.new(
  :source_address,
  :destination_address,
  :source_port,
  :destination_port,
  :protocol,
  :age,
  :packet_count,
  :byte_count)
  SENSITIVE = []
  include Aws::Structure
end