Class: Aws::NetworkFirewall::Types::FlowTimeouts
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::FlowTimeouts
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Describes the amount of time that can pass without any traffic sent through the firewall before the firewall determines that the connection is idle and Network Firewall removes the flow entry from its flow table. When you update this value, existing connections will be treated according to your stream exception policy configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tcp_idle_timeout_seconds ⇒ Integer
The number of seconds that can pass without any TCP traffic sent through the firewall before the firewall determines that the connection is idle.
Instance Attribute Details
#tcp_idle_timeout_seconds ⇒ Integer
The number of seconds that can pass without any TCP traffic sent through the firewall before the firewall determines that the connection is idle. After the idle timeout passes, data packets are dropped, however, the next TCP SYN packet is considered a new flow and is processed by the firewall. Clients or targets can use TCP keepalive packets to reset the idle timeout.
You can define the TcpIdleTimeoutSeconds value to be between 60
and 6000 seconds. If no value is provided, it defaults to 350
seconds.
4737 4738 4739 4740 4741 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4737 class FlowTimeouts < Struct.new( :tcp_idle_timeout_seconds) SENSITIVE = [] include Aws::Structure end |