Class: Aws::NetworkFirewall::Types::Header

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

The basic rule criteria for Network Firewall to use to inspect packet headers in stateful traffic flow inspection. Traffic flows that match the criteria are a match for the corresponding StatefulRule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination ⇒ String

The destination IP address or address range to inspect for, in CIDR notation. To match with any address, specify ANY.

Specify an IP address or a block of IP addresses in Classless Inter-Domain Routing (CIDR) notation. Network Firewall supports all address ranges for IPv4 and IPv6.

Examples:

  • To configure Network Firewall to inspect for the IP address 192.0.2.44, specify 192.0.2.44/32.

  • To configure Network Firewall to inspect for IP addresses from 192.0.2.0 to 192.0.2.255, specify 192.0.2.0/24.

  • To configure Network Firewall to inspect for the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify 1111:0000:0000:0000:0000:0000:0000:0111/128.

  • To configure Network Firewall to inspect for IP addresses from 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify 1111:0000:0000:0000:0000:0000:0000:0000/64.

For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing.

Returns:

  • (String)


4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4937

class Header < Struct.new(
  :protocol,
  :source,
  :source_port,
  :direction,
  :destination,
  :destination_port)
  SENSITIVE = []
  include Aws::Structure
end

#destination_port ⇒ String

The destination port to inspect for. You can specify an individual port, for example 1994 and you can specify a port range, for example 1990:1994. To match with any port, specify ANY.

Returns:

  • (String)


4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4937

class Header < Struct.new(
  :protocol,
  :source,
  :source_port,
  :direction,
  :destination,
  :destination_port)
  SENSITIVE = []
  include Aws::Structure
end

#direction ⇒ String

The direction of traffic flow to inspect. If set to ANY, the inspection matches bidirectional traffic, both from the source to the destination and from the destination to the source. If set to FORWARD, the inspection only matches traffic going from the source to the destination.

Returns:

  • (String)


4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4937

class Header < Struct.new(
  :protocol,
  :source,
  :source_port,
  :direction,
  :destination,
  :destination_port)
  SENSITIVE = []
  include Aws::Structure
end

#protocol ⇒ String

The protocol to inspect for. To specify all, you can use IP, because all traffic on Amazon Web Services and on the internet is IP.

Returns:

  • (String)


4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4937

class Header < Struct.new(
  :protocol,
  :source,
  :source_port,
  :direction,
  :destination,
  :destination_port)
  SENSITIVE = []
  include Aws::Structure
end

#source ⇒ String

The source IP address or address range to inspect for, in CIDR notation. To match with any address, specify ANY.

Specify an IP address or a block of IP addresses in Classless Inter-Domain Routing (CIDR) notation. Network Firewall supports all address ranges for IPv4 and IPv6.

Examples:

  • To configure Network Firewall to inspect for the IP address 192.0.2.44, specify 192.0.2.44/32.

  • To configure Network Firewall to inspect for IP addresses from 192.0.2.0 to 192.0.2.255, specify 192.0.2.0/24.

  • To configure Network Firewall to inspect for the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify 1111:0000:0000:0000:0000:0000:0000:0111/128.

  • To configure Network Firewall to inspect for IP addresses from 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify 1111:0000:0000:0000:0000:0000:0000:0000/64.

For more information about CIDR notation, see the Wikipedia entry Classless Inter-Domain Routing.

Returns:

  • (String)


4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4937

class Header < Struct.new(
  :protocol,
  :source,
  :source_port,
  :direction,
  :destination,
  :destination_port)
  SENSITIVE = []
  include Aws::Structure
end

#source_port ⇒ String

The source port to inspect for. You can specify an individual port, for example 1994 and you can specify a port range, for example 1990:1994. To match with any port, specify ANY.

Returns:

  • (String)


4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4937

class Header < Struct.new(
  :protocol,
  :source,
  :source_port,
  :direction,
  :destination,
  :destination_port)
  SENSITIVE = []
  include Aws::Structure
end