Class: Aws::NetworkFirewall::Types::Hits
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::Hits
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Attempts made to a access domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of attempts made to access a domain.
Instance Attribute Details
#count ⇒ Integer
The number of attempts made to access a domain.
4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4956 class Hits < Struct.new( :count) SENSITIVE = [] include Aws::Structure end |