Class: Aws::NetworkFirewall::Types::IPSetReference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Configures one or more IP set references for a Suricata-compatible rule group. This is used in CreateRuleGroup or UpdateRuleGroup. An IP set reference is a rule variable that references resources that you create and manage in another Amazon Web Services service, such as an Amazon VPC prefix list. Network Firewall IP set references enable you to dynamically update the contents of your rules. When you create, update, or delete the resource you are referencing in your rule, Network Firewall automatically updates the rule's content with the changes. For more information about IP set references in Network Firewall, see Using IP set references in the Network Firewall Developer Guide.

Network Firewall currently supports Amazon VPC prefix lists and resource groups in IP set references.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#reference_arn ⇒ String

The Amazon Resource Name (ARN) of the resource that you are referencing in your rule group.

Returns:

  • (String)


5022
5023
5024
5025
5026
# File 'lib/aws-sdk-networkfirewall/types.rb', line 5022

class IPSetReference < Struct.new(
  :reference_arn)
  SENSITIVE = []
  include Aws::Structure
end