Class: Aws::NetworkFirewall::Types::InvalidRequestException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

The operation failed because of a problem with your request. Examples include:

  • You specified an unsupported parameter name or value.

  • You tried to update a property with a value that isn't among the available types.

  • Your request references an ARN that is malformed, or corresponds to a resource that isn't valid in the context of the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


5086
5087
5088
5089
5090
# File 'lib/aws-sdk-networkfirewall/types.rb', line 5086

class InvalidRequestException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end