Class: Aws::NetworkFirewall::Types::MatchAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Criteria for Network Firewall to use to inspect an individual packet in stateless rule inspection. Each match attributes set can include one or more items such as IP address, CIDR range, port number, protocol, and TCP flags.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_ports ⇒ Array<Types::PortRange>

The destination port to inspect for. You can specify an individual port, for example 1994 and you can specify a port range, for example 1990:1994. To match with any port, specify ANY.

This setting is only used for protocols 6 (TCP) and 17 (UDP).

Returns:



6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6114

class MatchAttributes < Struct.new(
  :sources,
  :destinations,
  :source_ports,
  :destination_ports,
  :protocols,
  :tcp_flags)
  SENSITIVE = []
  include Aws::Structure
end

#destinations ⇒ Array<Types::Address>

The destination IP addresses and address ranges to inspect for, in CIDR notation. If not specified, this matches with any destination address.

Returns:



6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6114

class MatchAttributes < Struct.new(
  :sources,
  :destinations,
  :source_ports,
  :destination_ports,
  :protocols,
  :tcp_flags)
  SENSITIVE = []
  include Aws::Structure
end

#protocols ⇒ Array<Integer>

The protocols to inspect for, specified using the assigned internet protocol number (IANA) for each protocol. If not specified, this matches with any protocol.

Returns:

  • (Array<Integer>)


6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6114

class MatchAttributes < Struct.new(
  :sources,
  :destinations,
  :source_ports,
  :destination_ports,
  :protocols,
  :tcp_flags)
  SENSITIVE = []
  include Aws::Structure
end

#source_ports ⇒ Array<Types::PortRange>

The source port to inspect for. You can specify an individual port, for example 1994 and you can specify a port range, for example 1990:1994. To match with any port, specify ANY.

If not specified, this matches with any source port.

This setting is only used for protocols 6 (TCP) and 17 (UDP).

Returns:



6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6114

class MatchAttributes < Struct.new(
  :sources,
  :destinations,
  :source_ports,
  :destination_ports,
  :protocols,
  :tcp_flags)
  SENSITIVE = []
  include Aws::Structure
end

#sources ⇒ Array<Types::Address>

The source IP addresses and address ranges to inspect for, in CIDR notation. If not specified, this matches with any source address.

Returns:



6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6114

class MatchAttributes < Struct.new(
  :sources,
  :destinations,
  :source_ports,
  :destination_ports,
  :protocols,
  :tcp_flags)
  SENSITIVE = []
  include Aws::Structure
end

#tcp_flags ⇒ Array<Types::TCPFlagField>

The TCP flags and masks to inspect for. If not specified, this matches with any settings. This setting is only used for protocol 6 (TCP).

Returns:



6114
6115
6116
6117
6118
6119
6120
6121
6122
6123
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6114

class MatchAttributes < Struct.new(
  :sources,
  :destinations,
  :source_ports,
  :destination_ports,
  :protocols,
  :tcp_flags)
  SENSITIVE = []
  include Aws::Structure
end