Class: Aws::NetworkFirewall::Types::NatGatewayAttachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

The definition and status of the attachment between a proxy mode firewall and a NAT gateway that proxies its traffic.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dns_name ⇒ String

The DNS name that resolves to the firewall's proxy for traffic sent through this NAT gateway attachment.

Returns:

  • (String)


6152
6153
6154
6155
6156
6157
6158
6159
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152

class NatGatewayAttachment < Struct.new(
  :nat_gateway_id,
  :status,
  :status_message,
  :dns_name)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_id ⇒ String

A unique identifier for the NAT gateway to use with proxy resources.

Returns:

  • (String)


6152
6153
6154
6155
6156
6157
6158
6159
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152

class NatGatewayAttachment < Struct.new(
  :nat_gateway_id,
  :status,
  :status_message,
  :dns_name)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the NAT gateway attachment.

When this value is READY, the attachment is available to proxy traffic. Otherwise, this value reflects its state, for example CREATING or DELETING.

Returns:

  • (String)


6152
6153
6154
6155
6156
6157
6158
6159
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152

class NatGatewayAttachment < Struct.new(
  :nat_gateway_id,
  :status,
  :status_message,
  :dns_name)
  SENSITIVE = []
  include Aws::Structure
end

#status_message ⇒ String

If Network Firewall encounters an issue with the NAT gateway attachment, it populates this with an explanation of the problem.

Returns:

  • (String)


6152
6153
6154
6155
6156
6157
6158
6159
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152

class NatGatewayAttachment < Struct.new(
  :nat_gateway_id,
  :status,
  :status_message,
  :dns_name)
  SENSITIVE = []
  include Aws::Structure
end