Class: Aws::NetworkFirewall::Types::Proxy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Proxy attached to a NAT gateway.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_time ⇒ Time

Time the Proxy was created.

Returns:

  • (Time)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#delete_time ⇒ Time

Time the Proxy was deleted.

Returns:

  • (Time)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_code ⇒ String

Failure code for cases when the Proxy fails to attach or update.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#failure_message ⇒ String

Failure message for cases when the Proxy fails to attach or update.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#listener_properties ⇒ Array<Types::ListenerProperty>

Listener properties for HTTP and HTTPS traffic.

Returns:



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_id ⇒ String

The NAT Gateway for the proxy.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy configuration.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_name ⇒ String

The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_modify_state ⇒ String

Current modification status of the Proxy.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_name ⇒ String

The descriptive name of the proxy. You can't change the name of a proxy after you create it.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_state ⇒ String

Current attachment/detachment status of the Proxy.

Returns:

  • (String)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.

Returns:



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tls_intercept_properties ⇒ Types::TlsInterceptProperties

TLS decryption on traffic to filter on attributes in the HTTP header.



6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#update_time ⇒ Time

Time the Proxy was updated.

Returns:

  • (Time)


6327
6328
6329
6330
6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6327

class Proxy < Struct.new(
  :create_time,
  :delete_time,
  :update_time,
  :failure_code,
  :failure_message,
  :proxy_state,
  :proxy_modify_state,
  :nat_gateway_id,
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :proxy_name,
  :proxy_arn,
  :listener_properties,
  :tls_intercept_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end