Class: Aws::NetworkFirewall::Types::ProxyConfigRuleGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Proxy rule group contained within a proxy configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#priority ⇒ Integer

Priority of the proxy rule group in the proxy configuration.

Returns:

  • (Integer)


6396
6397
6398
6399
6400
6401
6402
6403
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6396

class ProxyConfigRuleGroup < Struct.new(
  :proxy_rule_group_name,
  :proxy_rule_group_arn,
  :type,
  :priority)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_rule_group_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy rule group.

Returns:

  • (String)


6396
6397
6398
6399
6400
6401
6402
6403
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6396

class ProxyConfigRuleGroup < Struct.new(
  :proxy_rule_group_name,
  :proxy_rule_group_arn,
  :type,
  :priority)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_rule_group_name ⇒ String

The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

Returns:

  • (String)


6396
6397
6398
6399
6400
6401
6402
6403
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6396

class ProxyConfigRuleGroup < Struct.new(
  :proxy_rule_group_name,
  :proxy_rule_group_arn,
  :type,
  :priority)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Proxy rule group type.

Returns:

  • (String)


6396
6397
6398
6399
6400
6401
6402
6403
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6396

class ProxyConfigRuleGroup < Struct.new(
  :proxy_rule_group_name,
  :proxy_rule_group_arn,
  :type,
  :priority)
  SENSITIVE = []
  include Aws::Structure
end