Class: Aws::NetworkFirewall::Types::ProxyConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

A Proxy Configuration defines the monitoring and protection behavior for a Proxy. The details of the behavior are defined in the rule groups that you add to your configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_time ⇒ Time

Time the Proxy Configuration was created.

Returns:

  • (Time)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#default_rule_phase_actions ⇒ Types::ProxyConfigDefaultRulePhaseActionsRequest

Evaluation points in the traffic flow where rules are applied. There are three phases in a traffic where the rule match is applied.

Pre-DNS - before domain resolution.

Pre-Request - after DNS, before request.

Post-Response - after receiving response.



6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#delete_time ⇒ Time

Time the Proxy Configuration was deleted.

Returns:

  • (Time)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the proxy configuration.

Returns:

  • (String)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy configuration.

Returns:

  • (String)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_configuration_name ⇒ String

The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.

Returns:

  • (String)


6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#rule_groups ⇒ Array<Types::ProxyConfigRuleGroup>

Proxy rule groups within the proxy configuration.

Returns:



6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.

Returns:



6451
6452
6453
6454
6455
6456
6457
6458
6459
6460
6461
6462
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6451

class ProxyConfiguration < Struct.new(
  :proxy_configuration_name,
  :proxy_configuration_arn,
  :description,
  :create_time,
  :delete_time,
  :rule_groups,
  :default_rule_phase_actions,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end