Class: Aws::NetworkFirewall::Types::ProxyConfigurationMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

High-level information about a proxy configuration, returned by operations like create and describe. You can use the information provided in the metadata to retrieve and manage a proxy configuration. You can retrieve all objects for a proxy configuration by calling DescribeProxyConfiguration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of a proxy configuration.

Returns:

  • (String)


6481
6482
6483
6484
6485
6486
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6481

class ProxyConfigurationMetadata < Struct.new(
  :name,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.

Returns:

  • (String)


6481
6482
6483
6484
6485
6486
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6481

class ProxyConfigurationMetadata < Struct.new(
  :name,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end