Class: Aws::NetworkFirewall::Types::ProxyRuleCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Match criteria that specify what traffic attributes to examine.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#condition_key ⇒ String

Defines what is to be matched.

Returns:

  • (String)


6561
6562
6563
6564
6565
6566
6567
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6561

class ProxyRuleCondition < Struct.new(
  :condition_operator,
  :condition_key,
  :condition_values)
  SENSITIVE = []
  include Aws::Structure
end

#condition_operator ⇒ String

Defines how to perform a match.

Returns:

  • (String)


6561
6562
6563
6564
6565
6566
6567
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6561

class ProxyRuleCondition < Struct.new(
  :condition_operator,
  :condition_key,
  :condition_values)
  SENSITIVE = []
  include Aws::Structure
end

#condition_values ⇒ Array<String>

Specifes the exact value that needs to be matched against.

Returns:

  • (Array<String>)


6561
6562
6563
6564
6565
6566
6567
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6561

class ProxyRuleCondition < Struct.new(
  :condition_operator,
  :condition_key,
  :condition_values)
  SENSITIVE = []
  include Aws::Structure
end