Class: Aws::NetworkFirewall::Types::ProxyRuleGroupAttachment

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

The proxy rule group(s) to attach to the proxy configuration

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#insert_position ⇒ Integer

Where to insert a proxy rule group in a proxy configuration.

Returns:

  • (Integer)


6630
6631
6632
6633
6634
6635
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6630

class ProxyRuleGroupAttachment < Struct.new(
  :proxy_rule_group_name,
  :insert_position)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_rule_group_name ⇒ String

The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

Returns:

  • (String)


6630
6631
6632
6633
6634
6635
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6630

class ProxyRuleGroupAttachment < Struct.new(
  :proxy_rule_group_name,
  :insert_position)
  SENSITIVE = []
  include Aws::Structure
end