Class: Aws::NetworkFirewall::Types::ProxyRuleGroupMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

High-level information about a proxy rule group, returned by operations like create and describe. You can use the information provided in the metadata to retrieve and manage a proxy rule group. You can retrieve all objects for a proxy rule group by calling DescribeProxyRuleGroup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of a proxy rule group.

Returns:

  • (String)


6654
6655
6656
6657
6658
6659
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6654

class ProxyRuleGroupMetadata < Struct.new(
  :name,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.

Returns:

  • (String)


6654
6655
6656
6657
6658
6659
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6654

class ProxyRuleGroupMetadata < Struct.new(
  :name,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end