Class: Aws::NetworkFirewall::Types::PutResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::PutResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The IAM policy statement that lists the accounts that you want to share your Network Firewall resources with and the operations that you want the accounts to be able to perform.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the account that you want to share your Network Firewall resources with.
Instance Attribute Details
#policy ⇒ String
The IAM policy statement that lists the accounts that you want to share your Network Firewall resources with and the operations that you want the accounts to be able to perform.
For a rule group resource, you can specify the following operations in the Actions section of the statement:
-
network-firewall:CreateFirewallPolicy
-
network-firewall:UpdateFirewallPolicy
-
network-firewall:ListRuleGroups
For a firewall policy resource, you can specify the following operations in the Actions section of the statement:
-
network-firewall:AssociateFirewallPolicy
-
network-firewall:ListFirewallPolicies
For a firewall resource, you can specify the following operations in the Actions section of the statement:
-
network-firewall:CreateVpcEndpointAssociation
-
network-firewall:DescribeFirewallMetadata
-
network-firewall:ListFirewalls
In the Resource section of the statement, you specify the ARNs for
the Network Firewall resources that you want to share with the
account that you specified in Arn.
6819 6820 6821 6822 6823 6824 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6819 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the account that you want to share your Network Firewall resources with.
6819 6820 6821 6822 6823 6824 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6819 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy) SENSITIVE = [] include Aws::Structure end |