Class: Aws::NetworkFirewall::Types::RuleGroupMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

High-level information about a rule group, returned by ListRuleGroups. You can use the information provided in the metadata to retrieve and manage a rule group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the rule group.

Returns:

  • (String)


7060
7061
7062
7063
7064
7065
7066
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7060

class RuleGroupMetadata < Struct.new(
  :name,
  :arn,
  :vendor_name)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The descriptive name of the rule group. You can't change the name of a rule group after you create it.

Returns:

  • (String)


7060
7061
7062
7063
7064
7065
7066
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7060

class RuleGroupMetadata < Struct.new(
  :name,
  :arn,
  :vendor_name)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_name ⇒ String

The name of the Amazon Web Services Marketplace seller that provides this rule group.

Returns:

  • (String)


7060
7061
7062
7063
7064
7065
7066
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7060

class RuleGroupMetadata < Struct.new(
  :name,
  :arn,
  :vendor_name)
  SENSITIVE = []
  include Aws::Structure
end