Class: Aws::NetworkFirewall::Types::RuleSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

A complex type containing details about a Suricata rule. Contains:

  • SID

  • Msg

  • Metadata

Summaries are available for rule groups you manage and for active threat defense Amazon Web Services managed rule groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#metadata ⇒ String

The contents of the rule's metadata.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7261

class RuleSummary < Struct.new(
  :sid,
  :msg,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end

#msg ⇒ String

The contents taken from the rule's msg field.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7261

class RuleSummary < Struct.new(
  :sid,
  :msg,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end

#sid ⇒ String

The unique identifier (Signature ID) of the Suricata rule.

Returns:

  • (String)


7261
7262
7263
7264
7265
7266
7267
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7261

class RuleSummary < Struct.new(
  :sid,
  :msg,
  :metadata)
  SENSITIVE = []
  include Aws::Structure
end