Class: Aws::NetworkFirewall::Types::ServerCertificateScope
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::ServerCertificateScope
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Settings that define the Secure Sockets Layer/Transport Layer Security (SSL/TLS) traffic that Network Firewall should decrypt for inspection by the stateful rule engine.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_ports ⇒ Array<Types::PortRange>
The destination ports to decrypt for inspection, in Transmission Control Protocol (TCP) format.
-
#destinations ⇒ Array<Types::Address>
The destination IP addresses and address ranges to decrypt for inspection, in CIDR notation.
-
#protocols ⇒ Array<Integer>
The protocols to inspect for, specified using the assigned internet protocol number (IANA) for each protocol.
-
#source_ports ⇒ Array<Types::PortRange>
The source ports to decrypt for inspection, in Transmission Control Protocol (TCP) format.
-
#sources ⇒ Array<Types::Address>
The source IP addresses and address ranges to decrypt for inspection, in CIDR notation.
Instance Attribute Details
#destination_ports ⇒ Array<Types::PortRange>
The destination ports to decrypt for inspection, in Transmission Control Protocol (TCP) format. If not specified, this matches with any destination port.
You can specify individual ports, for example 1994, and you can
specify port ranges, such as 1990:1994.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7546 class ServerCertificateScope < Struct.new( :sources, :destinations, :source_ports, :destination_ports, :protocols) SENSITIVE = [] include Aws::Structure end |
#destinations ⇒ Array<Types::Address>
The destination IP addresses and address ranges to decrypt for inspection, in CIDR notation. If not specified, this matches with any destination address.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7546 class ServerCertificateScope < Struct.new( :sources, :destinations, :source_ports, :destination_ports, :protocols) SENSITIVE = [] include Aws::Structure end |
#protocols ⇒ Array<Integer>
The protocols to inspect for, specified using the assigned internet protocol number (IANA) for each protocol. If not specified, this matches with any protocol.
Network Firewall currently supports only TCP.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7546 class ServerCertificateScope < Struct.new( :sources, :destinations, :source_ports, :destination_ports, :protocols) SENSITIVE = [] include Aws::Structure end |
#source_ports ⇒ Array<Types::PortRange>
The source ports to decrypt for inspection, in Transmission Control Protocol (TCP) format. If not specified, this matches with any source port.
You can specify individual ports, for example 1994, and you can
specify port ranges, such as 1990:1994.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7546 class ServerCertificateScope < Struct.new( :sources, :destinations, :source_ports, :destination_ports, :protocols) SENSITIVE = [] include Aws::Structure end |
#sources ⇒ Array<Types::Address>
The source IP addresses and address ranges to decrypt for inspection, in CIDR notation. If not specified, this matches with any source address.
7546 7547 7548 7549 7550 7551 7552 7553 7554 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7546 class ServerCertificateScope < Struct.new( :sources, :destinations, :source_ports, :destination_ports, :protocols) SENSITIVE = [] include Aws::Structure end |