Class: Aws::NetworkFirewall::Types::SourceMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

High-level information about the managed rule group that your own rule group is copied from. You can use the the metadata to track version updates made to the originating rule group. You can retrieve all objects for a rule group by calling DescribeRuleGroup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#source_arn ⇒ String

The Amazon Resource Name (ARN) of the rule group that your own rule group is copied from.

Returns:

  • (String)


7582
7583
7584
7585
7586
7587
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7582

class SourceMetadata < Struct.new(
  :source_arn,
  :source_update_token)
  SENSITIVE = []
  include Aws::Structure
end

#source_update_token ⇒ String

The update token of the Amazon Web Services managed rule group that your own rule group is copied from. To determine the update token for the managed rule group, call DescribeRuleGroup.

Returns:

  • (String)


7582
7583
7584
7585
7586
7587
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7582

class SourceMetadata < Struct.new(
  :source_arn,
  :source_update_token)
  SENSITIVE = []
  include Aws::Structure
end