Class: Aws::NetworkFirewall::Types::StartFlowFlushRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone ⇒ String

The ID of the Availability Zone where the firewall is located. For example, us-east-2a.

Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation.

Returns:

  • (String)


7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7742

class StartFlowFlushRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :minimum_flow_age_in_seconds,
  :flow_filters)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall.

Returns:

  • (String)


7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7742

class StartFlowFlushRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :minimum_flow_age_in_seconds,
  :flow_filters)
  SENSITIVE = []
  include Aws::Structure
end

#flow_filters ⇒ Array<Types::FlowFilter>

Defines the scope a flow operation. You can use up to 20 filters to configure a single flow operation.

Returns:



7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7742

class StartFlowFlushRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :minimum_flow_age_in_seconds,
  :flow_filters)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_flow_age_in_seconds ⇒ Integer

The reqested FlowOperation ignores flows with an age (in seconds) lower than MinimumFlowAgeInSeconds. You provide this for start commands.

Returns:

  • (Integer)


7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7742

class StartFlowFlushRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :minimum_flow_age_in_seconds,
  :flow_filters)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_association_arn ⇒ String

The Amazon Resource Name (ARN) of a VPC endpoint association.

Returns:

  • (String)


7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7742

class StartFlowFlushRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :minimum_flow_age_in_seconds,
  :flow_filters)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_id ⇒ String

A unique identifier for the primary endpoint associated with a firewall.

Returns:

  • (String)


7742
7743
7744
7745
7746
7747
7748
7749
7750
7751
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7742

class StartFlowFlushRequest < Struct.new(
  :firewall_arn,
  :availability_zone,
  :vpc_endpoint_association_arn,
  :vpc_endpoint_id,
  :minimum_flow_age_in_seconds,
  :flow_filters)
  SENSITIVE = []
  include Aws::Structure
end