Class: Aws::NetworkFirewall::Types::StartFlowFlushResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall.

Returns:

  • (String)


7774
7775
7776
7777
7778
7779
7780
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7774

class StartFlowFlushResponse < Struct.new(
  :firewall_arn,
  :flow_operation_id,
  :flow_operation_status)
  SENSITIVE = []
  include Aws::Structure
end

#flow_operation_id ⇒ String

A unique identifier for the flow operation. This ID is returned in the responses to start and list commands. You provide to describe commands.

Returns:

  • (String)


7774
7775
7776
7777
7778
7779
7780
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7774

class StartFlowFlushResponse < Struct.new(
  :firewall_arn,
  :flow_operation_id,
  :flow_operation_status)
  SENSITIVE = []
  include Aws::Structure
end

#flow_operation_status ⇒ String

Returns the status of the flow operation. This string is returned in the responses to start, list, and describe commands.

If the status is COMPLETED_WITH_ERRORS, results may be returned with any number of Flows missing from the response. If the status is FAILED, Flows returned will be empty.

Returns:

  • (String)


7774
7775
7776
7777
7778
7779
7780
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7774

class StartFlowFlushResponse < Struct.new(
  :firewall_arn,
  :flow_operation_id,
  :flow_operation_status)
  SENSITIVE = []
  include Aws::Structure
end