Class: Aws::NetworkFirewall::Types::StatefulEngineOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::StatefulEngineOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Configuration settings for the handling of the stateful rule groups in a firewall policy.
Updating any setting in StatefulEngineOptions may require a restart
of the stateful engine in order to apply the changes. When this
occurs, existing connections will be treated according to your stream
exception policy configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_timeouts ⇒ Types::FlowTimeouts
Configures the amount of time that can pass without any traffic sent through the firewall before the firewall determines that the connection is idle.
-
#rule_order ⇒ String
Indicates how to manage the order of stateful rule evaluation for the policy.
-
#stream_exception_policy ⇒ String
Configures how Network Firewall processes traffic when a network connection breaks midstream.
Instance Attribute Details
#flow_timeouts ⇒ Types::FlowTimeouts
Configures the amount of time that can pass without any traffic sent through the firewall before the firewall determines that the connection is idle.
7845 7846 7847 7848 7849 7850 7851 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7845 class StatefulEngineOptions < Struct.new( :rule_order, :stream_exception_policy, :flow_timeouts) SENSITIVE = [] include Aws::Structure end |
#rule_order ⇒ String
Indicates how to manage the order of stateful rule evaluation for
the policy. STRICT_ORDER is the recommended option, but
DEFAULT_ACTION_ORDER is the default option. With STRICT_ORDER,
provide your rules in the order that you want them to be evaluated.
You can then choose one or more default actions for packets that
don't match any rules. Choose STRICT_ORDER to have the stateful
rules engine determine the evaluation order of your rules. The
default action for this rule order is PASS, followed by DROP,
REJECT, and ALERT actions. Stateful rules are provided to the
rule engine as Suricata compatible strings, and Suricata evaluates
them based on your settings. For more information, see Evaluation
order for stateful rules in the Network Firewall Developer
Guide.
7845 7846 7847 7848 7849 7850 7851 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7845 class StatefulEngineOptions < Struct.new( :rule_order, :stream_exception_policy, :flow_timeouts) SENSITIVE = [] include Aws::Structure end |
#stream_exception_policy ⇒ String
Configures how Network Firewall processes traffic when a network connection breaks midstream. Network connections can break due to disruptions in external networks or within the firewall itself.
-
DROP- Network Firewall fails closed and drops all subsequent traffic going to the firewall. This is the default behavior. -
CONTINUE- Network Firewall continues to apply rules to the subsequent traffic without context from traffic before the break. This impacts the behavior of rules that depend on this context. For example, if you have a stateful rule todrop httptraffic, Network Firewall won't match the traffic for this rule because the service won't have the context from session initialization defining the application layer protocol as HTTP. However, this behavior is rule dependent—a TCP-layer rule using aflow:statelessrule would still match, as would theaws:drop_strictdefault action. -
REJECT- Network Firewall fails closed and drops all subsequent traffic going to the firewall. Network Firewall also sends a TCP reject packet back to your client so that the client can immediately establish a new session. Network Firewall will have context about the new session and will apply rules to the subsequent traffic.
7845 7846 7847 7848 7849 7850 7851 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7845 class StatefulEngineOptions < Struct.new( :rule_order, :stream_exception_policy, :flow_timeouts) SENSITIVE = [] include Aws::Structure end |