Class: Aws::NetworkFirewall::Types::SubnetMapping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

The ID for a subnet that's used in an association with a firewall. This is used in CreateFirewall, AssociateSubnets, and CreateVpcEndpointAssociation. Network Firewall creates an instance of the associated firewall in each subnet that you specify, to filter traffic in the subnet's Availability Zone.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ip_address_type ⇒ String

The subnet's IP address type. You can't change the IP address type after you create the subnet.

Returns:

  • (String)


8114
8115
8116
8117
8118
8119
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8114

class SubnetMapping < Struct.new(
  :subnet_id,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_id ⇒ String

The unique identifier for the subnet.

Returns:

  • (String)


8114
8115
8116
8117
8118
8119
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8114

class SubnetMapping < Struct.new(
  :subnet_id,
  :ip_address_type)
  SENSITIVE = []
  include Aws::Structure
end