Class: Aws::NetworkFirewall::Types::SummaryConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

A complex type that specifies which Suricata rule metadata fields to use when displaying threat information. Contains:

  • RuleOptions - The Suricata rule options fields to extract and display

^

These settings affect how threat information appears in both the console and API responses. Summaries are available for rule groups you manage and for active threat defense Amazon Web Services managed rule groups.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#rule_options ⇒ Array<String>

Specifies the selected rule options returned by DescribeRuleGroupSummary.

Returns:

  • (Array<String>)


8161
8162
8163
8164
8165
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8161

class SummaryConfiguration < Struct.new(
  :rule_options)
  SENSITIVE = []
  include Aws::Structure
end