Class: Aws::NetworkFirewall::Types::SyncState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

The status of the firewall endpoint and firewall policy configuration for a single VPC subnet. This is part of the FirewallStatus.

For each VPC subnet that you associate with a firewall, Network Firewall does the following:

  • Instantiates a firewall endpoint in the subnet, ready to take traffic.

  • Configures the endpoint with the current firewall policy settings, to provide the filtering behavior for the endpoint.

When you update a firewall, for example to add a subnet association or change a rule group in the firewall policy, the affected sync states reflect out-of-sync or not ready status until the changes are complete.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attachment ⇒ Types::Attachment

The configuration and status for a single firewall subnet. For each configured subnet, Network Firewall creates the attachment by instantiating the firewall endpoint in the subnet so that it's ready to take traffic.

Returns:



8208
8209
8210
8211
8212
8213
8214
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8208

class SyncState < Struct.new(
  :attachment,
  :config,
  :nat_gateway_attachments)
  SENSITIVE = []
  include Aws::Structure
end

#config ⇒ Hash<String,Types::PerObjectStatus>

The configuration status of the firewall endpoint in a single VPC subnet. Network Firewall provides each endpoint with the rules that are configured in the firewall policy. Each time you add a subnet or modify the associated firewall policy, Network Firewall synchronizes the rules in the endpoint, so it can properly filter network traffic.

Returns:



8208
8209
8210
8211
8212
8213
8214
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8208

class SyncState < Struct.new(
  :attachment,
  :config,
  :nat_gateway_attachments)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_attachments ⇒ Array<Types::NatGatewayAttachment>

The status of the NAT gateway attachments for a proxy mode firewall in the Availability Zone. This reflects the attachment of the firewall to each NAT gateway that proxies its traffic.

Returns:



8208
8209
8210
8211
8212
8213
8214
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8208

class SyncState < Struct.new(
  :attachment,
  :config,
  :nat_gateway_attachments)
  SENSITIVE = []
  include Aws::Structure
end