Class: Aws::NetworkFirewall::Types::TransitGatewayAttachmentSyncState
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::TransitGatewayAttachmentSyncState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Contains information about the synchronization state of a transit gateway attachment, including its current status and any error messages. Network Firewall uses this to track the state of your transit gateway configuration changes.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The unique identifier of the transit gateway attachment.
-
#status_message ⇒ String
A message providing additional information about the current status, particularly useful when the transit gateway attachment is in a non-
READYstate. -
#transit_gateway_attachment_status ⇒ String
The current status of the transit gateway attachment.
Instance Attribute Details
#attachment_id ⇒ String
The unique identifier of the transit gateway attachment.
8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8597 class TransitGatewayAttachmentSyncState < Struct.new( :attachment_id, :transit_gateway_attachment_status, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message providing additional information about the current status,
particularly useful when the transit gateway attachment is in a
non-READY state.
Valid values are:
-
CREATING- The attachment is being created -
DELETING- The attachment is being deleted -
DELETED- The attachment has been deleted -
FAILED- The attachment creation has failed and cannot be recovered -
ERROR- The attachment is in an error state that might be recoverable -
READY- The attachment is active and processing traffic -
PENDING_ACCEPTANCE- The attachment is waiting to be accepted -
REJECTING- The attachment is in the process of being rejected -
REJECTED- The attachment has been rejected
For information about troubleshooting endpoint failures, see Troubleshooting firewall endpoint failures in the Network Firewall Developer Guide.
8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8597 class TransitGatewayAttachmentSyncState < Struct.new( :attachment_id, :transit_gateway_attachment_status, :status_message) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_status ⇒ String
The current status of the transit gateway attachment.
Valid values are:
-
CREATING- The attachment is being created -
DELETING- The attachment is being deleted -
DELETED- The attachment has been deleted -
FAILED- The attachment creation has failed and cannot be recovered -
ERROR- The attachment is in an error state that might be recoverable -
READY- The attachment is active and processing traffic -
PENDING_ACCEPTANCE- The attachment is waiting to be accepted -
REJECTING- The attachment is in the process of being rejected -
REJECTED- The attachment has been rejected
8597 8598 8599 8600 8601 8602 8603 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8597 class TransitGatewayAttachmentSyncState < Struct.new( :attachment_id, :transit_gateway_attachment_status, :status_message) SENSITIVE = [] include Aws::Structure end |