Class: Aws::NetworkFirewall::Types::UpdateContainerAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_association_arn ⇒ String

The Amazon Resource Name (ARN) of the container association.

You must specify the ARN or the name, and you can specify both.



8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8807

class UpdateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#container_association_name ⇒ String

The descriptive name of the container association.

You must specify the ARN or the name, and you can specify both.



8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8807

class UpdateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#container_monitoring_configurations ⇒ Array<Types::ContainerMonitoringConfiguration>

The updated monitoring configurations for the container association. Each configuration specifies an Amazon ECS or Amazon EKS cluster to monitor and optional attribute filters.



8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8807

class UpdateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A description of the container association. When omitted, the existing description remains unchanged. To clear the description, pass an empty string.



8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8807

class UpdateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The key:value pairs to associate with the resource.



8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8807

class UpdateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The container type. This value must match the existing type and can't be changed. Valid values:

  • ECS - Amazon Elastic Container Service

  • EKS - Amazon Elastic Kubernetes Service



8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8807

class UpdateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#update_token ⇒ String

A token used for optimistic locking. Network Firewall returns a token to your requests that access the container association. The token marks the state of the container association resource at the time of the request.

To make changes to the container association, you provide the token in your request. Network Firewall uses the token to ensure that the container association hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the container association again to get a current copy of it with a current token. Reapply your changes as needed, then try the operation again using the new token.



8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8807

class UpdateContainerAssociationRequest < Struct.new(
  :container_association_name,
  :container_association_arn,
  :description,
  :type,
  :container_monitoring_configurations,
  :tags,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end