Class: Aws::NetworkFirewall::Types::UpdateFirewallEncryptionConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_configuration ⇒ Types::EncryptionConfiguration

A complex type that contains optional Amazon Web Services Key Management Service (KMS) encryption settings for your Network Firewall resources. Your data is encrypted by default with an Amazon Web Services owned key that Amazon Web Services owns and manages for you. You can use either the Amazon Web Services owned key, or provide your own customer managed key. To learn more about KMS encryption of your Network Firewall resources, see Encryption at rest with Amazon Web Services Key Managment Service in the Network Firewall Developer Guide.



9220
9221
9222
9223
9224
9225
9226
9227
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9220

class UpdateFirewallEncryptionConfigurationRequest < Struct.new(
  :update_token,
  :firewall_arn,
  :firewall_name,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9220

class UpdateFirewallEncryptionConfigurationRequest < Struct.new(
  :update_token,
  :firewall_arn,
  :firewall_name,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_name ⇒ String

The descriptive name of the firewall. You can't change the name of a firewall after you create it.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9220

class UpdateFirewallEncryptionConfigurationRequest < Struct.new(
  :update_token,
  :firewall_arn,
  :firewall_name,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#update_token ⇒ String

An optional token that you can use for optimistic locking. Network Firewall returns a token to your requests that access the firewall. The token marks the state of the firewall resource at the time of the request.

To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it.

To make a conditional change to the firewall, provide the token in your update request. Network Firewall uses the token to ensure that the firewall hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token.

Returns:

  • (String)


9220
9221
9222
9223
9224
9225
9226
9227
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9220

class UpdateFirewallEncryptionConfigurationRequest < Struct.new(
  :update_token,
  :firewall_arn,
  :firewall_name,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end