Class: Aws::NetworkFirewall::Types::UpdateFirewallPolicyChangeProtectionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::UpdateFirewallPolicyChangeProtectionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
-
#firewall_name ⇒ String
The descriptive name of the firewall.
-
#firewall_policy_change_protection ⇒ Boolean
A setting indicating whether the firewall is protected against a change to the firewall policy association.
-
#update_token ⇒ String
An optional token that you can use for optimistic locking.
Instance Attribute Details
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
8718 8719 8720 8721 8722 8723 8724 8725 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8718 class UpdateFirewallPolicyChangeProtectionResponse < Struct.new( :update_token, :firewall_arn, :firewall_name, :firewall_policy_change_protection) SENSITIVE = [] include Aws::Structure end |
#firewall_name ⇒ String
The descriptive name of the firewall. You can’t change the name of a firewall after you create it.
8718 8719 8720 8721 8722 8723 8724 8725 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8718 class UpdateFirewallPolicyChangeProtectionResponse < Struct.new( :update_token, :firewall_arn, :firewall_name, :firewall_policy_change_protection) SENSITIVE = [] include Aws::Structure end |
#firewall_policy_change_protection ⇒ Boolean
A setting indicating whether the firewall is protected against a change to the firewall policy association. Use this setting to protect against accidentally modifying the firewall policy for a firewall that is in use. When you create a firewall, the operation initializes this setting to TRUE.
8718 8719 8720 8721 8722 8723 8724 8725 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8718 class UpdateFirewallPolicyChangeProtectionResponse < Struct.new( :update_token, :firewall_arn, :firewall_name, :firewall_policy_change_protection) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
An optional token that you can use for optimistic locking. Network Firewall returns a token to your requests that access the firewall. The token marks the state of the firewall resource at the time of the request.
To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it.
To make a conditional change to the firewall, provide the token in your update request. Network Firewall uses the token to ensure that the firewall hasn’t changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token.
8718 8719 8720 8721 8722 8723 8724 8725 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8718 class UpdateFirewallPolicyChangeProtectionResponse < Struct.new( :update_token, :firewall_arn, :firewall_name, :firewall_policy_change_protection) SENSITIVE = [] include Aws::Structure end |