Class: Aws::NetworkFirewall::Types::UpdateProxyConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::UpdateProxyConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_rule_phase_actions ⇒ Types::ProxyConfigDefaultRulePhaseActionsRequest
Evaluation points in the traffic flow where rules are applied.
-
#proxy_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy configuration.
-
#proxy_configuration_name ⇒ String
The descriptive name of the proxy configuration.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#default_rule_phase_actions ⇒ Types::ProxyConfigDefaultRulePhaseActionsRequest
Evaluation points in the traffic flow where rules are applied. There are three phases in a traffic where the rule match is applied.
9599 9600 9601 9602 9603 9604 9605 9606 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9599 class UpdateProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :default_rule_phase_actions, :update_token) SENSITIVE = [] include Aws::Structure end |
#proxy_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy configuration.
You must specify the ARN or the name, and you can specify both.
9599 9600 9601 9602 9603 9604 9605 9606 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9599 class UpdateProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :default_rule_phase_actions, :update_token) SENSITIVE = [] include Aws::Structure end |
#proxy_configuration_name ⇒ String
The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.
You must specify the ARN or the name, and you can specify both.
9599 9600 9601 9602 9603 9604 9605 9606 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9599 class UpdateProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :default_rule_phase_actions, :update_token) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the proxy configuration. The token marks the state of the proxy configuration resource at the time of the request.
To make changes to the proxy configuration, you provide the token in
your request. Network Firewall uses the token to ensure that the
proxy configuration hasn't changed since you last retrieved it. If
it has changed, the operation fails with an InvalidTokenException.
If this happens, retrieve the proxy configuration again to get a
current copy of it with a current token. Reapply your changes as
needed, then try the operation again using the new token.
9599 9600 9601 9602 9603 9604 9605 9606 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9599 class UpdateProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :default_rule_phase_actions, :update_token) SENSITIVE = [] include Aws::Structure end |