Class: Aws::NetworkFirewall::Types::UpdateProxyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#listener_properties_to_add ⇒ Array<Types::ListenerPropertyRequest>

Listener properties for HTTP and HTTPS traffic to add.

Returns:



9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9683

class UpdateProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn,
  :listener_properties_to_add,
  :listener_properties_to_remove,
  :tls_intercept_properties,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#listener_properties_to_remove ⇒ Array<Types::ListenerPropertyRequest>

Listener properties for HTTP and HTTPS traffic to remove.

Returns:



9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9683

class UpdateProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn,
  :listener_properties_to_add,
  :listener_properties_to_remove,
  :tls_intercept_properties,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#nat_gateway_id ⇒ String

The NAT Gateway the proxy is attached to.

Returns:

  • (String)


9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9683

class UpdateProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn,
  :listener_properties_to_add,
  :listener_properties_to_remove,
  :tls_intercept_properties,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_arn ⇒ String

The Amazon Resource Name (ARN) of a proxy.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9683

class UpdateProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn,
  :listener_properties_to_add,
  :listener_properties_to_remove,
  :tls_intercept_properties,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_name ⇒ String

The descriptive name of the proxy. You can't change the name of a proxy after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9683

class UpdateProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn,
  :listener_properties_to_add,
  :listener_properties_to_remove,
  :tls_intercept_properties,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#tls_intercept_properties ⇒ Types::TlsInterceptPropertiesRequest

TLS decryption on traffic to filter on attributes in the HTTP header.



9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9683

class UpdateProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn,
  :listener_properties_to_add,
  :listener_properties_to_remove,
  :tls_intercept_properties,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end

#update_token ⇒ String

A token used for optimistic locking. Network Firewall returns a token to your requests that access the proxy. The token marks the state of the proxy resource at the time of the request.

To make changes to the proxy, you provide the token in your request. Network Firewall uses the token to ensure that the proxy hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the proxy again to get a current copy of it with a current token. Reapply your changes as needed, then try the operation again using the new token.

Returns:

  • (String)


9683
9684
9685
9686
9687
9688
9689
9690
9691
9692
9693
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9683

class UpdateProxyRequest < Struct.new(
  :nat_gateway_id,
  :proxy_name,
  :proxy_arn,
  :listener_properties_to_add,
  :listener_properties_to_remove,
  :tls_intercept_properties,
  :update_token)
  SENSITIVE = []
  include Aws::Structure
end