Class: Aws::NetworkFirewall::Types::UpdateProxyRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::UpdateProxyRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
Depending on the match action, the proxy either stops the evaluation (if the action is terminal - allow or deny), or continues it (if the action is alert) until it matches a rule with a terminal action.
-
#add_conditions ⇒ Array<Types::ProxyRuleCondition>
Proxy rule conditions to add.
-
#description ⇒ String
A description of the proxy rule.
-
#proxy_rule_group_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy rule group.
-
#proxy_rule_group_name ⇒ String
The descriptive name of the proxy rule group.
-
#proxy_rule_name ⇒ String
The descriptive name of the proxy rule.
-
#remove_conditions ⇒ Array<Types::ProxyRuleCondition>
Proxy rule conditions to remove.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#action ⇒ String
Depending on the match action, the proxy either stops the evaluation (if the action is terminal - allow or deny), or continues it (if the action is alert) until it matches a rule with a terminal action.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#add_conditions ⇒ Array<Types::ProxyRuleCondition>
Proxy rule conditions to add. Match criteria that specify what traffic attributes to examine. Conditions include operators (StringEquals, StringLike) and values to match against.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the proxy rule.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#proxy_rule_group_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy rule group.
You must specify the ARN or the name, and you can specify both.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#proxy_rule_group_name ⇒ String
The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.
You must specify the ARN or the name, and you can specify both.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#proxy_rule_name ⇒ String
The descriptive name of the proxy rule. You can't change the name of a proxy rule after you create it.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#remove_conditions ⇒ Array<Types::ProxyRuleCondition>
Proxy rule conditions to remove. Match criteria that specify what traffic attributes to examine. Conditions include operators (StringEquals, StringLike) and values to match against.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the proxy rule. The token marks the state of the proxy rule resource at the time of the request.
To make changes to the proxy rule, you provide the token in your
request. Network Firewall uses the token to ensure that the proxy
rule hasn't changed since you last retrieved it. If it has changed,
the operation fails with an InvalidTokenException. If this
happens, retrieve the proxy rule again to get a current copy of it
with a current token. Reapply your changes as needed, then try the
operation again using the new token.
9946 9947 9948 9949 9950 9951 9952 9953 9954 9955 9956 9957 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9946 class UpdateProxyRuleRequest < Struct.new( :proxy_rule_group_name, :proxy_rule_group_arn, :proxy_rule_name, :description, :action, :add_conditions, :remove_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |