Class: Aws::NetworkFirewall::Types::UpdateProxyRuleResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::UpdateProxyRuleResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#proxy_rule ⇒ Types::ProxyRule
The updated proxy rule resource that reflects the updates from the request.
-
#removed_conditions ⇒ Array<Types::ProxyRuleCondition>
Proxy rule conditions removed from the rule.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#proxy_rule ⇒ Types::ProxyRule
The updated proxy rule resource that reflects the updates from the request.
9984 9985 9986 9987 9988 9989 9990 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9984 class UpdateProxyRuleResponse < Struct.new( :proxy_rule, :removed_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#removed_conditions ⇒ Array<Types::ProxyRuleCondition>
Proxy rule conditions removed from the rule.
9984 9985 9986 9987 9988 9989 9990 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9984 class UpdateProxyRuleResponse < Struct.new( :proxy_rule, :removed_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the proxy rule. The token marks the state of the proxy rule resource at the time of the request.
To make changes to the proxy rule, you provide the token in your
request. Network Firewall uses the token to ensure that the proxy
rule hasn't changed since you last retrieved it. If it has changed,
the operation fails with an InvalidTokenException. If this
happens, retrieve the proxy rule again to get a current copy of it
with a current token. Reapply your changes as needed, then try the
operation again using the new token.
9984 9985 9986 9987 9988 9989 9990 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9984 class UpdateProxyRuleResponse < Struct.new( :proxy_rule, :removed_conditions, :update_token) SENSITIVE = [] include Aws::Structure end |