Class: Aws::NetworkFirewall::Types::UpdateProxySettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#firewall_arn ⇒ String

The Amazon Resource Name (ARN) of the firewall.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


10033
10034
10035
10036
10037
10038
10039
10040
# File 'lib/aws-sdk-networkfirewall/types.rb', line 10033

class UpdateProxySettingsRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :update_token,
  :proxy_settings)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_name ⇒ String

The descriptive name of the firewall. You can't change the name of a firewall after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


10033
10034
10035
10036
10037
10038
10039
10040
# File 'lib/aws-sdk-networkfirewall/types.rb', line 10033

class UpdateProxySettingsRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :update_token,
  :proxy_settings)
  SENSITIVE = []
  include Aws::Structure
end

#proxy_settings ⇒ Types::ProxySettings

The proxy listener configuration to set on the firewall. This specifies the ports and protocols on which the firewall's proxy listens for traffic.



10033
10034
10035
10036
10037
10038
10039
10040
# File 'lib/aws-sdk-networkfirewall/types.rb', line 10033

class UpdateProxySettingsRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :update_token,
  :proxy_settings)
  SENSITIVE = []
  include Aws::Structure
end

#update_token ⇒ String

An optional token that you can use for optimistic locking. Network Firewall returns a token to your requests that access the firewall. The token marks the state of the firewall resource at the time of the request.

To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it.

To make a conditional change to the firewall, provide the token in your update request. Network Firewall uses the token to ensure that the firewall hasn't changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token.

Returns:

  • (String)


10033
10034
10035
10036
10037
10038
10039
10040
# File 'lib/aws-sdk-networkfirewall/types.rb', line 10033

class UpdateProxySettingsRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :update_token,
  :proxy_settings)
  SENSITIVE = []
  include Aws::Structure
end