Class: Aws::NetworkFirewall::Types::VpcEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::VpcEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
The VPC and subnets for a proxy mode firewall endpoint. This is used
in CreateFirewall when NoSourcePreservation is TRUE, to specify
where Network Firewall creates the firewall endpoint.
This differs from VpcEndpointAssociation, which defines additional secondary endpoints for a firewall in other VPCs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#subnet_mappings ⇒ Array<Types::SubnetMapping>
The subnets in which Network Firewall creates the firewall endpoint for a proxy mode firewall.
-
#vpc_id ⇒ String
The unique identifier of the VPC where Network Firewall creates the proxy mode firewall endpoint.
Instance Attribute Details
#subnet_mappings ⇒ Array<Types::SubnetMapping>
The subnets in which Network Firewall creates the firewall endpoint for a proxy mode firewall. Each subnet must belong to a different Availability Zone in the VPC.
10467 10468 10469 10470 10471 10472 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 10467 class VpcEndpoint < Struct.new( :vpc_id, :subnet_mappings) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The unique identifier of the VPC where Network Firewall creates the proxy mode firewall endpoint.
10467 10468 10469 10470 10471 10472 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 10467 class VpcEndpoint < Struct.new( :vpc_id, :subnet_mappings) SENSITIVE = [] include Aws::Structure end |