Class: Aws::NetworkFirewall::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NetworkFirewall::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-networkfirewall/client.rb
Overview
An API client for NetworkFirewall. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::NetworkFirewall::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
-
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall.
-
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
-
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
-
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
-
#create_tls_inspection_configuration(params = {}) ⇒ Types::CreateTLSInspectionConfigurationResponse
Creates an Network Firewall TLS inspection configuration.
-
#create_vpc_endpoint_association(params = {}) ⇒ Types::CreateVpcEndpointAssociationResponse
Creates a firewall endpoint for an Network Firewall firewall.
-
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus.
-
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
-
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
-
#delete_tls_inspection_configuration(params = {}) ⇒ Types::DeleteTLSInspectionConfigurationResponse
Deletes the specified TLSInspectionConfiguration.
-
#delete_vpc_endpoint_association(params = {}) ⇒ Types::DeleteVpcEndpointAssociationResponse
Deletes the specified VpcEndpointAssociation.
-
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
-
#describe_firewall_metadata(params = {}) ⇒ Types::DescribeFirewallMetadataResponse
Returns the high-level information about a firewall, including the Availability Zones where the Firewall is currently in use.
-
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
-
#describe_flow_operation(params = {}) ⇒ Types::DescribeFlowOperationResponse
Returns key information about a specific flow operation.
-
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
-
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
-
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
-
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe.
-
#describe_tls_inspection_configuration(params = {}) ⇒ Types::DescribeTLSInspectionConfigurationResponse
Returns the data objects for the specified TLS inspection configuration.
-
#describe_vpc_endpoint_association(params = {}) ⇒ Types::DescribeVpcEndpointAssociationResponse
Returns the data object for the specified VPC endpoint association.
-
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall.
-
#get_analysis_report_results(params = {}) ⇒ Types::GetAnalysisReportResultsResponse
The results of a ‘COMPLETED` analysis report generated with StartAnalysisReport.
-
#list_analysis_reports(params = {}) ⇒ Types::ListAnalysisReportsResponse
Returns a list of all traffic analysis reports generated within the last 30 days.
-
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined.
-
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined.
-
#list_flow_operation_results(params = {}) ⇒ Types::ListFlowOperationResultsResponse
Returns the results of a specific flow operation.
-
#list_flow_operations(params = {}) ⇒ Types::ListFlowOperationsResponse
Returns a list of all flow operations ran in a specific firewall.
-
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource.
-
#list_tls_inspection_configurations(params = {}) ⇒ Types::ListTLSInspectionConfigurationsResponse
Retrieves the metadata for the TLS inspection configurations that you have defined.
-
#list_vpc_endpoint_associations(params = {}) ⇒ Types::ListVpcEndpointAssociationsResponse
Retrieves the metadata for the VPC endpoint associations that you have defined.
-
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group, firewall policy, or firewall.
-
#start_analysis_report(params = {}) ⇒ Types::StartAnalysisReportResponse
Generates a traffic analysis report for the timeframe and traffic type you specify.
-
#start_flow_capture(params = {}) ⇒ Types::StartFlowCaptureResponse
Begins capturing the flows in a firewall, according to the filters you define.
-
#start_flow_flush(params = {}) ⇒ Types::StartFlowFlushResponse
Begins the flushing of traffic from the firewall, according to the filters you define.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource.
-
#update_firewall_analysis_settings(params = {}) ⇒ Types::UpdateFirewallAnalysisSettingsResponse
Enables specific types of firewall analysis on a specific firewall you define.
-
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag, ‘DeleteProtection`, which indicates whether it is possible to delete the firewall.
-
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall.
-
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
-
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
-
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag, ‘ChangeProtection`, which indicates whether it is possible to change the firewall.
-
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
-
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group.
-
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:.
-
#update_tls_inspection_configuration(params = {}) ⇒ Types::UpdateTLSInspectionConfigurationResponse
Updates the TLS inspection configuration settings for the specified TLS inspection configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4715 4716 4717 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4715 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4718 4719 4720 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4718 def errors_module Errors end |
Instance Method Details
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
A firewall policy defines how to monitor and manage your VPC network traffic, using a collection of inspection rule groups and other settings. Each firewall requires one firewall policy association, and you can use the same firewall policy for multiple firewalls.
546 547 548 549 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 546 def associate_firewall_policy(params = {}, = {}) req = build_request(:associate_firewall_policy, params) req.send_request() end |
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall. You can specify one subnet for each of the Availability Zones that the VPC spans.
This request creates an Network Firewall firewall endpoint in each of the subnets. To enable the firewall’s protections, you must also modify the VPC’s route tables for each subnet’s Availability Zone, to redirect the traffic that’s coming into and going out of the zone through the firewall endpoint.
628 629 630 631 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 628 def associate_subnets(params = {}, = {}) req = build_request(:associate_subnets, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4688 4689 4690 4691 4692 4693 4694 4695 4696 4697 4698 4699 4700 4701 4702 4703 4704 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4688 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NetworkFirewall') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-networkfirewall' context[:gem_version] = '1.67.0' Seahorse::Client::Request.new(handlers, context) end |
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
The firewall defines the configuration settings for an Network Firewall firewall. The settings that you can define at creation include the firewall policy, the subnets in your VPC to use for the firewall endpoints, and any tags that are attached to the firewall Amazon Web Services resource.
After you create a firewall, you can provide additional settings, like the logging configuration.
To update the settings for a firewall, you use the operations that apply to the settings themselves, for example UpdateLoggingConfiguration, AssociateSubnets, and UpdateFirewallDeleteProtection.
To manage a firewall’s tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about firewalls, use ListFirewalls and DescribeFirewall.
To generate a report on the last 30 days of traffic monitored by a firewall, use StartAnalysisReport.
789 790 791 792 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 789 def create_firewall(params = {}, = {}) req = build_request(:create_firewall, params) req.send_request() end |
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
An Network Firewall firewall policy defines the behavior of a firewall, in a collection of stateless and stateful rule groups and other settings. You can use one firewall policy for multiple firewalls.
928 929 930 931 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 928 def create_firewall_policy(params = {}, = {}) req = build_request(:create_firewall_policy, params) req.send_request() end |
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
You provide your rule group specification in your request using either ‘RuleGroup` or `Rules`.
1225 1226 1227 1228 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1225 def create_rule_group(params = {}, = {}) req = build_request(:create_rule_group, params) req.send_request() end |
#create_tls_inspection_configuration(params = {}) ⇒ Types::CreateTLSInspectionConfigurationResponse
Creates an Network Firewall TLS inspection configuration. Network Firewall uses TLS inspection configurations to decrypt your firewall’s inbound and outbound SSL/TLS traffic. After decryption, Network Firewall inspects the traffic according to your firewall policy’s stateful rules, and then re-encrypts it before sending it to its destination. You can enable inspection of your firewall’s inbound traffic, outbound traffic, or both. To use TLS inspection with your firewall, you must first import or provision certificates using ACM, create a TLS inspection configuration, add that configuration to a new firewall policy, and then associate that policy with your firewall.
To update the settings for a TLS inspection configuration, use UpdateTLSInspectionConfiguration.
To manage a TLS inspection configuration’s tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about TLS inspection configurations, use ListTLSInspectionConfigurations and DescribeTLSInspectionConfiguration.
For more information about TLS inspection configurations, see
- Inspecting SSL/TLS traffic with TLS inspection configurations][1
-
in
the *Network Firewall Developer Guide*.
[1]: docs.aws.amazon.com/network-firewall/latest/developerguide/tls-inspection.html
1403 1404 1405 1406 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1403 def create_tls_inspection_configuration(params = {}, = {}) req = build_request(:create_tls_inspection_configuration, params) req.send_request() end |
#create_vpc_endpoint_association(params = {}) ⇒ Types::CreateVpcEndpointAssociationResponse
Creates a firewall endpoint for an Network Firewall firewall. This type of firewall endpoint is independent of the firewall endpoints that you specify in the ‘Firewall` itself, and you define it in addition to those endpoints after the firewall has been created. You can define a VPC endpoint association using a different VPC than the one you used in the firewall specifications.
1481 1482 1483 1484 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1481 def create_vpc_endpoint_association(params = {}, = {}) req = build_request(:create_vpc_endpoint_association, params) req.send_request() end |
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus. This operation requires the firewall’s ‘DeleteProtection` flag to be `FALSE`. You can’t revert this operation.
You can check whether a firewall is in use by reviewing the route tables for the Availability Zones where you have firewall subnet mappings. Retrieve the subnet mappings by calling DescribeFirewall. You define and update the route tables through Amazon VPC. As needed, update the route tables for the zones to remove the firewall endpoints. When the route tables no longer use the firewall endpoints, you can remove the firewall safely.
To delete a firewall, remove the delete protection if you need to using UpdateFirewallDeleteProtection, then delete the firewall by calling DeleteFirewall.
1566 1567 1568 1569 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1566 def delete_firewall(params = {}, = {}) req = build_request(:delete_firewall, params) req.send_request() end |
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
1616 1617 1618 1619 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1616 def delete_firewall_policy(params = {}, = {}) req = build_request(:delete_firewall_policy, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
1640 1641 1642 1643 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1640 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
1710 1711 1712 1713 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1710 def delete_rule_group(params = {}, = {}) req = build_request(:delete_rule_group, params) req.send_request() end |
#delete_tls_inspection_configuration(params = {}) ⇒ Types::DeleteTLSInspectionConfigurationResponse
Deletes the specified TLSInspectionConfiguration.
1767 1768 1769 1770 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1767 def delete_tls_inspection_configuration(params = {}, = {}) req = build_request(:delete_tls_inspection_configuration, params) req.send_request() end |
#delete_vpc_endpoint_association(params = {}) ⇒ Types::DeleteVpcEndpointAssociationResponse
Deletes the specified VpcEndpointAssociation.
You can check whether an endpoint association is in use by reviewing the route tables for the Availability Zones where you have the endpoint subnet mapping. You can retrieve the subnet mapping by calling DescribeVpcEndpointAssociation. You define and update the route tables through Amazon VPC. As needed, update the route tables for the Availability Zone to remove the firewall endpoint for the association. When the route tables no longer use the firewall endpoint, you can remove the endpoint association safely.
1820 1821 1822 1823 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1820 def delete_vpc_endpoint_association(params = {}, = {}) req = build_request(:delete_vpc_endpoint_association, params) req.send_request() end |
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
1893 1894 1895 1896 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1893 def describe_firewall(params = {}, = {}) req = build_request(:describe_firewall, params) req.send_request() end |
#describe_firewall_metadata(params = {}) ⇒ Types::DescribeFirewallMetadataResponse
Returns the high-level information about a firewall, including the Availability Zones where the Firewall is currently in use.
1931 1932 1933 1934 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1931 def (params = {}, = {}) req = build_request(:describe_firewall_metadata, params) req.send_request() end |
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
2008 2009 2010 2011 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2008 def describe_firewall_policy(params = {}, = {}) req = build_request(:describe_firewall_policy, params) req.send_request() end |
#describe_flow_operation(params = {}) ⇒ Types::DescribeFlowOperationResponse
Returns key information about a specific flow operation.
2084 2085 2086 2087 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2084 def describe_flow_operation(params = {}, = {}) req = build_request(:describe_flow_operation, params) req.send_request() end |
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
2127 2128 2129 2130 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2127 def describe_logging_configuration(params = {}, = {}) req = build_request(:describe_logging_configuration, params) req.send_request() end |
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
2157 2158 2159 2160 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2157 def describe_resource_policy(params = {}, = {}) req = build_request(:describe_resource_policy, params) req.send_request() end |
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
2288 2289 2290 2291 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2288 def describe_rule_group(params = {}, = {}) req = build_request(:describe_rule_group, params) req.send_request() end |
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe. You can use the information provided in the metadata to retrieve and manage a rule group. You can retrieve all objects for a rule group by calling DescribeRuleGroup.
2352 2353 2354 2355 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2352 def (params = {}, = {}) req = build_request(:describe_rule_group_metadata, params) req.send_request() end |
#describe_tls_inspection_configuration(params = {}) ⇒ Types::DescribeTLSInspectionConfigurationResponse
Returns the data objects for the specified TLS inspection configuration.
2432 2433 2434 2435 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2432 def describe_tls_inspection_configuration(params = {}, = {}) req = build_request(:describe_tls_inspection_configuration, params) req.send_request() end |
#describe_vpc_endpoint_association(params = {}) ⇒ Types::DescribeVpcEndpointAssociationResponse
Returns the data object for the specified VPC endpoint association.
2476 2477 2478 2479 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2476 def describe_vpc_endpoint_association(params = {}, = {}) req = build_request(:describe_vpc_endpoint_association, params) req.send_request() end |
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall. This removes the firewall endpoints from the subnets and removes any network filtering protections that the endpoints were providing.
2547 2548 2549 2550 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2547 def disassociate_subnets(params = {}, = {}) req = build_request(:disassociate_subnets, params) req.send_request() end |
#get_analysis_report_results(params = {}) ⇒ Types::GetAnalysisReportResultsResponse
The results of a ‘COMPLETED` analysis report generated with StartAnalysisReport.
For more information, see AnalysisTypeReportResult.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2627 2628 2629 2630 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2627 def get_analysis_report_results(params = {}, = {}) req = build_request(:get_analysis_report_results, params) req.send_request() end |
#list_analysis_reports(params = {}) ⇒ Types::ListAnalysisReportsResponse
Returns a list of all traffic analysis reports generated within the last 30 days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2688 2689 2690 2691 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2688 def list_analysis_reports(params = {}, = {}) req = build_request(:list_analysis_reports, params) req.send_request() end |
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined. Depending on your setting for max results and the number of firewall policies, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2735 2736 2737 2738 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2735 def list_firewall_policies(params = {}, = {}) req = build_request(:list_firewall_policies, params) req.send_request() end |
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined. If you provide VPC identifiers in your request, this returns only the firewalls for those VPCs.
Depending on your setting for max results and the number of firewalls, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2791 2792 2793 2794 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2791 def list_firewalls(params = {}, = {}) req = build_request(:list_firewalls, params) req.send_request() end |
#list_flow_operation_results(params = {}) ⇒ Types::ListFlowOperationResultsResponse
Returns the results of a specific flow operation.
Flow operations let you manage the flows tracked in the flow table, also known as the firewall table.
A flow is network traffic that is monitored by a firewall, either by stateful or stateless rules. For traffic to be considered part of a flow, it must share Destination, DestinationPort, Direction, Protocol, Source, and SourcePort.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2893 2894 2895 2896 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2893 def list_flow_operation_results(params = {}, = {}) req = build_request(:list_flow_operation_results, params) req.send_request() end |
#list_flow_operations(params = {}) ⇒ Types::ListFlowOperationsResponse
Returns a list of all flow operations ran in a specific firewall. You can optionally narrow the request scope by specifying the operation type or Availability Zone associated with a firewall’s flow operations.
Flow operations let you manage the flows tracked in the flow table, also known as the firewall table.
A flow is network traffic that is monitored by a firewall, either by stateful or stateless rules. For traffic to be considered part of a flow, it must share Destination, DestinationPort, Direction, Protocol, Source, and SourcePort.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2977 2978 2979 2980 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2977 def list_flow_operations(params = {}, = {}) req = build_request(:list_flow_operations, params) req.send_request() end |
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined. Depending on your setting for max results and the number of rule groups, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3041 3042 3043 3044 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3041 def list_rule_groups(params = {}, = {}) req = build_request(:list_rule_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3146 3147 3148 3149 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3146 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_tls_inspection_configurations(params = {}) ⇒ Types::ListTLSInspectionConfigurationsResponse
Retrieves the metadata for the TLS inspection configurations that you have defined. Depending on your setting for max results and the number of TLS inspection configurations, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3089 3090 3091 3092 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3089 def list_tls_inspection_configurations(params = {}, = {}) req = build_request(:list_tls_inspection_configurations, params) req.send_request() end |
#list_vpc_endpoint_associations(params = {}) ⇒ Types::ListVpcEndpointAssociationsResponse
Retrieves the metadata for the VPC endpoint associations that you have defined. If you specify a fireawll, this returns only the endpoint associations for that firewall.
Depending on your setting for max results and the number of associations, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3202 3203 3204 3205 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3202 def list_vpc_endpoint_associations(params = {}, = {}) req = build_request(:list_vpc_endpoint_associations, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group, firewall policy, or firewall. Use this to share these resources between accounts. This operation works in conjunction with the Amazon Web Services Resource Access Manager (RAM) service to manage resource sharing for Network Firewall.
For information about using sharing with Network Firewall resources, see [Sharing Network Firewall resources] in the *Network Firewall Developer Guide*.
Use this operation to create or update a resource policy for your Network Firewall rule group, firewall policy, or firewall. In the resource policy, you specify the accounts that you want to share the Network Firewall resource with and the operations that you want the accounts to be able to perform.
When you add an account in the resource policy, you then run the following Resource Access Manager (RAM) operations to access and accept the shared resource.
- GetResourceShareInvitations][2
-
Returns the Amazon Resource Names
-
(ARNs) of the resource share invitations.
- AcceptResourceShareInvitation][3
-
Accepts the share invitation
-
for a specified resource share.
For additional information about resource sharing using RAM, see [Resource Access Manager User Guide].
[1]: docs.aws.amazon.com/network-firewall/latest/developerguide/sharing.html [2]: docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareInvitations.html [3]: docs.aws.amazon.com/ram/latest/APIReference/API_AcceptResourceShareInvitation.html [4]: docs.aws.amazon.com/ram/latest/userguide/what-is.html
3294 3295 3296 3297 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3294 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#start_analysis_report(params = {}) ⇒ Types::StartAnalysisReportResponse
Generates a traffic analysis report for the timeframe and traffic type you specify.
For information on the contents of a traffic analysis report, see AnalysisReport.
3339 3340 3341 3342 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3339 def start_analysis_report(params = {}, = {}) req = build_request(:start_analysis_report, params) req.send_request() end |
#start_flow_capture(params = {}) ⇒ Types::StartFlowCaptureResponse
Begins capturing the flows in a firewall, according to the filters you define. Captures are similar, but not identical to snapshots. Capture operations provide visibility into flows that are not closed and are tracked by a firewall’s flow table. Unlike snapshots, captures are a time-boxed view.
A flow is network traffic that is monitored by a firewall, either by stateful or stateless rules. For traffic to be considered part of a flow, it must share Destination, DestinationPort, Direction, Protocol, Source, and SourcePort.
<note markdown=“1”> To avoid encountering operation limits, you should avoid starting captures with broad filters, like wide IP ranges. Instead, we recommend you define more specific criteria with ‘FlowFilters`, like narrow IP ranges, ports, or protocols.
</note>
3432 3433 3434 3435 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3432 def start_flow_capture(params = {}, = {}) req = build_request(:start_flow_capture, params) req.send_request() end |
#start_flow_flush(params = {}) ⇒ Types::StartFlowFlushResponse
Begins the flushing of traffic from the firewall, according to the filters you define. When the operation starts, impacted flows are temporarily marked as timed out before the Suricata engine prunes, or flushes, the flows from the firewall table.
While the flush completes, impacted flows are processed as midstream traffic. This may result in a temporary increase in midstream traffic metrics. We recommend that you double check your stream exception policy before you perform a flush operation.
3512 3513 3514 3515 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3512 def start_flow_flush(params = {}, = {}) req = build_request(:start_flow_flush, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
3550 3551 3552 3553 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3550 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can manage tags for the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
3584 3585 3586 3587 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3584 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_firewall_analysis_settings(params = {}) ⇒ Types::UpdateFirewallAnalysisSettingsResponse
Enables specific types of firewall analysis on a specific firewall you define.
3654 3655 3656 3657 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3654 def update_firewall_analysis_settings(params = {}, = {}) req = build_request(:update_firewall_analysis_settings, params) req.send_request() end |
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag, ‘DeleteProtection`, which indicates whether it is possible to delete the firewall. If the flag is set to `TRUE`, the firewall is protected against deletion. This setting helps protect against accidentally deleting a firewall that’s in use.
3728 3729 3730 3731 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3728 def update_firewall_delete_protection(params = {}, = {}) req = build_request(:update_firewall_delete_protection, params) req.send_request() end |
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall. Use the description to help you identify the firewall when you’re working with it.
3798 3799 3800 3801 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3798 def update_firewall_description(params = {}, = {}) req = build_request(:update_firewall_description, params) req.send_request() end |
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
3878 3879 3880 3881 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3878 def update_firewall_encryption_configuration(params = {}, = {}) req = build_request(:update_firewall_encryption_configuration, params) req.send_request() end |
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
4027 4028 4029 4030 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4027 def update_firewall_policy(params = {}, = {}) req = build_request(:update_firewall_policy, params) req.send_request() end |
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag, ‘ChangeProtection`, which indicates whether it is possible to change the firewall. If the flag is set to `TRUE`, the firewall is protected from changes. This setting helps protect against accidentally changing a firewall that’s in use.
4101 4102 4103 4104 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4101 def update_firewall_policy_change_protection(params = {}, = {}) req = build_request(:update_firewall_policy_change_protection, params) req.send_request() end |
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
To change the logging configuration, retrieve the LoggingConfiguration by calling DescribeLoggingConfiguration, then change it and provide the modified object to this update call. You must change the logging configuration one LogDestinationConfig at a time inside the retrieved LoggingConfiguration object.
You can perform only one of the following actions in any call to ‘UpdateLoggingConfiguration`:
-
Create a new log destination object by adding a single ‘LogDestinationConfig` array element to `LogDestinationConfigs`.
-
Delete a log destination object by removing a single ‘LogDestinationConfig` array element from `LogDestinationConfigs`.
-
Change the ‘LogDestination` setting in a single `LogDestinationConfig` array element.
You can’t change the ‘LogDestinationType` or `LogType` in a `LogDestinationConfig`. To change these settings, delete the existing `LogDestinationConfig` object and create a new one, using two separate calls to this update operation.
4184 4185 4186 4187 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4184 def update_logging_configuration(params = {}, = {}) req = build_request(:update_logging_configuration, params) req.send_request() end |
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group. You use a rule group by reference in one or more firewall policies. When you modify a rule group, you modify all firewall policies that use the rule group.
To update a rule group, first call DescribeRuleGroup to retrieve the current RuleGroup object, update the object as needed, and then provide the updated object to this call.
4451 4452 4453 4454 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4451 def update_rule_group(params = {}, = {}) req = build_request(:update_rule_group, params) req.send_request() end |
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:
-
#update_token => String
-
#firewall_arn => String
-
#firewall_name => String
-
#subnet_change_protection => Boolean
4520 4521 4522 4523 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4520 def update_subnet_change_protection(params = {}, = {}) req = build_request(:update_subnet_change_protection, params) req.send_request() end |
#update_tls_inspection_configuration(params = {}) ⇒ Types::UpdateTLSInspectionConfigurationResponse
Updates the TLS inspection configuration settings for the specified TLS inspection configuration. You use a TLS inspection configuration by referencing it in one or more firewall policies. When you modify a TLS inspection configuration, you modify all firewall policies that use the TLS inspection configuration.
To update a TLS inspection configuration, first call DescribeTLSInspectionConfiguration to retrieve the current TLSInspectionConfiguration object, update the object as needed, and then provide the updated object to this call.
4679 4680 4681 4682 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4679 def update_tls_inspection_configuration(params = {}, = {}) req = build_request(:update_tls_inspection_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4708 4709 4710 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 4708 def waiter_names [] end |