Class: Aws::NetworkFirewall::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NetworkFirewall::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-networkfirewall/client.rb
Overview
An API client for NetworkFirewall. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::NetworkFirewall::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
-
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall.
-
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
-
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
-
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
-
#create_tls_inspection_configuration(params = {}) ⇒ Types::CreateTLSInspectionConfigurationResponse
Creates an Network Firewall TLS inspection configuration.
-
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus.
-
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
-
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
-
#delete_tls_inspection_configuration(params = {}) ⇒ Types::DeleteTLSInspectionConfigurationResponse
Deletes the specified TLSInspectionConfiguration.
-
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
-
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
-
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
-
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
-
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
-
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe.
-
#describe_tls_inspection_configuration(params = {}) ⇒ Types::DescribeTLSInspectionConfigurationResponse
Returns the data objects for the specified TLS inspection configuration.
-
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall.
-
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined.
-
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined.
-
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource.
-
#list_tls_inspection_configurations(params = {}) ⇒ Types::ListTLSInspectionConfigurationsResponse
Retrieves the metadata for the TLS inspection configurations that you have defined.
-
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group or firewall policy.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource.
-
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag, ‘DeleteProtection`, which indicates whether it is possible to delete the firewall.
-
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall.
-
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
-
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
-
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag, ‘ChangeProtection`, which indicates whether it is possible to change the firewall.
-
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
-
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group.
-
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:.
-
#update_tls_inspection_configuration(params = {}) ⇒ Types::UpdateTLSInspectionConfigurationResponse
Updates the TLS inspection configuration settings for the specified TLS inspection configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
391 392 393 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 391 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3552 3553 3554 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3552 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3555 3556 3557 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3555 def errors_module Errors end |
Instance Method Details
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
A firewall policy defines how to monitor and manage your VPC network traffic, using a collection of inspection rule groups and other settings. Each firewall requires one firewall policy association, and you can use the same firewall policy for multiple firewalls.
464 465 466 467 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 464 def associate_firewall_policy(params = {}, = {}) req = build_request(:associate_firewall_policy, params) req.send_request() end |
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall. You can specify one subnet for each of the Availability Zones that the VPC spans.
This request creates an Network Firewall firewall endpoint in each of the subnets. To enable the firewall’s protections, you must also modify the VPC’s route tables for each subnet’s Availability Zone, to redirect the traffic that’s coming into and going out of the zone through the firewall endpoint.
546 547 548 549 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 546 def associate_subnets(params = {}, = {}) req = build_request(:associate_subnets, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3530 3531 3532 3533 3534 3535 3536 3537 3538 3539 3540 3541 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3530 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-networkfirewall' context[:gem_version] = '1.32.0' Seahorse::Client::Request.new(handlers, context) end |
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
The firewall defines the configuration settings for an Network Firewall firewall. The settings that you can define at creation include the firewall policy, the subnets in your VPC to use for the firewall endpoints, and any tags that are attached to the firewall Amazon Web Services resource.
After you create a firewall, you can provide additional settings, like the logging configuration.
To update the settings for a firewall, you use the operations that apply to the settings themselves, for example UpdateLoggingConfiguration, AssociateSubnets, and UpdateFirewallDeleteProtection.
To manage a firewall’s tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about firewalls, use ListFirewalls and DescribeFirewall.
696 697 698 699 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 696 def create_firewall(params = {}, = {}) req = build_request(:create_firewall, params) req.send_request() end |
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
An Network Firewall firewall policy defines the behavior of a firewall, in a collection of stateless and stateful rule groups and other settings. You can use one firewall policy for multiple firewalls.
832 833 834 835 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 832 def create_firewall_policy(params = {}, = {}) req = build_request(:create_firewall_policy, params) req.send_request() end |
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
You provide your rule group specification in your request using either ‘RuleGroup` or `Rules`.
1116 1117 1118 1119 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1116 def create_rule_group(params = {}, = {}) req = build_request(:create_rule_group, params) req.send_request() end |
#create_tls_inspection_configuration(params = {}) ⇒ Types::CreateTLSInspectionConfigurationResponse
Creates an Network Firewall TLS inspection configuration. A TLS inspection configuration contains the Certificate Manager certificate references that Network Firewall uses to decrypt and re-encrypt inbound traffic.
After you create a TLS inspection configuration, you associate it with a firewall policy.
To update the settings for a TLS inspection configuration, use UpdateTLSInspectionConfiguration.
To manage a TLS inspection configuration’s tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about TLS inspection configurations, use ListTLSInspectionConfigurations and DescribeTLSInspectionConfiguration.
For more information about TLS inspection configurations, see
- Decrypting SSL/TLS traffic with TLS inspection configurations][1
-
in
the *Network Firewall Developer Guide*.
[1]: docs.aws.amazon.com/network-firewall/latest/developerguide/tls-inspection.html
1282 1283 1284 1285 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1282 def create_tls_inspection_configuration(params = {}, = {}) req = build_request(:create_tls_inspection_configuration, params) req.send_request() end |
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus. This operation requires the firewall’s ‘DeleteProtection` flag to be `FALSE`. You can’t revert this operation.
You can check whether a firewall is in use by reviewing the route tables for the Availability Zones where you have firewall subnet mappings. Retrieve the subnet mappings by calling DescribeFirewall. You define and update the route tables through Amazon VPC. As needed, update the route tables for the zones to remove the firewall endpoints. When the route tables no longer use the firewall endpoints, you can remove the firewall safely.
To delete a firewall, remove the delete protection if you need to using UpdateFirewallDeleteProtection, then delete the firewall by calling DeleteFirewall.
1364 1365 1366 1367 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1364 def delete_firewall(params = {}, = {}) req = build_request(:delete_firewall, params) req.send_request() end |
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
1414 1415 1416 1417 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1414 def delete_firewall_policy(params = {}, = {}) req = build_request(:delete_firewall_policy, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
1438 1439 1440 1441 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1438 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
1503 1504 1505 1506 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1503 def delete_rule_group(params = {}, = {}) req = build_request(:delete_rule_group, params) req.send_request() end |
#delete_tls_inspection_configuration(params = {}) ⇒ Types::DeleteTLSInspectionConfigurationResponse
Deletes the specified TLSInspectionConfiguration.
1556 1557 1558 1559 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1556 def delete_tls_inspection_configuration(params = {}, = {}) req = build_request(:delete_tls_inspection_configuration, params) req.send_request() end |
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
1626 1627 1628 1629 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1626 def describe_firewall(params = {}, = {}) req = build_request(:describe_firewall, params) req.send_request() end |
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
1702 1703 1704 1705 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1702 def describe_firewall_policy(params = {}, = {}) req = build_request(:describe_firewall_policy, params) req.send_request() end |
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
1745 1746 1747 1748 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1745 def describe_logging_configuration(params = {}, = {}) req = build_request(:describe_logging_configuration, params) req.send_request() end |
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
1775 1776 1777 1778 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1775 def describe_resource_policy(params = {}, = {}) req = build_request(:describe_resource_policy, params) req.send_request() end |
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
1895 1896 1897 1898 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1895 def describe_rule_group(params = {}, = {}) req = build_request(:describe_rule_group, params) req.send_request() end |
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe. You can use the information provided in the metadata to retrieve and manage a rule group. You can retrieve all objects for a rule group by calling DescribeRuleGroup.
1959 1960 1961 1962 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1959 def (params = {}, = {}) req = build_request(:describe_rule_group_metadata, params) req.send_request() end |
#describe_tls_inspection_configuration(params = {}) ⇒ Types::DescribeTLSInspectionConfigurationResponse
Returns the data objects for the specified TLS inspection configuration.
2032 2033 2034 2035 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2032 def describe_tls_inspection_configuration(params = {}, = {}) req = build_request(:describe_tls_inspection_configuration, params) req.send_request() end |
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall. This removes the firewall endpoints from the subnets and removes any network filtering protections that the endpoints were providing.
2103 2104 2105 2106 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2103 def disassociate_subnets(params = {}, = {}) req = build_request(:disassociate_subnets, params) req.send_request() end |
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined. Depending on your setting for max results and the number of firewall policies, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2150 2151 2152 2153 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2150 def list_firewall_policies(params = {}, = {}) req = build_request(:list_firewall_policies, params) req.send_request() end |
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined. If you provide VPC identifiers in your request, this returns only the firewalls for those VPCs.
Depending on your setting for max results and the number of firewalls, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2206 2207 2208 2209 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2206 def list_firewalls(params = {}, = {}) req = build_request(:list_firewalls, params) req.send_request() end |
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined. Depending on your setting for max results and the number of rule groups, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2270 2271 2272 2273 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2270 def list_rule_groups(params = {}, = {}) req = build_request(:list_rule_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2375 2376 2377 2378 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2375 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_tls_inspection_configurations(params = {}) ⇒ Types::ListTLSInspectionConfigurationsResponse
Retrieves the metadata for the TLS inspection configurations that you have defined. Depending on your setting for max results and the number of TLS inspection configurations, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2318 2319 2320 2321 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2318 def list_tls_inspection_configurations(params = {}, = {}) req = build_request(:list_tls_inspection_configurations, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group or firewall policy. Use this to share rule groups and firewall policies between accounts. This operation works in conjunction with the Amazon Web Services Resource Access Manager (RAM) service to manage resource sharing for Network Firewall.
Use this operation to create or update a resource policy for your rule group or firewall policy. In the policy, you specify the accounts that you want to share the resource with and the operations that you want the accounts to be able to perform.
When you add an account in the resource policy, you then run the following Resource Access Manager (RAM) operations to access and accept the shared rule group or firewall policy.
- GetResourceShareInvitations][1
-
Returns the Amazon Resource Names
-
(ARNs) of the resource share invitations.
- AcceptResourceShareInvitation][2
-
Accepts the share invitation
-
for a specified resource share.
For additional information about resource sharing using RAM, see [Resource Access Manager User Guide].
[1]: docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareInvitations.html [2]: docs.aws.amazon.com/ram/latest/APIReference/API_AcceptResourceShareInvitation.html [3]: docs.aws.amazon.com/ram/latest/userguide/what-is.html
2452 2453 2454 2455 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2452 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
2490 2491 2492 2493 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2490 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can manage tags for the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
2524 2525 2526 2527 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2524 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag, ‘DeleteProtection`, which indicates whether it is possible to delete the firewall. If the flag is set to `TRUE`, the firewall is protected against deletion. This setting helps protect against accidentally deleting a firewall that’s in use.
2598 2599 2600 2601 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2598 def update_firewall_delete_protection(params = {}, = {}) req = build_request(:update_firewall_delete_protection, params) req.send_request() end |
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall. Use the description to help you identify the firewall when you’re working with it.
2668 2669 2670 2671 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2668 def update_firewall_description(params = {}, = {}) req = build_request(:update_firewall_description, params) req.send_request() end |
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
2748 2749 2750 2751 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2748 def update_firewall_encryption_configuration(params = {}, = {}) req = build_request(:update_firewall_encryption_configuration, params) req.send_request() end |
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
2891 2892 2893 2894 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2891 def update_firewall_policy(params = {}, = {}) req = build_request(:update_firewall_policy, params) req.send_request() end |
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag, ‘ChangeProtection`, which indicates whether it is possible to change the firewall. If the flag is set to `TRUE`, the firewall is protected from changes. This setting helps protect against accidentally changing a firewall that’s in use.
2965 2966 2967 2968 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2965 def update_firewall_policy_change_protection(params = {}, = {}) req = build_request(:update_firewall_policy_change_protection, params) req.send_request() end |
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
To change the logging configuration, retrieve the LoggingConfiguration by calling DescribeLoggingConfiguration, then change it and provide the modified object to this update call. You must change the logging configuration one LogDestinationConfig at a time inside the retrieved LoggingConfiguration object.
You can perform only one of the following actions in any call to ‘UpdateLoggingConfiguration`:
-
Create a new log destination object by adding a single ‘LogDestinationConfig` array element to `LogDestinationConfigs`.
-
Delete a log destination object by removing a single ‘LogDestinationConfig` array element from `LogDestinationConfigs`.
-
Change the ‘LogDestination` setting in a single `LogDestinationConfig` array element.
You can’t change the ‘LogDestinationType` or `LogType` in a `LogDestinationConfig`. To change these settings, delete the existing `LogDestinationConfig` object and create a new one, using two separate calls to this update operation.
3048 3049 3050 3051 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3048 def update_logging_configuration(params = {}, = {}) req = build_request(:update_logging_configuration, params) req.send_request() end |
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group. You use a rule group by reference in one or more firewall policies. When you modify a rule group, you modify all firewall policies that use the rule group.
To update a rule group, first call DescribeRuleGroup to retrieve the current RuleGroup object, update the object as needed, and then provide the updated object to this call.
3302 3303 3304 3305 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3302 def update_rule_group(params = {}, = {}) req = build_request(:update_rule_group, params) req.send_request() end |
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:
-
#update_token => String
-
#firewall_arn => String
-
#firewall_name => String
-
#subnet_change_protection => Boolean
3371 3372 3373 3374 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3371 def update_subnet_change_protection(params = {}, = {}) req = build_request(:update_subnet_change_protection, params) req.send_request() end |
#update_tls_inspection_configuration(params = {}) ⇒ Types::UpdateTLSInspectionConfigurationResponse
Updates the TLS inspection configuration settings for the specified TLS inspection configuration. You use a TLS inspection configuration by reference in one or more firewall policies. When you modify a TLS inspection configuration, you modify all firewall policies that use the TLS inspection configuration.
To update a TLS inspection configuration, first call DescribeTLSInspectionConfiguration to retrieve the current TLSInspectionConfiguration object, update the object as needed, and then provide the updated object to this call.
3521 3522 3523 3524 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3521 def update_tls_inspection_configuration(params = {}, = {}) req = build_request(:update_tls_inspection_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3545 3546 3547 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3545 def waiter_names [] end |