Class: Aws::NetworkFirewall::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NetworkFirewall::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-networkfirewall/client.rb
Overview
An API client for NetworkFirewall. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::NetworkFirewall::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
-
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall.
-
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
-
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
-
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
-
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus.
-
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
-
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
-
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
-
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
-
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
-
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
-
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
-
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe.
-
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall.
-
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined.
-
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined.
-
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource.
-
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group or firewall policy.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource.
-
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag, `DeleteProtection`, which indicates whether it is possible to delete the firewall.
-
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall.
-
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
-
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
-
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag, `ChangeProtection`, which indicates whether it is possible to change the firewall.
-
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
-
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group.
-
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
375 376 377 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 375 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3023 3024 3025 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3023 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3026 3027 3028 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3026 def errors_module Errors end |
Instance Method Details
#associate_firewall_policy(params = {}) ⇒ Types::AssociateFirewallPolicyResponse
Associates a FirewallPolicy to a Firewall.
A firewall policy defines how to monitor and manage your VPC network traffic, using a collection of inspection rule groups and other settings. Each firewall requires one firewall policy association, and you can use the same firewall policy for multiple firewalls.
448 449 450 451 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 448 def associate_firewall_policy(params = {}, = {}) req = build_request(:associate_firewall_policy, params) req.send_request() end |
#associate_subnets(params = {}) ⇒ Types::AssociateSubnetsResponse
Associates the specified subnets in the Amazon VPC to the firewall. You can specify one subnet for each of the Availability Zones that the VPC spans.
This request creates an Network Firewall firewall endpoint in each of the subnets. To enable the firewall's protections, you must also modify the VPC's route tables for each subnet's Availability Zone, to redirect the traffic that's coming into and going out of the zone through the firewall endpoint.
528 529 530 531 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 528 def associate_subnets(params = {}, = {}) req = build_request(:associate_subnets, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3001 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-networkfirewall' context[:gem_version] = '1.21.0' Seahorse::Client::Request.new(handlers, context) end |
#create_firewall(params = {}) ⇒ Types::CreateFirewallResponse
Creates an Network Firewall Firewall and accompanying FirewallStatus for a VPC.
The firewall defines the configuration settings for an Network Firewall firewall. The settings that you can define at creation include the firewall policy, the subnets in your VPC to use for the firewall endpoints, and any tags that are attached to the firewall Amazon Web Services resource.
After you create a firewall, you can provide additional settings, like the logging configuration.
To update the settings for a firewall, you use the operations that apply to the settings themselves, for example UpdateLoggingConfiguration, AssociateSubnets, and UpdateFirewallDeleteProtection.
To manage a firewall's tags, use the standard Amazon Web Services resource tagging operations, ListTagsForResource, TagResource, and UntagResource.
To retrieve information about firewalls, use ListFirewalls and DescribeFirewall.
676 677 678 679 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 676 def create_firewall(params = {}, = {}) req = build_request(:create_firewall, params) req.send_request() end |
#create_firewall_policy(params = {}) ⇒ Types::CreateFirewallPolicyResponse
Creates the firewall policy for the firewall according to the specifications.
An Network Firewall firewall policy defines the behavior of a firewall, in a collection of stateless and stateful rule groups and other settings. You can use one firewall policy for multiple firewalls.
804 805 806 807 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 804 def create_firewall_policy(params = {}, = {}) req = build_request(:create_firewall_policy, params) req.send_request() end |
#create_rule_group(params = {}) ⇒ Types::CreateRuleGroupResponse
Creates the specified stateless or stateful rule group, which includes the rules for network traffic inspection, a capacity setting, and tags.
You provide your rule group specification in your request using either `RuleGroup` or `Rules`.
1088 1089 1090 1091 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1088 def create_rule_group(params = {}, = {}) req = build_request(:create_rule_group, params) req.send_request() end |
#delete_firewall(params = {}) ⇒ Types::DeleteFirewallResponse
Deletes the specified Firewall and its FirewallStatus. This operation requires the firewall's `DeleteProtection` flag to be `FALSE`. You can't revert this operation.
You can check whether a firewall is in use by reviewing the route tables for the Availability Zones where you have firewall subnet mappings. Retrieve the subnet mappings by calling DescribeFirewall. You define and update the route tables through Amazon VPC. As needed, update the route tables for the zones to remove the firewall endpoints. When the route tables no longer use the firewall endpoints, you can remove the firewall safely.
To delete a firewall, remove the delete protection if you need to using UpdateFirewallDeleteProtection, then delete the firewall by calling DeleteFirewall.
1169 1170 1171 1172 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1169 def delete_firewall(params = {}, = {}) req = build_request(:delete_firewall, params) req.send_request() end |
#delete_firewall_policy(params = {}) ⇒ Types::DeleteFirewallPolicyResponse
Deletes the specified FirewallPolicy.
1219 1220 1221 1222 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1219 def delete_firewall_policy(params = {}, = {}) req = build_request(:delete_firewall_policy, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy that you created in a PutResourcePolicy request.
1243 1244 1245 1246 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1243 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_rule_group(params = {}) ⇒ Types::DeleteRuleGroupResponse
Deletes the specified RuleGroup.
1308 1309 1310 1311 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1308 def delete_rule_group(params = {}, = {}) req = build_request(:delete_rule_group, params) req.send_request() end |
#describe_firewall(params = {}) ⇒ Types::DescribeFirewallResponse
Returns the data objects for the specified firewall.
1377 1378 1379 1380 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1377 def describe_firewall(params = {}, = {}) req = build_request(:describe_firewall, params) req.send_request() end |
#describe_firewall_policy(params = {}) ⇒ Types::DescribeFirewallPolicyResponse
Returns the data objects for the specified firewall policy.
1449 1450 1451 1452 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1449 def describe_firewall_policy(params = {}, = {}) req = build_request(:describe_firewall_policy, params) req.send_request() end |
#describe_logging_configuration(params = {}) ⇒ Types::DescribeLoggingConfigurationResponse
Returns the logging configuration for the specified firewall.
1492 1493 1494 1495 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1492 def describe_logging_configuration(params = {}, = {}) req = build_request(:describe_logging_configuration, params) req.send_request() end |
#describe_resource_policy(params = {}) ⇒ Types::DescribeResourcePolicyResponse
Retrieves a resource policy that you created in a PutResourcePolicy request.
1522 1523 1524 1525 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1522 def describe_resource_policy(params = {}, = {}) req = build_request(:describe_resource_policy, params) req.send_request() end |
#describe_rule_group(params = {}) ⇒ Types::DescribeRuleGroupResponse
Returns the data objects for the specified rule group.
1642 1643 1644 1645 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1642 def describe_rule_group(params = {}, = {}) req = build_request(:describe_rule_group, params) req.send_request() end |
#describe_rule_group_metadata(params = {}) ⇒ Types::DescribeRuleGroupMetadataResponse
High-level information about a rule group, returned by operations like create and describe. You can use the information provided in the metadata to retrieve and manage a rule group. You can retrieve all objects for a rule group by calling DescribeRuleGroup.
1706 1707 1708 1709 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1706 def (params = {}, = {}) req = build_request(:describe_rule_group_metadata, params) req.send_request() end |
#disassociate_subnets(params = {}) ⇒ Types::DisassociateSubnetsResponse
Removes the specified subnet associations from the firewall. This removes the firewall endpoints from the subnets and removes any network filtering protections that the endpoints were providing.
1776 1777 1778 1779 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1776 def disassociate_subnets(params = {}, = {}) req = build_request(:disassociate_subnets, params) req.send_request() end |
#list_firewall_policies(params = {}) ⇒ Types::ListFirewallPoliciesResponse
Retrieves the metadata for the firewall policies that you have defined. Depending on your setting for max results and the number of firewall policies, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1823 1824 1825 1826 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1823 def list_firewall_policies(params = {}, = {}) req = build_request(:list_firewall_policies, params) req.send_request() end |
#list_firewalls(params = {}) ⇒ Types::ListFirewallsResponse
Retrieves the metadata for the firewalls that you have defined. If you provide VPC identifiers in your request, this returns only the firewalls for those VPCs.
Depending on your setting for max results and the number of firewalls, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1879 1880 1881 1882 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1879 def list_firewalls(params = {}, = {}) req = build_request(:list_firewalls, params) req.send_request() end |
#list_rule_groups(params = {}) ⇒ Types::ListRuleGroupsResponse
Retrieves the metadata for the rule groups that you have defined. Depending on your setting for max results and the number of rule groups, a single call might not return the full list.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1943 1944 1945 1946 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 1943 def list_rule_groups(params = {}, = {}) req = build_request(:list_rule_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags associated with the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2000 2001 2002 2003 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2000 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Struct
Creates or updates an IAM policy for your rule group or firewall policy. Use this to share rule groups and firewall policies between accounts. This operation works in conjunction with the Amazon Web Services Resource Access Manager (RAM) service to manage resource sharing for Network Firewall.
Use this operation to create or update a resource policy for your rule group or firewall policy. In the policy, you specify the accounts that you want to share the resource with and the operations that you want the accounts to be able to perform.
When you add an account in the resource policy, you then run the following Resource Access Manager (RAM) operations to access and accept the shared rule group or firewall policy.
- GetResourceShareInvitations][1
-
Returns the Amazon Resource Names
-
(ARNs) of the resource share invitations.
- AcceptResourceShareInvitation][2
-
Accepts the share invitation
-
for a specified resource share.
For additional information about resource sharing using RAM, see [Resource Access Manager User Guide].
[1]: docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareInvitations.html [2]: docs.aws.amazon.com/ram/latest/APIReference/API_AcceptResourceShareInvitation.html [3]: docs.aws.amazon.com/ram/latest/userguide/what-is.html
2081 2082 2083 2084 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2081 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can tag the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
2119 2120 2121 2122 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2119 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the tags with the specified keys from the specified resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to “customer” and the value to the customer name or ID. You can specify one or more tags to add to each Amazon Web Services resource, up to 50 tags for a resource.
You can manage tags for the Amazon Web Services resources that you manage through Network Firewall: firewalls, firewall policies, and rule groups.
2153 2154 2155 2156 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2153 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_firewall_delete_protection(params = {}) ⇒ Types::UpdateFirewallDeleteProtectionResponse
Modifies the flag, `DeleteProtection`, which indicates whether it is possible to delete the firewall. If the flag is set to `TRUE`, the firewall is protected against deletion. This setting helps protect against accidentally deleting a firewall that's in use.
2227 2228 2229 2230 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2227 def update_firewall_delete_protection(params = {}, = {}) req = build_request(:update_firewall_delete_protection, params) req.send_request() end |
#update_firewall_description(params = {}) ⇒ Types::UpdateFirewallDescriptionResponse
Modifies the description for the specified firewall. Use the description to help you identify the firewall when you're working with it.
2297 2298 2299 2300 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2297 def update_firewall_description(params = {}, = {}) req = build_request(:update_firewall_description, params) req.send_request() end |
#update_firewall_encryption_configuration(params = {}) ⇒ Types::UpdateFirewallEncryptionConfigurationResponse
A complex type that contains settings for encryption of your firewall resources.
2377 2378 2379 2380 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2377 def update_firewall_encryption_configuration(params = {}, = {}) req = build_request(:update_firewall_encryption_configuration, params) req.send_request() end |
#update_firewall_policy(params = {}) ⇒ Types::UpdateFirewallPolicyResponse
Updates the properties of the specified firewall policy.
2512 2513 2514 2515 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2512 def update_firewall_policy(params = {}, = {}) req = build_request(:update_firewall_policy, params) req.send_request() end |
#update_firewall_policy_change_protection(params = {}) ⇒ Types::UpdateFirewallPolicyChangeProtectionResponse
Modifies the flag, `ChangeProtection`, which indicates whether it is possible to change the firewall. If the flag is set to `TRUE`, the firewall is protected from changes. This setting helps protect against accidentally changing a firewall that's in use.
2586 2587 2588 2589 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2586 def update_firewall_policy_change_protection(params = {}, = {}) req = build_request(:update_firewall_policy_change_protection, params) req.send_request() end |
#update_logging_configuration(params = {}) ⇒ Types::UpdateLoggingConfigurationResponse
Sets the logging configuration for the specified firewall.
To change the logging configuration, retrieve the LoggingConfiguration by calling DescribeLoggingConfiguration, then change it and provide the modified object to this update call. You must change the logging configuration one LogDestinationConfig at a time inside the retrieved LoggingConfiguration object.
You can perform only one of the following actions in any call to `UpdateLoggingConfiguration`:
-
Create a new log destination object by adding a single `LogDestinationConfig` array element to `LogDestinationConfigs`.
-
Delete a log destination object by removing a single `LogDestinationConfig` array element from `LogDestinationConfigs`.
-
Change the `LogDestination` setting in a single `LogDestinationConfig` array element.
You can't change the `LogDestinationType` or `LogType` in a `LogDestinationConfig`. To change these settings, delete the existing `LogDestinationConfig` object and create a new one, using two separate calls to this update operation.
2669 2670 2671 2672 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2669 def update_logging_configuration(params = {}, = {}) req = build_request(:update_logging_configuration, params) req.send_request() end |
#update_rule_group(params = {}) ⇒ Types::UpdateRuleGroupResponse
Updates the rule settings for the specified rule group. You use a rule group by reference in one or more firewall policies. When you modify a rule group, you modify all firewall policies that use the rule group.
To update a rule group, first call DescribeRuleGroup to retrieve the current RuleGroup object, update the object as needed, and then provide the updated object to this call.
2923 2924 2925 2926 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2923 def update_rule_group(params = {}, = {}) req = build_request(:update_rule_group, params) req.send_request() end |
#update_subnet_change_protection(params = {}) ⇒ Types::UpdateSubnetChangeProtectionResponse
Returns a response object which responds to the following methods:
-
#update_token => String
-
#firewall_arn => String
-
#firewall_name => String
-
#subnet_change_protection => Boolean
2992 2993 2994 2995 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 2992 def update_subnet_change_protection(params = {}, = {}) req = build_request(:update_subnet_change_protection, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3016 3017 3018 |
# File 'lib/aws-sdk-networkfirewall/client.rb', line 3016 def waiter_names [] end |