Class: Aws::NetworkFirewall::Types::CreateVpcEndpointAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::CreateVpcEndpointAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the VPC endpoint association.
-
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
-
#subnet_mapping ⇒ Types::SubnetMapping
The ID for a subnet that's used in an association with a firewall.
-
#tags ⇒ Array<Types::Tag>
The key:value pairs to associate with the resource.
-
#vpc_id ⇒ String
The unique identifier of the VPC where you want to create a firewall endpoint.
Instance Attribute Details
#description ⇒ String
A description of the VPC endpoint association.
1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963 class CreateVpcEndpointAssociationRequest < Struct.new( :firewall_arn, :vpc_id, :subnet_mapping, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963 class CreateVpcEndpointAssociationRequest < Struct.new( :firewall_arn, :vpc_id, :subnet_mapping, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#subnet_mapping ⇒ Types::SubnetMapping
The ID for a subnet that's used in an association with a firewall. This is used in CreateFirewall, AssociateSubnets, and CreateVpcEndpointAssociation. Network Firewall creates an instance of the associated firewall in each subnet that you specify, to filter traffic in the subnet's Availability Zone.
1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963 class CreateVpcEndpointAssociationRequest < Struct.new( :firewall_arn, :vpc_id, :subnet_mapping, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The key:value pairs to associate with the resource.
1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963 class CreateVpcEndpointAssociationRequest < Struct.new( :firewall_arn, :vpc_id, :subnet_mapping, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The unique identifier of the VPC where you want to create a firewall endpoint.
1963 1964 1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1963 class CreateVpcEndpointAssociationRequest < Struct.new( :firewall_arn, :vpc_id, :subnet_mapping, :description, :tags) SENSITIVE = [] include Aws::Structure end |