Class: Aws::NetworkFirewall::Types::CreateVpcEndpointAssociationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::CreateVpcEndpointAssociationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#vpc_endpoint_association ⇒ Types::VpcEndpointAssociation
The configuration settings for the VPC endpoint association.
-
#vpc_endpoint_association_status ⇒ Types::VpcEndpointAssociationStatus
Detailed information about the current status of a VpcEndpointAssociation.
Instance Attribute Details
#vpc_endpoint_association ⇒ Types::VpcEndpointAssociation
The configuration settings for the VPC endpoint association. These settings include the firewall and the VPC and subnet to use for the firewall endpoint.
1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1988 class CreateVpcEndpointAssociationResponse < Struct.new( :vpc_endpoint_association, :vpc_endpoint_association_status) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_association_status ⇒ Types::VpcEndpointAssociationStatus
Detailed information about the current status of a VpcEndpointAssociation. You can retrieve this by calling DescribeVpcEndpointAssociation and providing the VPC endpoint association ARN.
1988 1989 1990 1991 1992 1993 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 1988 class CreateVpcEndpointAssociationResponse < Struct.new( :vpc_endpoint_association, :vpc_endpoint_association_status) SENSITIVE = [] include Aws::Structure end |