Class: Aws::NetworkFirewall::Types::DeleteVpcEndpointAssociationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#vpc_endpoint_associationTypes::VpcEndpointAssociation

The configuration settings for the VPC endpoint association. These settings include the firewall and the VPC and subnet to use for the firewall endpoint.



2261
2262
2263
2264
2265
2266
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2261

class DeleteVpcEndpointAssociationResponse < Struct.new(
  :vpc_endpoint_association,
  :vpc_endpoint_association_status)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_association_statusTypes::VpcEndpointAssociationStatus

Detailed information about the current status of a VpcEndpointAssociation. You can retrieve this by calling DescribeVpcEndpointAssociation and providing the VPC endpoint association ARN.



2261
2262
2263
2264
2265
2266
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2261

class DeleteVpcEndpointAssociationResponse < Struct.new(
  :vpc_endpoint_association,
  :vpc_endpoint_association_status)
  SENSITIVE = []
  include Aws::Structure
end