Class: Aws::NetworkFirewall::Types::DescribeFirewallMetadataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DescribeFirewallMetadataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the firewall.
-
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
-
#firewall_policy_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall policy.
-
#status ⇒ String
The readiness of the configured firewall to handle network traffic across all of the Availability Zones where you have it configured.
-
#supported_availability_zones ⇒ Hash<String,Types::AvailabilityZoneMetadata>
The Availability Zones that the firewall currently supports.
-
#transit_gateway_attachment_id ⇒ String
The unique identifier of the transit gateway attachment associated with this firewall.
Instance Attribute Details
#description ⇒ String
A description of the firewall.
2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2676 class DescribeFirewallMetadataResponse < Struct.new( :firewall_arn, :firewall_policy_arn, :description, :status, :supported_availability_zones, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2676 class DescribeFirewallMetadataResponse < Struct.new( :firewall_arn, :firewall_policy_arn, :description, :status, :supported_availability_zones, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#firewall_policy_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall policy.
2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2676 class DescribeFirewallMetadataResponse < Struct.new( :firewall_arn, :firewall_policy_arn, :description, :status, :supported_availability_zones, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The readiness of the configured firewall to handle network traffic
across all of the Availability Zones where you have it configured.
This setting is READY only when the
ConfigurationSyncStateSummary value is IN_SYNC and the
Attachment Status values for all of the configured subnets are
READY.
2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2676 class DescribeFirewallMetadataResponse < Struct.new( :firewall_arn, :firewall_policy_arn, :description, :status, :supported_availability_zones, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#supported_availability_zones ⇒ Hash<String,Types::AvailabilityZoneMetadata>
The Availability Zones that the firewall currently supports. This includes all Availability Zones for which the firewall has a subnet defined.
2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2676 class DescribeFirewallMetadataResponse < Struct.new( :firewall_arn, :firewall_policy_arn, :description, :status, :supported_availability_zones, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |
#transit_gateway_attachment_id ⇒ String
The unique identifier of the transit gateway attachment associated with this firewall. This field is only present for transit gateway-attached firewalls.
2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2676 class DescribeFirewallMetadataResponse < Struct.new( :firewall_arn, :firewall_policy_arn, :description, :status, :supported_availability_zones, :transit_gateway_attachment_id) SENSITIVE = [] include Aws::Structure end |