Class: Aws::NetworkFirewall::Types::DescribeLoggingConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DescribeLoggingConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_monitoring_dashboard ⇒ Boolean
A boolean that reflects whether or not the firewall monitoring dashboard is enabled on a firewall.
-
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
-
#logging_configuration ⇒ Types::LoggingConfiguration
Defines how Network Firewall performs logging for a Firewall.
Instance Attribute Details
#enable_monitoring_dashboard ⇒ Boolean
A boolean that reflects whether or not the firewall monitoring dashboard is enabled on a firewall.
Returns TRUE when the firewall monitoring dashboard is enabled on
the firewall. Returns FALSE when the firewall monitoring dashboard
is not enabled on the firewall.
2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2967 class DescribeLoggingConfigurationResponse < Struct.new( :firewall_arn, :logging_configuration, :enable_monitoring_dashboard) SENSITIVE = [] include Aws::Structure end |
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2967 class DescribeLoggingConfigurationResponse < Struct.new( :firewall_arn, :logging_configuration, :enable_monitoring_dashboard) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
Defines how Network Firewall performs logging for a Firewall.
2967 2968 2969 2970 2971 2972 2973 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 2967 class DescribeLoggingConfigurationResponse < Struct.new( :firewall_arn, :logging_configuration, :enable_monitoring_dashboard) SENSITIVE = [] include Aws::Structure end |