Class: Aws::NetworkFirewall::Types::DescribeProxyResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DescribeProxyResource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Proxy attached to a NAT gateway.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_time ⇒ Time
Time the Proxy was created.
-
#delete_time ⇒ Time
Time the Proxy was deleted.
-
#failure_code ⇒ String
Failure code for cases when the Proxy fails to attach or update.
-
#failure_message ⇒ String
Failure message for cases when the Proxy fails to attach or update.
-
#listener_properties ⇒ Array<Types::ListenerProperty>
Listener properties for HTTP and HTTPS traffic.
-
#nat_gateway_id ⇒ String
The NAT Gateway for the proxy.
-
#private_dns_name ⇒ String
The private DNS name of the Proxy.
-
#proxy_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy.
-
#proxy_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy configuration.
-
#proxy_configuration_name ⇒ String
The descriptive name of the proxy configuration.
-
#proxy_modify_state ⇒ String
Current modification status of the Proxy.
-
#proxy_name ⇒ String
The descriptive name of the proxy.
-
#proxy_state ⇒ String
Current attachment/detachment status of the Proxy.
-
#tags ⇒ Array<Types::Tag>
The key:value pairs to associate with the resource.
-
#tls_intercept_properties ⇒ Types::TlsInterceptProperties
TLS decryption on traffic to filter on attributes in the HTTP header.
-
#update_time ⇒ Time
Time the Proxy was updated.
-
#vpc_endpoint_service_name ⇒ String
The service endpoint created in the VPC.
Instance Attribute Details
#create_time ⇒ Time
Time the Proxy was created.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#delete_time ⇒ Time
Time the Proxy was deleted.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
Failure code for cases when the Proxy fails to attach or update.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
Failure message for cases when the Proxy fails to attach or update.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#listener_properties ⇒ Array<Types::ListenerProperty>
Listener properties for HTTP and HTTPS traffic.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
The NAT Gateway for the proxy.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#private_dns_name ⇒ String
The private DNS name of the Proxy.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#proxy_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#proxy_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy configuration.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#proxy_configuration_name ⇒ String
The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#proxy_modify_state ⇒ String
Current modification status of the Proxy.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#proxy_name ⇒ String
The descriptive name of the proxy. You can't change the name of a proxy after you create it.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#proxy_state ⇒ String
Current attachment/detachment status of the Proxy.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The key:value pairs to associate with the resource.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#tls_intercept_properties ⇒ Types::TlsInterceptProperties
TLS decryption on traffic to filter on attributes in the HTTP header.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
Time the Proxy was updated.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_service_name ⇒ String
The service endpoint created in the VPC.
3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3122 class DescribeProxyResource < Struct.new( :proxy_name, :proxy_arn, :proxy_configuration_name, :proxy_configuration_arn, :nat_gateway_id, :proxy_state, :proxy_modify_state, :listener_properties, :tls_intercept_properties, :vpc_endpoint_service_name, :private_dns_name, :create_time, :delete_time, :update_time, :failure_code, :failure_message, :tags) SENSITIVE = [] include Aws::Structure end |