Class: Aws::NetworkFirewall::Types::DescribeRuleGroupMetadataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacityInteger

The maximum operating resources that this rule group can use. Rule group capacity is fixed at creation. When you update a rule group, you are limited to this capacity. When you reference a rule group from a firewall policy, Network Firewall reserves this capacity for the rule group.

You can retrieve the capacity that would be required for a rule group before you create the rule group by calling CreateRuleGroup with DryRun set to TRUE.

Returns:

  • (Integer)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Returns the metadata objects for the specified rule group.

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

A timestamp indicating when the rule group was last modified.

Returns:

  • (Time)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#listing_nameString

The display name of the product listing for this rule group.

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#product_idString

The unique identifier for the product listing associated with this rule group.

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_arnString

The descriptive name of the rule group. You can’t change the name of a rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#rule_group_nameString

The descriptive name of the rule group. You can’t change the name of a rule group after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#stateful_rule_optionsTypes::StatefulRuleOptions

Additional options governing how Network Firewall handles the rule group. You can only use these for stateful rule groups.



3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules.

<note markdown=“1”> This setting is required for requests that do not include the RuleGroupARN.

</note>

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_nameString

The name of the Amazon Web Services Marketplace vendor that provides this rule group.

Returns:

  • (String)


3041
3042
3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041

class DescribeRuleGroupMetadataResponse < Struct.new(
  :rule_group_arn,
  :rule_group_name,
  :description,
  :type,
  :capacity,
  :stateful_rule_options,
  :last_modified_time,
  :vendor_name,
  :product_id,
  :listing_name)
  SENSITIVE = []
  include Aws::Structure
end