Class: Aws::NetworkFirewall::Types::DescribeRuleGroupMetadataResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DescribeRuleGroupMetadataResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity ⇒ Integer
The maximum operating resources that this rule group can use.
-
#description ⇒ String
Returns the metadata objects for the specified rule group.
-
#last_modified_time ⇒ Time
A timestamp indicating when the rule group was last modified.
-
#listing_name ⇒ String
The display name of the product listing for this rule group.
-
#product_id ⇒ String
The unique identifier for the product listing associated with this rule group.
-
#rule_group_arn ⇒ String
The descriptive name of the rule group.
-
#rule_group_name ⇒ String
The descriptive name of the rule group.
-
#stateful_rule_options ⇒ Types::StatefulRuleOptions
Additional options governing how Network Firewall handles the rule group.
-
#type ⇒ String
Indicates whether the rule group is stateless or stateful.
-
#vendor_name ⇒ String
The name of the Amazon Web Services Marketplace vendor that provides this rule group.
Instance Attribute Details
#capacity ⇒ Integer
The maximum operating resources that this rule group can use. Rule group capacity is fixed at creation. When you update a rule group, you are limited to this capacity. When you reference a rule group from a firewall policy, Network Firewall reserves this capacity for the rule group.
You can retrieve the capacity that would be required for a rule group before you create the rule group by calling CreateRuleGroup with DryRun set to TRUE.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Returns the metadata objects for the specified rule group.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
A timestamp indicating when the rule group was last modified.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#listing_name ⇒ String
The display name of the product listing for this rule group.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#product_id ⇒ String
The unique identifier for the product listing associated with this rule group.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#rule_group_arn ⇒ String
The descriptive name of the rule group. You can’t change the name of a rule group after you create it.
You must specify the ARN or the name, and you can specify both.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#rule_group_name ⇒ String
The descriptive name of the rule group. You can’t change the name of a rule group after you create it.
You must specify the ARN or the name, and you can specify both.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#stateful_rule_options ⇒ Types::StatefulRuleOptions
Additional options governing how Network Firewall handles the rule group. You can only use these for stateful rule groups.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Indicates whether the rule group is stateless or stateful. If the rule group is stateless, it contains stateless rules. If it is stateful, it contains stateful rules.
<note markdown=“1”> This setting is required for requests that do not include the RuleGroupARN.
</note>
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |
#vendor_name ⇒ String
The name of the Amazon Web Services Marketplace vendor that provides this rule group.
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3041 class DescribeRuleGroupMetadataResponse < Struct.new( :rule_group_arn, :rule_group_name, :description, :type, :capacity, :stateful_rule_options, :last_modified_time, :vendor_name, :product_id, :listing_name) SENSITIVE = [] include Aws::Structure end |