Class: Aws::NetworkFirewall::Types::DescribeRuleGroupSummaryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DescribeRuleGroupSummaryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the rule group.
-
#rule_group_name ⇒ String
The descriptive name of the rule group.
-
#summary ⇒ Types::Summary
A complex type that contains rule information based on the rule group’s configured summary settings.
Instance Attribute Details
#description ⇒ String
A description of the rule group.
3202 3203 3204 3205 3206 3207 3208 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3202 class DescribeRuleGroupSummaryResponse < Struct.new( :rule_group_name, :description, :summary) SENSITIVE = [] include Aws::Structure end |
#rule_group_name ⇒ String
The descriptive name of the rule group. You can’t change the name of a rule group after you create it.
3202 3203 3204 3205 3206 3207 3208 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3202 class DescribeRuleGroupSummaryResponse < Struct.new( :rule_group_name, :description, :summary) SENSITIVE = [] include Aws::Structure end |
#summary ⇒ Types::Summary
A complex type that contains rule information based on the rule group’s configured summary settings. The content varies depending on the fields that you specified to extract in your SummaryConfiguration. When you haven’t configured any summary settings, this returns an empty array. The response might include:
-
Rule identifiers
-
Rule descriptions
-
Any metadata fields that you specified in your SummaryConfiguration
3202 3203 3204 3205 3206 3207 3208 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3202 class DescribeRuleGroupSummaryResponse < Struct.new( :rule_group_name, :description, :summary) SENSITIVE = [] include Aws::Structure end |