Class: Aws::NetworkFirewall::Types::DetachRuleGroupsFromProxyConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DetachRuleGroupsFromProxyConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#proxy_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy configuration.
-
#proxy_configuration_name ⇒ String
The descriptive name of the proxy configuration.
-
#rule_group_arns ⇒ Array<String>
The proxy rule group arns to detach from the proxy configuration.
-
#rule_group_names ⇒ Array<String>
The proxy rule group names to detach from the proxy configuration.
-
#update_token ⇒ String
A token used for optimistic locking.
Instance Attribute Details
#proxy_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of a proxy configuration.
You must specify the ARN or the name, and you can specify both.
3724 3725 3726 3727 3728 3729 3730 3731 3732 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3724 class DetachRuleGroupsFromProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :rule_group_names, :rule_group_arns, :update_token) SENSITIVE = [] include Aws::Structure end |
#proxy_configuration_name ⇒ String
The descriptive name of the proxy configuration. You can't change the name of a proxy configuration after you create it.
You must specify the ARN or the name, and you can specify both.
3724 3725 3726 3727 3728 3729 3730 3731 3732 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3724 class DetachRuleGroupsFromProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :rule_group_names, :rule_group_arns, :update_token) SENSITIVE = [] include Aws::Structure end |
#rule_group_arns ⇒ Array<String>
The proxy rule group arns to detach from the proxy configuration
3724 3725 3726 3727 3728 3729 3730 3731 3732 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3724 class DetachRuleGroupsFromProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :rule_group_names, :rule_group_arns, :update_token) SENSITIVE = [] include Aws::Structure end |
#rule_group_names ⇒ Array<String>
The proxy rule group names to detach from the proxy configuration
3724 3725 3726 3727 3728 3729 3730 3731 3732 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3724 class DetachRuleGroupsFromProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :rule_group_names, :rule_group_arns, :update_token) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
A token used for optimistic locking. Network Firewall returns a token to your requests that access the proxy configuration. The token marks the state of the proxy configuration resource at the time of the request.
To make changes to the proxy configuration, you provide the token in
your request. Network Firewall uses the token to ensure that the
proxy configuration hasn't changed since you last retrieved it. If
it has changed, the operation fails with an InvalidTokenException.
If this happens, retrieve the proxy configuration again to get a
current copy of it with a current token. Reapply your changes as
needed, then try the operation again using the new token.
3724 3725 3726 3727 3728 3729 3730 3731 3732 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3724 class DetachRuleGroupsFromProxyConfigurationRequest < Struct.new( :proxy_configuration_name, :proxy_configuration_arn, :rule_group_names, :rule_group_arns, :update_token) SENSITIVE = [] include Aws::Structure end |