Class: Aws::NetworkFirewall::Types::DisassociateAvailabilityZonesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::DisassociateAvailabilityZonesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone_mappings ⇒ Array<Types::AvailabilityZoneMapping>
The remaining Availability Zones where the firewall has endpoints after the disassociation.
-
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
-
#firewall_name ⇒ String
The descriptive name of the firewall.
-
#update_token ⇒ String
An optional token that you can use for optimistic locking.
Instance Attribute Details
#availability_zone_mappings ⇒ Array<Types::AvailabilityZoneMapping>
The remaining Availability Zones where the firewall has endpoints after the disassociation.
3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3516 class DisassociateAvailabilityZonesResponse < Struct.new( :firewall_arn, :firewall_name, :availability_zone_mappings, :update_token) SENSITIVE = [] include Aws::Structure end |
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3516 class DisassociateAvailabilityZonesResponse < Struct.new( :firewall_arn, :firewall_name, :availability_zone_mappings, :update_token) SENSITIVE = [] include Aws::Structure end |
#firewall_name ⇒ String
The descriptive name of the firewall. You can’t change the name of a firewall after you create it.
3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3516 class DisassociateAvailabilityZonesResponse < Struct.new( :firewall_arn, :firewall_name, :availability_zone_mappings, :update_token) SENSITIVE = [] include Aws::Structure end |
#update_token ⇒ String
An optional token that you can use for optimistic locking. Network Firewall returns a token to your requests that access the firewall. The token marks the state of the firewall resource at the time of the request.
To make an unconditional change to the firewall, omit the token in your update request. Without the token, Network Firewall performs your updates regardless of whether the firewall has changed since you last retrieved it.
To make a conditional change to the firewall, provide the token in your update request. Network Firewall uses the token to ensure that the firewall hasn’t changed since you last retrieved it. If it has changed, the operation fails with an InvalidTokenException. If this happens, retrieve the firewall again to get a current copy of it with a new token. Reapply your changes as needed, then try the operation again using the new token.
3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 3516 class DisassociateAvailabilityZonesResponse < Struct.new( :firewall_arn, :firewall_name, :availability_zone_mappings, :update_token) SENSITIVE = [] include Aws::Structure end |