Class: Aws::NetworkFirewall::Types::Hits
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::Hits
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Attempts made to a access domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of attempts made to access a domain.
Instance Attribute Details
#count ⇒ Integer
The number of attempts made to access a domain.
4553 4554 4555 4556 4557 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 4553 class Hits < Struct.new( :count) SENSITIVE = [] include Aws::Structure end |