Class: Aws::NetworkFirewall::Types::NatGatewayAttachment
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::NatGatewayAttachment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
The definition and status of the attachment between a proxy mode firewall and a NAT gateway that proxies its traffic.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dns_name ⇒ String
The DNS name that resolves to the firewall's proxy for traffic sent through this NAT gateway attachment.
-
#nat_gateway_id ⇒ String
A unique identifier for the NAT gateway to use with proxy resources.
-
#status ⇒ String
The current status of the NAT gateway attachment.
-
#status_message ⇒ String
If Network Firewall encounters an issue with the NAT gateway attachment, it populates this with an explanation of the problem.
Instance Attribute Details
#dns_name ⇒ String
The DNS name that resolves to the firewall's proxy for traffic sent through this NAT gateway attachment.
6152 6153 6154 6155 6156 6157 6158 6159 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152 class NatGatewayAttachment < Struct.new( :nat_gateway_id, :status, :status_message, :dns_name) SENSITIVE = [] include Aws::Structure end |
#nat_gateway_id ⇒ String
A unique identifier for the NAT gateway to use with proxy resources.
6152 6153 6154 6155 6156 6157 6158 6159 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152 class NatGatewayAttachment < Struct.new( :nat_gateway_id, :status, :status_message, :dns_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the NAT gateway attachment.
When this value is READY, the attachment is available to proxy
traffic. Otherwise, this value reflects its state, for example
CREATING or DELETING.
6152 6153 6154 6155 6156 6157 6158 6159 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152 class NatGatewayAttachment < Struct.new( :nat_gateway_id, :status, :status_message, :dns_name) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
If Network Firewall encounters an issue with the NAT gateway attachment, it populates this with an explanation of the problem.
6152 6153 6154 6155 6156 6157 6158 6159 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6152 class NatGatewayAttachment < Struct.new( :nat_gateway_id, :status, :status_message, :dns_name) SENSITIVE = [] include Aws::Structure end |