Class: Aws::NetworkFirewall::Types::ProxyRuleGroupAttachment
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::ProxyRuleGroupAttachment
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
The proxy rule group(s) to attach to the proxy configuration
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#insert_position ⇒ Integer
Where to insert a proxy rule group in a proxy configuration.
-
#proxy_rule_group_name ⇒ String
The descriptive name of the proxy rule group.
Instance Attribute Details
#insert_position ⇒ Integer
Where to insert a proxy rule group in a proxy configuration.
6630 6631 6632 6633 6634 6635 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6630 class ProxyRuleGroupAttachment < Struct.new( :proxy_rule_group_name, :insert_position) SENSITIVE = [] include Aws::Structure end |
#proxy_rule_group_name ⇒ String
The descriptive name of the proxy rule group. You can't change the name of a proxy rule group after you create it.
6630 6631 6632 6633 6634 6635 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 6630 class ProxyRuleGroupAttachment < Struct.new( :proxy_rule_group_name, :insert_position) SENSITIVE = [] include Aws::Structure end |