Class: Aws::NetworkFirewall::Types::RuleOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::RuleOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Additional settings for a stateful rule. This is part of the StatefulRule configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#keyword ⇒ String
The keyword for the Suricata compatible rule option.
-
#settings ⇒ Array<String>
The settings of the Suricata compatible rule option.
Instance Attribute Details
#keyword ⇒ String
The keyword for the Suricata compatible rule option. You must
include a sid (signature ID), and can optionally include other
keywords. For information about Suricata compatible keywords, see
Rule options in the Suricata documentation.
7229 7230 7231 7232 7233 7234 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7229 class RuleOption < Struct.new( :keyword, :settings) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Array<String>
The settings of the Suricata compatible rule option. Rule options
have zero or more setting values, and the number of possible and
required settings depends on the Keyword. For more information
about the settings for specific options, see Rule options.
7229 7230 7231 7232 7233 7234 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7229 class RuleOption < Struct.new( :keyword, :settings) SENSITIVE = [] include Aws::Structure end |