Class: Aws::NetworkFirewall::Types::RuleSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::RuleSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
A complex type containing details about a Suricata rule. Contains:
-
SID -
Msg -
Metadata
Summaries are available for rule groups you manage and for active threat defense Amazon Web Services managed rule groups.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata ⇒ String
The contents of the rule's metadata.
-
#msg ⇒ String
The contents taken from the rule's msg field.
-
#sid ⇒ String
The unique identifier (Signature ID) of the Suricata rule.
Instance Attribute Details
#metadata ⇒ String
The contents of the rule's metadata.
7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7261 class RuleSummary < Struct.new( :sid, :msg, :metadata) SENSITIVE = [] include Aws::Structure end |
#msg ⇒ String
The contents taken from the rule's msg field.
7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7261 class RuleSummary < Struct.new( :sid, :msg, :metadata) SENSITIVE = [] include Aws::Structure end |
#sid ⇒ String
The unique identifier (Signature ID) of the Suricata rule.
7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 7261 class RuleSummary < Struct.new( :sid, :msg, :metadata) SENSITIVE = [] include Aws::Structure end |