Class: Aws::NetworkFirewall::Types::StatelessRulesAndCustomActions
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::StatelessRulesAndCustomActions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Stateless inspection criteria. Each stateless rule group uses exactly one of these data types to define its stateless rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_actions ⇒ Array<Types::CustomAction>
Defines an array of individual custom action definitions that are available for use by the stateless rules in this
StatelessRulesAndCustomActionsspecification. -
#stateless_rules ⇒ Array<Types::StatelessRule>
Defines the set of stateless rules for use in a stateless rule group.
Instance Attribute Details
#custom_actions ⇒ Array<Types::CustomAction>
Defines an array of individual custom action definitions that are
available for use by the stateless rules in this
StatelessRulesAndCustomActions specification. You name each custom
action that you define, and then you can use it by name in your
StatelessRule RuleDefinition Actions specification.
8090 8091 8092 8093 8094 8095 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8090 class StatelessRulesAndCustomActions < Struct.new( :stateless_rules, :custom_actions) SENSITIVE = [] include Aws::Structure end |
#stateless_rules ⇒ Array<Types::StatelessRule>
Defines the set of stateless rules for use in a stateless rule group.
8090 8091 8092 8093 8094 8095 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8090 class StatelessRulesAndCustomActions < Struct.new( :stateless_rules, :custom_actions) SENSITIVE = [] include Aws::Structure end |