Class: Aws::NetworkFirewall::Types::UpdateLoggingConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-networkfirewall/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enable_monitoring_dashboardBoolean

A boolean that lets you enable or disable the detailed firewall monitoring dashboard on the firewall.

The monitoring dashboard provides comprehensive visibility into your firewall’s flow logs and alert logs. After you enable detailed monitoring, you can access these dashboards directly from the Monitoring page of the Network Firewall console.

Specify TRUE to enable the the detailed monitoring dashboard on the firewall. Specify FALSE to disable the the detailed monitoring dashboard on the firewall.

Returns:

  • (Boolean)


8864
8865
8866
8867
8868
8869
8870
8871
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8864

class UpdateLoggingConfigurationRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :logging_configuration,
  :enable_monitoring_dashboard)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_arnString

The Amazon Resource Name (ARN) of the firewall.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


8864
8865
8866
8867
8868
8869
8870
8871
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8864

class UpdateLoggingConfigurationRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :logging_configuration,
  :enable_monitoring_dashboard)
  SENSITIVE = []
  include Aws::Structure
end

#firewall_nameString

The descriptive name of the firewall. You can’t change the name of a firewall after you create it.

You must specify the ARN or the name, and you can specify both.

Returns:

  • (String)


8864
8865
8866
8867
8868
8869
8870
8871
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8864

class UpdateLoggingConfigurationRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :logging_configuration,
  :enable_monitoring_dashboard)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

Defines how Network Firewall performs logging for a firewall. If you omit this setting, Network Firewall disables logging for the firewall.



8864
8865
8866
8867
8868
8869
8870
8871
# File 'lib/aws-sdk-networkfirewall/types.rb', line 8864

class UpdateLoggingConfigurationRequest < Struct.new(
  :firewall_arn,
  :firewall_name,
  :logging_configuration,
  :enable_monitoring_dashboard)
  SENSITIVE = []
  include Aws::Structure
end