Class: Aws::NetworkFirewall::Types::UpdateLoggingConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NetworkFirewall::Types::UpdateLoggingConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-networkfirewall/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_monitoring_dashboard ⇒ Boolean
A boolean that lets you enable or disable the detailed firewall monitoring dashboard on the firewall.
-
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
-
#firewall_name ⇒ String
The descriptive name of the firewall.
-
#logging_configuration ⇒ Types::LoggingConfiguration
Defines how Network Firewall performs logging for a firewall.
Instance Attribute Details
#enable_monitoring_dashboard ⇒ Boolean
A boolean that lets you enable or disable the detailed firewall monitoring dashboard on the firewall.
The monitoring dashboard provides comprehensive visibility into your firewall's flow logs and alert logs. After you enable detailed monitoring, you can access these dashboards directly from the Monitoring page of the Network Firewall console.
Specify TRUE to enable the the detailed monitoring dashboard on
the firewall. Specify FALSE to disable the the detailed monitoring
dashboard on the firewall.
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9522 class UpdateLoggingConfigurationRequest < Struct.new( :firewall_arn, :firewall_name, :logging_configuration, :enable_monitoring_dashboard) SENSITIVE = [] include Aws::Structure end |
#firewall_arn ⇒ String
The Amazon Resource Name (ARN) of the firewall.
You must specify the ARN or the name, and you can specify both.
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9522 class UpdateLoggingConfigurationRequest < Struct.new( :firewall_arn, :firewall_name, :logging_configuration, :enable_monitoring_dashboard) SENSITIVE = [] include Aws::Structure end |
#firewall_name ⇒ String
The descriptive name of the firewall. You can't change the name of a firewall after you create it.
You must specify the ARN or the name, and you can specify both.
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9522 class UpdateLoggingConfigurationRequest < Struct.new( :firewall_arn, :firewall_name, :logging_configuration, :enable_monitoring_dashboard) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::LoggingConfiguration
Defines how Network Firewall performs logging for a firewall. If you omit this setting, Network Firewall disables logging for the firewall.
9522 9523 9524 9525 9526 9527 9528 9529 |
# File 'lib/aws-sdk-networkfirewall/types.rb', line 9522 class UpdateLoggingConfigurationRequest < Struct.new( :firewall_arn, :firewall_name, :logging_configuration, :enable_monitoring_dashboard) SENSITIVE = [] include Aws::Structure end |